@@ -17,12 +17,10 @@ import ldap0.modlist
 from ldap0.controls.readentry import PostReadControl
 from ldap0.dn import DNObj
 
-import web2ldap.web.forms
-import web2ldap.app.cnf
-import web2ldap.app.core
-import web2ldap.app.gui
-import web2ldap.app.schema
 from .addmodifyform import w2l_addform, get_entry_input, read_old_entry, read_ldif_template
+from . import ErrorExit
+from .gui import invalid_syntax_message, extract_invalid_syntax, main_menu
+
 
 # Attribute types always ignored for add requests
 ADD_IGNORE_ATTR_TYPES = {
@@ -48,10 +46,16 @@ def w2l_add(app):
         del app.form.field['in_avi'].value[del_row_num]
     elif input_modrow[0] == '+':
         insert_row_num = int(input_modrow[1:])
-        app.form.field['in_at'].value.insert(insert_row_num+1, app.form.field['in_at'].value[insert_row_num])
+        app.form.field['in_at'].value.insert(
+            insert_row_num+1,
+            app.form.field['in_at'].value[insert_row_num]
+        )
         app.form.field['in_av'].value.insert(insert_row_num+1, '')
         # FIX ME! This is definitely not sufficient!
-        app.form.field['in_avi'].value.insert(insert_row_num+1, app.form.field['in_avi'].value[insert_row_num])
+        app.form.field['in_avi'].value.insert(
+            insert_row_num+1,
+            app.form.field['in_avi'].value[insert_row_num]
+        )
 
     add_clonedn = app.form.getInputValue('add_clonedn', [None])[0]
     add_template = app.form.getInputValue('add_template', [None])[0]
@@ -74,7 +78,7 @@ def w2l_add(app):
         add_basedn = app.form.getInputValue('add_basedn', [app.dn])[0]
 
     if invalid_attrs:
-        error_msg = web2ldap.app.gui.invalid_syntax_message(app, invalid_attrs)
+        error_msg = invalid_syntax_message(app, invalid_attrs)
     else:
         error_msg = ''
 
@@ -126,8 +130,8 @@ def w2l_add(app):
                 app,
                 add_rdn,
                 add_basedn, entry,
-                msg='Attribute <var>%s</var> required for RDN not in entry data.' % (
-                    app.form.utf2display(rdn_attr_type)
+                msg='Attribute <var>%s</var> required for RDN not in entry data or multiple RDN values.' % (
+                    app.form.s2d(rdn_attr_type)
                 ),
             )
             return
@@ -143,7 +147,7 @@ def w2l_add(app):
     }
 
     if not add_entry:
-        raise web2ldap.app.core.ErrorExit(u'Cannot add entry without attribute values.')
+        raise ErrorExit(u'Cannot add entry without attribute values.')
 
     if app.dn:
         new_dn = rdn + DNObj.from_str(add_basedn)
@@ -163,22 +167,26 @@ def w2l_add(app):
             add_entry,
             req_ctrls=add_req_ctrls
         )
-    except ldap0.NO_SUCH_OBJECT as e:
-        raise web2ldap.app.core.ErrorExit(
-            u"""
-            %s<br>
-            Probably this superiour entry does not exist:<br>%s<br>
-            Maybe wrong base DN in LDIF template?<br>
-            """ % (
-                app.ldap_error_msg(e),
-                app.display_dn(add_basedn.decode(app.ls.charset), commandbutton=0),
+    except ldap0.NO_SUCH_OBJECT as err:
+        raise ErrorExit(
+            (
+                '%s<br>'
+                'Probably this superiour entry does not exist: %s<br>'
+                'Maybe wrong base DN in LDIF template?'
+            ) % (
+                app.ldap_error_msg(err),
+                app.display_dn(add_basedn, links=False),
             )
         )
+    except ldap0.INVALID_SYNTAX as err:
+        error_msg, invalid_attrs = extract_invalid_syntax(app, err)
+        # go back to input form so the user can correct something
+        w2l_addform(app, add_rdn, add_basedn, entry, msg=error_msg, invalid_attrs=invalid_attrs)
+        return
     except (
             ldap0.ALREADY_EXISTS,
             ldap0.CONSTRAINT_VIOLATION,
             ldap0.INVALID_DN_SYNTAX,
-            ldap0.INVALID_SYNTAX,
             ldap0.NAMING_VIOLATION,
             ldap0.OBJECT_CLASS_VIOLATION,
             ldap0.OTHER,
@@ -199,21 +207,21 @@ def w2l_add(app):
             new_dn = prec_ctrls[0].res.dn_s
         app.simple_message(
             'Added Entry',
-            """
-            <p class="SuccessMessage">Successfully added new entry.</p>
-            <p>%s</p>
-            <dl>
-              <dt>Distinguished name:</dt>
-              <dd>%s</dd>
-            </dl>
-            """ % (
+            (
+                '<p class="SuccessMessage">Successfully added new entry.</p>'
+                '<p>%s</p>'
+                '<dl>'
+                '<dt>Distinguished name:</dt>'
+                '<dd>%s</dd>'
+                '</dl>'
+            ) % (
                 app.anchor(
                     'read', 'Read added entry',
                     [('dn', str(new_dn))],
                     title=u'Display added entry %s' % (new_dn,),
                 ),
-                app.display_dn(str(new_dn), commandbutton=0),
+                app.display_dn(str(new_dn), links=False),
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
+            main_menu_list=main_menu(app),
             context_menu_list=[]
         )
