@@ -19,14 +19,13 @@ from ldap0.dn import DNObj
 
 import web2ldapcnf
 
-import web2ldap.ldapsession
-import web2ldap.ldaputil
-import web2ldap.app.cnf
-import web2ldap.app.gui
-import web2ldap.app.params
-from web2ldap.ldaputil.oidreg import OID_REG
-from web2ldap.app.schema.syntaxes import syntax_registry, LDAPSyntaxValueError
-from web2ldap.app.modify import modlist_ldif
+from ..ldaputil.oidreg import OID_REG
+from ..ldapsession import LDAPLimitErrors
+
+from . import ErrorExit
+from .gui import attrtype_select_field, footer, main_menu, top_section
+from .schema.syntaxes import syntax_registry, LDAPSyntaxValueError
+from .modify import modlist_ldif
 
 
 BULKMOD_CONFIRMATION_FORM_TMPL = """
@@ -141,11 +140,11 @@ def bulkmod_input_form(
     bulkmod_av = bulkmod_av or [u'']
     error_attrs = sorted({bulkmod_at[i] for i in input_errors})
     if error_attrs:
-        Msg = '<p class="ErrorMessage">Invalid input: %s</p>' % (
-            ', '.join(map(app.form.utf2display, error_attrs))
+        error_msg = '<p class="ErrorMessage">Invalid input: %s</p>' % (
+            ', '.join(map(app.form.s2d, error_attrs))
         )
     else:
-        Msg = '<p class="WarningMessage">Input bulk modify parameters here.</p>'
+        error_msg = '<p class="WarningMessage">Input bulk modify parameters here.</p>'
     if bulkmod_submit and bulkmod_submit.startswith('-'):
         del_row_num = int(bulkmod_submit[1:])
         if len(bulkmod_at) > 1:
@@ -159,18 +158,14 @@ def bulkmod_input_form(
             bulkmod_op.insert(insert_row_num+1, bulkmod_op[insert_row_num])
             bulkmod_av.insert(insert_row_num+1, u'')
     # Generate a select field for the attribute type
-    bulkmod_attr_select = web2ldap.app.gui.attrtype_select_field(
+    bulkmod_attr_select = attrtype_select_field(
         app,
         'bulkmod_at',
         u'Attribute type',
         [], default_attr_options=None
     )
     # Output confirmation form
-    web2ldap.app.gui.top_section(
-        app,
-        'Bulk modification input',
-        web2ldap.app.gui.main_menu(app),
-    )
+    top_section(app, 'Bulk modification input', main_menu(app))
     input_fields = '\n'.join([
         """
         <tr>
@@ -228,13 +223,13 @@ def bulkmod_input_form(
         </fieldset>
         </form>
         """.format(
-            text_msg=Msg,
+            text_msg=error_msg,
             form_begin=app.begin_form('bulkmod', 'POST'),
             field_bulkmod_ctrl=app.form.field['bulkmod_ctrl'].input_html(default=app.form.field['bulkmod_ctrl'].value),
             input_fields=input_fields,
-            field_hidden_dn=app.form.hiddenFieldHTML('dn', app.dn, app.dn),
-            field_hidden_filterstr=app.form.hiddenFieldHTML('filterstr', bulkmod_filter, bulkmod_filter),
-            field_hidden_scope=app.form.hiddenFieldHTML(
+            field_hidden_dn=app.form.hidden_field_html('dn', app.dn, app.dn),
+            field_hidden_filterstr=app.form.hidden_field_html('filterstr', bulkmod_filter, bulkmod_filter),
+            field_hidden_scope=app.form.hidden_field_html(
                 'scope',
                 str(scope),
                 str(ldap0.ldapurl.SEARCH_SCOPE_STR[scope]),
@@ -246,7 +241,7 @@ def bulkmod_input_form(
             field_bulkmod_cp=app.form.field['bulkmod_cp'].input_html(checked=bulkmod_cp),
         )
     )
-    web2ldap.app.gui.footer(app)
+    footer(app)
     # end of bulkmod_input_form()
 
 
@@ -259,7 +254,7 @@ def bulkmod_confirmation_form(
     # first try to determine the number of affected entries
     try:
         num_entries, num_referrals = app.ls.count(app.dn, scope, bulkmod_filter, sizelimit=1000)
-    except web2ldap.ldapsession.LDAPLimitErrors:
+    except LDAPLimitErrors:
         num_entries, num_referrals = ('unknown', 'unknown')
     else:
         if num_entries is None:
@@ -282,26 +277,21 @@ def bulkmod_confirmation_form(
         bulk_mod_list_ldif = '- none -'
 
     # Output confirmation form
-    web2ldap.app.gui.top_section(
-        app,
-        'Modify entries?',
-        web2ldap.app.gui.main_menu(app),
-        main_div_id='Input',
-    )
+    top_section(app, 'Modify entries?', main_menu(app), main_div_id='Input')
     app.outf.write(
         BULKMOD_CONFIRMATION_FORM_TMPL.format(
             form_begin=app.begin_form('bulkmod', 'POST'),
             field_bulkmod_ctrl='\n'.join([
                 '<li>%s (%s)</li>' % (
-                    app.form.utf2display(OID_REG.get(ctrl_oid, (ctrl_oid,))[0]),
-                    app.form.utf2display(ctrl_oid),
+                    app.form.s2d(OID_REG.get(ctrl_oid, (ctrl_oid,))[0]),
+                    app.form.s2d(ctrl_oid),
                 )
                 for ctrl_oid in app.form.field['bulkmod_ctrl'].value or []
             ]) or '- none -',
-            field_hidden_dn=app.form.hiddenFieldHTML('dn', dn, dn),
-            field_hidden_filterstr=app.form.hiddenFieldHTML('filterstr', bulkmod_filter, bulkmod_filter),
-            field_hidden_scope=app.form.hiddenFieldHTML('scope', str(scope), str(ldap0.ldapurl.SEARCH_SCOPE_STR[scope])),
-            field_bulkmod_newsuperior=app.form.hiddenFieldHTML(
+            field_hidden_dn=app.form.hidden_field_html('dn', dn, dn),
+            field_hidden_filterstr=app.form.hidden_field_html('filterstr', bulkmod_filter, bulkmod_filter),
+            field_hidden_scope=app.form.hidden_field_html('scope', str(scope), str(ldap0.ldapurl.SEARCH_SCOPE_STR[scope])),
+            field_bulkmod_newsuperior=app.form.hidden_field_html(
                 'bulkmod_newsuperior',
                 bulkmod_newsuperior,
                 bulkmod_newsuperior
@@ -310,12 +300,12 @@ def bulkmod_confirmation_form(
             num_entries=num_entries,
             num_referrals=num_referrals,
             text_ldifchangerecord=bulk_mod_list_ldif,
-            hidden_fields=app.form.hiddenInputHTML(ignoreFieldNames=[
+            hidden_fields=app.form.hidden_input_html(ignored_fields=[
                 'dn', 'scope', 'filterstr', 'bulkmod_submit', 'bulkmod_newsuperior',
             ]),
         )
     )
-    web2ldap.app.gui.footer(app)
+    footer(app)
     # end of bulkmod_confirmation_form()
 
 
@@ -345,7 +335,7 @@ def w2l_bulkmod(app):
     bulkmod_ctrl_oids = app.form.getInputValue('bulkmod_ctrl', [])
 
     if not len(bulkmod_at) == len(bulkmod_op) == len(bulkmod_av):
-        raise web2ldap.app.core.ErrorExit(u'Invalid bulk modification input.')
+        raise ErrorExit(u'Invalid bulk modification input.')
 
     bulk_mod_list, input_errors = input_modlist(
         app,
@@ -357,7 +347,7 @@ def w2l_bulkmod(app):
         app.simple_message(
             'Canceled bulk modification.',
             '<p class="SuccessMessage">Canceled bulk modification.</p>',
-            main_menu_list=web2ldap.app.gui.main_menu(app),
+            main_menu_list=main_menu(app),
         )
 
     elif not (bulk_mod_list or bulkmod_newsuperior) or \
@@ -390,7 +380,7 @@ def w2l_bulkmod(app):
         bulkmod_ctrl_oids = app.form.getInputValue('bulkmod_ctrl', [])
         conn_server_ctrls = {
             server_ctrl.controlType
-            for server_ctrl in app.ls.l._req_ctrls['**all**']+app.ls.l._req_ctrls['**write**']+app.ls.l._req_ctrls['modify']
+            for server_ctrl in app.ls.l.req_ctrls['**all**']+app.ls.l.req_ctrls['**write**']+app.ls.l.req_ctrls['modify']
         }
         bulkmod_server_ctrls = list({
             ldap0.controls.LDAPControl(ctrl_oid, True, None)
@@ -429,7 +419,7 @@ def w2l_bulkmod(app):
                     except ldap0.LDAPError as e:
                         ldap_error_html.append(
                             '<dt>%s</dt><dd>%s</dd>' % (
-                                app.form.utf2display(rdat.dn_s),
+                                app.form.s2d(rdat.dn_s),
                                 app.ldap_error_msg(e),
                             )
                         )
@@ -460,16 +450,16 @@ def w2l_bulkmod(app):
                     except ldap0.LDAPError as e:
                         ldap_error_html.append(
                             '<dt>%s</dt><dd>%s</dd>' % (
-                                app.form.utf2display(rdat.dn_s),
-                                app.form.utf2display(str(e)),
+                                app.form.s2d(rdat.dn_s),
+                                app.form.s2d(str(e)),
                             )
                         )
                     else:
                         result_ldif_html.append(
                             '<p>%s %s beneath %s</p>' % (
                                 {False:'Moved', True:'Copied'}[bulkmod_cp],
-                                app.form.utf2display(rdat.dn_s),
-                                app.form.utf2display(bulkmod_newsuperior),
+                                app.form.s2d(rdat.dn_s),
+                                app.form.s2d(bulkmod_newsuperior),
                             )
                         )
 
@@ -527,15 +517,15 @@ def w2l_bulkmod(app):
                 ldap0.ldapurl.SEARCH_SCOPE_STR[scope],
                 end_time_stamp-begin_time_stamp,
                 app.begin_form('bulkmod', 'POST'),
-                app.form.hiddenInputHTML(ignoreFieldNames=['bulkmod_submit']),
+                app.form.hidden_input_html(ignored_fields=['bulkmod_submit']),
                 error_messages,
                 change_records,
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
+            main_menu_list=main_menu(app),
         )
 
     else:
 
-        raise web2ldap.app.core.ErrorExit(u'Invalid bulk modification form data.')
+        raise ErrorExit(u'Invalid bulk modification form data.')
 
     # end of w2l_bulkmod()
