@@ -19,11 +19,13 @@ import ldap0.filter
 
 import web2ldapcnf
 
-import web2ldap.utctime
-import web2ldap.ldaputil
-import web2ldap.app.core
-import web2ldap.app.gui
-from web2ldap.app.session import session_store
+from ..utctime import strftimeiso8601
+from .gui import (
+    footer,
+    main_menu,
+    top_section,
+)
+from .session import session_store
 
 CONNINFO_LDAP_TEMPLATE = """
 <h1>LDAP Connection Parameters</h1>
@@ -146,9 +148,9 @@ def w2l_conninfo(app):
     config_dn_list = []
 
     monitored_info = None
-    if 'monitorContext' in app.ls.rootDSE:
+    if 'monitorContext' in app.ls.root_dse:
         # seems to be OpenLDAP's back-monitor
-        monitor_context_dn = app.ls.rootDSE['monitorContext'][0].decode(app.ls.charset)
+        monitor_context_dn = app.ls.root_dse['monitorContext'][0].decode(app.ls.charset)
         context_menu_list.append(
             app.anchor(
                 'read', 'Monitor',
@@ -180,37 +182,37 @@ def w2l_conninfo(app):
     else:
         config_dn_list.append(('CN=MONITOR', 'Monitor'))
 
-    if 'changelog' in app.ls.rootDSE:
+    if 'changelog' in app.ls.root_dse:
         context_menu_list.append(
             app.anchor(
                 'read', 'Change log',
-                [('dn', app.ls.rootDSE['changelog'][0])],
+                [('dn', app.ls.root_dse['changelog'][0])],
             )
         )
     else:
         config_dn_list.append(('cn=changelog', 'Change log'))
 
-    if 'configContext' in app.ls.rootDSE:
+    if 'configContext' in app.ls.root_dse:
         context_menu_list.append(
             app.anchor(
                 'read', 'Config',
-                [('dn', app.ls.rootDSE['configContext'][0])],
+                [('dn', app.ls.root_dse['configContext'][0])],
             )
         )
-    elif 'configurationNamingContext' in app.ls.rootDSE:
+    elif 'configurationNamingContext' in app.ls.root_dse:
         # MS AD
         context_menu_list.append(
             app.anchor(
                 'read', 'AD Configuration',
-                [('dn', app.ls.rootDSE['configurationNamingContext'][0])]
+                [('dn', app.ls.root_dse['configurationNamingContext'][0])]
             )
         )
-    elif 'ibm-configurationnamingcontext' in app.ls.rootDSE:
+    elif 'ibm-configurationnamingcontext' in app.ls.root_dse:
         # IBM Directory Server
         context_menu_list.append(
             app.anchor(
                 'read', 'IBM DS Configuration',
-                [('dn', app.ls.rootDSE['ibm-configurationnamingcontext'][0])]
+                [('dn', app.ls.root_dse['ibm-configurationnamingcontext'][0])]
             )
         )
     else:
@@ -269,25 +271,25 @@ def w2l_conninfo(app):
                 )
             )
 
-    if 'schemaNamingContext' in app.ls.rootDSE:
+    if 'schemaNamingContext' in app.ls.root_dse:
         # MS AD schema configuration
         context_menu_list.append(
             app.anchor(
                 'read', 'AD Schema Configuration',
-                [('dn', app.ls.rootDSE['schemaNamingContext'][0])],
+                [('dn', app.ls.root_dse['schemaNamingContext'][0])],
             )
         )
 
-    web2ldap.app.gui.top_section(
+    top_section(
         app,
         'Connection Info',
-        web2ldap.app.gui.main_menu(app),
+        main_menu(app),
         context_menu_list=context_menu_list
     )
 
     if app.ls.who:
         who_html = '%s<br>( %s )' % (
-            app.display_dn(app.ls.who, commandbutton=False),
+            app.display_dn(app.ls.who, links=False),
             web2ldapcnf.command_link_separator.join((
                 app.anchor(
                     'read', 'Read',
@@ -305,7 +307,7 @@ def w2l_conninfo(app):
         who_html = 'anonymous'
 
     try:
-        whoami_result = '%s' % (app.form.utf2display(repr(app.ls.l.whoami_s())))
+        whoami_result = '%s' % (app.form.s2d(repr(app.ls.l.whoami_s())))
     except ldap0.LDAPError as ldap_err:
         whoami_result = '<strong>Failed:</strong> %s' % (app.ldap_error_msg(ldap_err))
 
@@ -313,8 +315,8 @@ def w2l_conninfo(app):
         sasl_mech = u'SASL/%s' % (app.ls.sasl_mech)
         sasl_auth_info = '<table>%s</table>' % '\n'.join([
             '<tr><td>%s</td><td>%s</td></tr>' % (
-                app.form.utf2display(ldap0.OPT_NAMES.get(key, str(key))),
-                app.form.utf2display(repr(val))
+                app.form.s2d(ldap0.OPT_NAMES.get(key, str(key))),
+                app.form.s2d(repr(val))
             )
             for key, val in app.ls.sasl_auth.cb_value_dict.items()
             if val
@@ -342,29 +344,29 @@ def w2l_conninfo(app):
             app.ls.uri,
             protocol_version,
             app.ls.charset.upper(),
-            {False:'not secured', True:'secured'}[app.ls.secureConn],
-            web2ldap.utctime.strftimeiso8601(time.gmtime(app.ls.connStartTime)),
-            time.time()-app.ls.connStartTime,
+            {False:'not secured', True:'secured'}[app.ls.secure_conn],
+            strftimeiso8601(time.gmtime(app.ls.conn_start)),
+            time.time()-app.ls.conn_start,
             app.ls.l._reconnects_done,
-            app.form.utf2display(
+            app.form.s2d(
                 app.ls.vendorName
                 or monitored_info
                 or {True:'OpenLDAP', False:''}[app.ls.is_openldap]
                 or 'unknown'
             ),
-            app.form.utf2display(app.ls.vendorVersion or ''),
+            app.form.s2d(app.ls.vendorVersion or ''),
             who_html,
             whoami_result,
-            app.form.utf2display(sasl_mech),
+            app.form.s2d(sasl_mech),
             sasl_auth_info,
             sasl_user_name,
-            app.form.utf2display(sasl_ssf),
-            app.form.utf2display(app.dn or u'- World -'),
-            app.form.utf2display(app.parent_dn if app.parent_dn is not None else u''),
-            app.form.utf2display(str(app.naming_context)),
+            app.form.s2d(sasl_ssf),
+            app.form.s2d(app.dn or u'- World -'),
+            app.form.s2d(app.parent_dn if app.parent_dn is not None else u''),
+            app.form.s2d(str(app.naming_context)),
             min(len(app.ls.l.last_search_bases), app.ls.l.last_search_bases.maxlen),
             '<br>'.join([
-                app.display_dn(search_base, commandbutton=True)
+                app.display_dn(search_base, links=True)
                 for search_base in app.ls.l.last_search_bases
             ])
         )
@@ -387,22 +389,22 @@ def w2l_conninfo(app):
     cross_check_vars = session_store().sessiondict['__session_checkvars__'+app.sid].items()
     cross_check_vars_html = '\n'.join([
         '<tr><td>%s</td><td>%s</td></tr>' % (
-            app.form.utf2display(k),
-            app.form.utf2display(v),
+            app.form.s2d(k),
+            app.form.s2d(v),
         )
         for k, v in sorted(cross_check_vars)
     ])
 
     app.outf.write(
         CONNINFO_HTTP_TEMPLATE % (
-            app.ls.onBehalf,
-            app.form.utf2display(str(app.env.get('REMOTE_ADDR', ''))),
-            app.form.utf2display(str(app.env.get('REMOTE_PORT', ''))),
+            app.ls.on_behalf,
+            app.form.s2d(str(app.env.get('REMOTE_ADDR', ''))),
+            app.form.s2d(str(app.env.get('REMOTE_PORT', ''))),
             app.env.get('SERVER_SIGNATURE', ''),
-            app.form.utf2display(str(', '.join(app.form.accept_language))),
-            app.form.utf2display(app.form.accept_charset.upper()),
+            app.form.s2d(str(', '.join(app.form.accept_language))),
+            app.form.s2d(app.form.accept_charset.upper()),
             cross_check_vars_html,
-            app.form.utf2display(app.env.get('HTTP_USER_AGENT', '')),
+            app.form.s2d(app.env.get('HTTP_USER_AGENT', '')),
         )
     )
-    web2ldap.app.gui.footer(app)
+    footer(app)
