@@ -17,14 +17,11 @@ import time
 import ldap0
 from ldap0.res import SearchResultEntry
 
-import web2ldap.web.forms
-import web2ldap.ldaputil.asynch
-import web2ldap.ldapsession
-import web2ldap.ldaputil
-import web2ldap.app.core
-import web2ldap.app.cnf
-import web2ldap.app.gui
-from web2ldap.log import logger
+from ..web.forms import Select as SelectField
+from ..ldaputil.asynch import AsyncSearchHandler
+from ..ldapsession import CONTROL_TREEDELETE, LDAPLimitErrors
+from .gui import context_menu_single_entry, footer, main_menu, top_section
+from ..log import logger
 
 
 DELETE_SUBTREE_FORM_TMPL = """
@@ -107,11 +104,11 @@ DELETE_ENTRIES_SUCCESS_TMPL = """
 """
 
 
-class DeleteLeafs(web2ldap.ldaputil.asynch.AsyncSearchHandler):
+class DeleteLeafs(AsyncSearchHandler):
     """
     Class for deleting entries which are results of a search.
 
-    DNs of Non-leaf entries are collected in DeleteLeafs.nonLeafEntries.
+    DNs of Non-leaf entries are collected in DeleteLeafs.non_leaf_entries.
     """
     _entryResultTypes = {
         ldap0.RES_SEARCH_ENTRY,
@@ -119,18 +116,18 @@ class DeleteLeafs(web2ldap.ldaputil.asynch.AsyncSearchHandler):
     }
 
     def __init__(self, l, tree_delete_ctrl, delete_server_ctrls):
-        web2ldap.ldaputil.asynch.AsyncSearchHandler.__init__(self, l)
+        AsyncSearchHandler.__init__(self, l)
         self.req_ctrls = delete_server_ctrls
         self.tree_delete_ctrl = tree_delete_ctrl
 
     def start_search(self, searchRoot, searchScope, filterStr):
         if searchScope == ldap0.SCOPE_BASE:
             raise ValueError('Parameter searchScope must not be ldap0.SCOPE_BASE.')
-        self.nonLeafEntries = []
-        self.nonDeletableEntries = []
-        self.deletedEntries = 0
-        self.noSuchObjectCounter = 0
-        web2ldap.ldaputil.asynch.AsyncSearchHandler.start_search(
+        self.non_leaf_entries = []
+        self.non_deletable_entries = []
+        self.deleted_entries = 0
+        self.no_such_object_count = 0
+        AsyncSearchHandler.start_search(
             self,
             searchRoot,
             searchScope,
@@ -150,12 +147,12 @@ class DeleteLeafs(web2ldap.ldaputil.asynch.AsyncSearchHandler):
             return
         dn, entry = resultItem.dn_s, resultItem.entry_s
         try:
-            hasSubordinates = entry['hasSubordinates'][0].upper() == 'TRUE'
+            has_subordinates = entry['hasSubordinates'][0].upper() == 'TRUE'
         except KeyError:
-            # hasSubordinates not available => look at numeric subordinate counters
-            hasSubordinates = None
+            # attribute hasSubordinates not available => look at numeric subordinate counters
+            has_subordinates = None
             try:
-                subordinateCount = int(
+                subordinate_count = int(
                     entry.get(
                         'subordinateCount',
                         entry.get(
@@ -165,15 +162,15 @@ class DeleteLeafs(web2ldap.ldaputil.asynch.AsyncSearchHandler):
                                 entry['msDS-Approx-Immed-Subordinates'])))[0]
                 )
             except KeyError:
-                subordinateCount = None
+                subordinate_count = None
         else:
-            subordinateCount = None
+            subordinate_count = None
         if (
                 not self.tree_delete_ctrl and
-                (hasSubordinates or (subordinateCount or 0) > 0)
+                (has_subordinates or (subordinate_count or 0) > 0)
             ):
             logger.debug('Skipping deletion of non-leaf entry %r', dn)
-            self.nonLeafEntries.append(dn)
+            self.non_leaf_entries.append(dn)
             return
         logger.debug('Deleting entry %r', dn)
         try:
@@ -181,22 +178,22 @@ class DeleteLeafs(web2ldap.ldaputil.asynch.AsyncSearchHandler):
         except ldap0.NO_SUCH_OBJECT:
             # Don't do anything if the entry is already gone except counting
             # these sub-optimal cases
-            self.noSuchObjectCounter += 1
+            self.no_such_object_count += 1
         except ldap0.INSUFFICIENT_ACCESS:
-            self.nonDeletableEntries.append(dn)
+            self.non_deletable_entries.append(dn)
         except ldap0.NOT_ALLOWED_ON_NONLEAF:
-            if hasSubordinates is None and subordinateCount is None:
-                self.nonLeafEntries.append(dn)
+            if has_subordinates is None and subordinate_count is None:
+                self.non_leaf_entries.append(dn)
             # Next statements are kind of a safety net and should never be executed
             else:
                 raise ValueError(
-                    'Non-leaf entry %r has hasSubordinates %r and subordinateCount %r' % (
-                        dn, hasSubordinates, subordinateCount,
+                    'Non-leaf entry %r has has_subordinates = %r and subordinate_count = %r' % (
+                        dn, has_subordinates, subordinate_count,
                     )
                 )
         else:
             # The entry was correctly deleted
-            self.deletedEntries += 1
+            self.deleted_entries += 1
         # end of _process_result()
 
 
@@ -214,7 +211,6 @@ def delete_entries(
     """
     start_time = time.time()
     end_time = start_time + delete_timelimit
-    delete_filter = delete_filter or '(objectClass=*)'
     if scope == ldap0.SCOPE_SUBTREE and tree_delete_control:
         # Try to directly delete the whole subtree with the tree delete control
         app.ls.l.delete_s(dn, req_ctrls=delete_server_ctrls)
@@ -230,13 +226,13 @@ def delete_entries(
         except ldap0.NO_SUCH_OBJECT:
             break
         except (ldap0.SIZELIMIT_EXCEEDED, ldap0.ADMINLIMIT_EXCEEDED):
-            deleted_entries_count += leafs_deleter.deletedEntries
-            non_leaf_entries.update(leafs_deleter.nonLeafEntries)
-            non_deletable_entries.update(leafs_deleter.nonDeletableEntries)
+            deleted_entries_count += leafs_deleter.deleted_entries
+            non_leaf_entries.update(leafs_deleter.non_leaf_entries)
+            non_deletable_entries.update(leafs_deleter.non_deletable_entries)
         else:
-            deleted_entries_count += leafs_deleter.deletedEntries
-            non_leaf_entries.update(leafs_deleter.nonLeafEntries)
-            non_deletable_entries.update(leafs_deleter.nonDeletableEntries)
+            deleted_entries_count += leafs_deleter.deleted_entries
+            non_leaf_entries.update(leafs_deleter.non_leaf_entries)
+            non_deletable_entries.update(leafs_deleter.non_deletable_entries)
             break
     else:
         non_deletable_entries.update(non_leaf_entries)
@@ -248,15 +244,15 @@ def delete_entries(
             leafs_deleter.start_search(dn, ldap0.SCOPE_SUBTREE, filterStr=delete_filter)
             leafs_deleter.process_results()
         except (ldap0.SIZELIMIT_EXCEEDED, ldap0.ADMINLIMIT_EXCEEDED):
-            deleted_entries_count += leafs_deleter.deletedEntries
+            deleted_entries_count += leafs_deleter.deleted_entries
             non_leaf_entries.add(dn)
-            non_leaf_entries.update(leafs_deleter.nonLeafEntries)
+            non_leaf_entries.update(leafs_deleter.non_leaf_entries)
         else:
-            deleted_entries_count += leafs_deleter.deletedEntries
-            if leafs_deleter.deletedEntries == 0:
+            deleted_entries_count += leafs_deleter.deleted_entries
+            if leafs_deleter.deleted_entries == 0:
                 non_deletable_entries.add(dn)
                 continue
-            non_leaf_entries.update(leafs_deleter.nonLeafEntries)
+            non_leaf_entries.update(leafs_deleter.non_leaf_entries)
         if time.time() > end_time:
             non_deletable_entries.update(non_leaf_entries)
             break
@@ -273,7 +269,7 @@ def del_singleentry_form(app):
 
 
 def del_subtree_form(app, scope):
-    delete_scope_field = web2ldap.web.forms.Select(
+    delete_scope_field = SelectField(
         'scope', 'Scope of delete operation', 1,
         options=(
             (str(ldap0.SCOPE_BASE), 'Only this entry'),
@@ -282,25 +278,25 @@ def del_subtree_form(app, scope):
         ),
         default=str(scope),
     )
-    hasSubordinates, numSubordinates, numAllSubordinates = app.ls.get_sub_ordinates(app.dn)
-    if not hasSubordinates:
+    has_subordinates, num_subordinates, num_all_subordinates = app.ls.get_sub_ordinates(app.dn)
+    if not has_subordinates:
         return del_singleentry_form(app)
-    if numSubordinates:
-        numSubordinates_html = '<p>Number of direct subordinates: %d</p>' % (numSubordinates)
+    if num_subordinates:
+        num_subordinates_html = '<p>Number of direct subordinates: %d</p>' % (num_subordinates)
     else:
-        numSubordinates_html = ''
-    if numAllSubordinates:
-        numAllSubordinates_html = '<p>Total number of subordinates: %d</p>' % (numAllSubordinates)
+        num_subordinates_html = ''
+    if num_all_subordinates:
+        num_all_subordinates_html = '<p>Total number of subordinates: %d</p>' % (num_all_subordinates)
     else:
-        numAllSubordinates_html = ''
+        num_all_subordinates_html = ''
     return DELETE_SUBTREE_FORM_TMPL.format(
         text_dn=app.display_dn(app.dn),
-        text_num_sub_ordinates=numSubordinates_html,
-        text_num_all_sub_ordinates=numAllSubordinates_html,
+        text_num_sub_ordinates=num_subordinates_html,
+        text_num_all_sub_ordinates=num_all_subordinates_html,
         field_delete_scope=delete_scope_field.input_html(),
-        value_delete_ctrl_oid=web2ldap.ldapsession.CONTROL_TREEDELETE,
+        value_delete_ctrl_oid=CONTROL_TREEDELETE,
         value_delete_ctrl_checked=' checked'*int(
-            web2ldap.ldapsession.CONTROL_TREEDELETE in app.ls.supportedControl and \
+            CONTROL_TREEDELETE in app.ls.supportedControl and \
             not app.ls.is_openldap
         ),
     )
@@ -314,9 +310,9 @@ def del_attr_form(app, entry, delete_attr):
         app.display_dn(app.dn),
         '\n'.join([
             '<input type="checkbox" name="delete_attr" value="%s"%s>%s<br>' % (
-                app.form.utf2display(attr_type, sp_entity='  '),
+                app.form.s2d(attr_type, sp_entity='  '),
                 ' checked'*(attr_type in entry),
-                app.form.utf2display(attr_type),
+                app.form.s2d(attr_type),
             )
             for attr_type in delete_attr
         ]),
@@ -331,7 +327,7 @@ def del_search_form(app, scope, delete_filter):
             delete_filter,
             sizelimit=1000,
         )
-    except web2ldap.ldapsession.LDAPLimitErrors:
+    except LDAPLimitErrors:
         num_entries, num_referrals = ('unknown', 'unknown')
     else:
         if num_entries is None:
@@ -347,8 +343,8 @@ def del_search_form(app, scope, delete_filter):
         text_scope=ldap0.ldapurl.SEARCH_SCOPE_STR[scope],
         num_entries=num_entries,
         num_referrals=num_referrals,
-        value_delete_filter=app.form.utf2display(delete_filter),
-        value_delete_scope=app.form.utf2display(str(scope)),
+        value_delete_filter=app.form.s2d(delete_filter),
+        value_delete_scope=app.form.s2d(str(scope)),
     )
 
 
@@ -362,17 +358,25 @@ def w2l_delete(app):
             for a in app.ldap_url.attrs or []
         ]
     )
-    delete_filter = app.form.getInputValue('filterstr', [app.ldap_url.filterstr])[0]
+    delete_filter = app.form.getInputValue(
+        'filterstr',
+        [app.ldap_url.filterstr or '(objectClass=*)']
+    )[0]
     delete_attr.sort()
     if delete_attr:
         scope = ldap0.SCOPE_BASE
     else:
-        scope = int(app.form.getInputValue('scope', [str(app.ldap_url.scope or ldap0.SCOPE_BASE)])[0])
+        scope = int(
+            app.form.getInputValue(
+                'scope',
+                [str(app.ldap_url.scope or ldap0.SCOPE_BASE)],
+            )[0]
+        )
 
     # Generate a list of requested LDAPv3 extended controls to be sent along
     # with a modify or delete request
     delete_ctrl_oids = app.form.getInputValue('delete_ctrl', [])
-    delete_ctrl_tree_delete = web2ldap.ldapsession.CONTROL_TREEDELETE in delete_ctrl_oids
+    delete_ctrl_tree_delete = CONTROL_TREEDELETE in delete_ctrl_oids
 
     if delete_confirm is None:
         # First show delete confirmation and delete mode select form
@@ -386,41 +390,43 @@ def w2l_delete(app):
         entry = ldap0.schema.models.Entry(app.schema, app.dn, ldap_res.entry_as)
         if delete_attr:
             inner_form = del_attr_form(app, entry, delete_attr)
-        elif delete_filter:
+        elif delete_confirm == 'yes':
             inner_form = del_search_form(app, scope, delete_filter)
         else:
             inner_form = del_subtree_form(app, scope)
         # Output confirmation form
-        web2ldap.app.gui.top_section(
+        top_section(
             app,
             'Delete entry?',
-            web2ldap.app.gui.main_menu(app),
+            main_menu(app),
             context_menu_list=[],
         )
         app.outf.write(
             DELETE_FORM_TEMPLATE.format(
                 form_begin=app.begin_form('delete', 'POST'),
                 inner_form=inner_form,
-                field_delete_ctrl=app.form.field['delete_ctrl'].input_html(default=delete_ctrl_oids),
-                field_hidden_dn=app.form.hiddenFieldHTML('dn', app.dn, ''),
+                field_delete_ctrl=app.form.field['delete_ctrl'].input_html(
+                    default=delete_ctrl_oids
+                ),
+                field_hidden_dn=app.form.hidden_field_html('dn', app.dn, ''),
             )
         )
-        web2ldap.app.gui.footer(app)
+        footer(app)
         return
 
     if delete_confirm != 'yes':
         app.simple_message(
             'Canceled delete',
             '<p class="SuccessMessage">Canceled delete.</p>',
-            main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
+            main_menu_list=main_menu(app),
+            context_menu_list=context_menu_single_entry(app)
         )
         return
 
     # determine extended controls to be sent with delete operation
     conn_server_ctrls = {
         server_ctrl.controlType
-        for server_ctrl in app.ls.l._req_ctrls['**all**']+app.ls.l._req_ctrls['**write**']+app.ls.l._req_ctrls['delete']
+        for server_ctrl in app.ls.l.req_ctrls['**all**']+app.ls.l.req_ctrls['**write**']+app.ls.l.req_ctrls['delete']
     }
     delete_server_ctrls = [
         ldap0.controls.LDAPControl(ctrl_oid, True, None)
@@ -458,7 +464,7 @@ def w2l_delete(app):
                 end_time_stamp-begin_time_stamp,
                 len(non_deletable_entries),
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
+            main_menu_list=main_menu(app),
             context_menu_list=[],
         )
 
@@ -485,12 +491,12 @@ def w2l_delete(app):
             """ % (
                 app.display_dn(app.dn),
                 '</li>\n<li>'.join([
-                    app.form.hiddenFieldHTML('delete_attr', attr_type, attr_type)
+                    app.form.hidden_field_html('delete_attr', attr_type, attr_type)
                     for attr_type in delete_attr
                 ]),
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
+            main_menu_list=main_menu(app),
+            context_menu_list=context_menu_single_entry(app)
         )
 
     elif scope == ldap0.SCOPE_BASE:
@@ -506,6 +512,6 @@ def w2l_delete(app):
             '<p class="SuccessMessage">Deleted entry: %s</p>' % (
                 app.display_dn(old_dn)
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
+            main_menu_list=main_menu(app),
             context_menu_list=[],
         )
