@@ -15,8 +15,8 @@ https://www.apache.org/licenses/LICENSE-2.0
 import ldap0
 from ldap0.dn import DNObj
 
-import web2ldap.app.gui
-from web2ldap.app.gui import dn_anchor_hash
+from ..ldaputil import has_subordinates
+from .gui import dn_anchor_hash, main_menu
 
 
 # All attributes to be read for nodes
@@ -38,33 +38,11 @@ DIT_ATTR_LIST = [
 ]
 
 
-def decode_dict(d, charset):
-    r = {}
-    for k, v in d.items():
-        r[k] = [
-            value.decode(charset)
-            for value in v
-        ]
-    return r
-
-
 def dit_html(app, anchor_dn, dit_dict, entry_dict, max_levels):
     """
     Outputs HTML representation of a directory information tree (DIT)
     """
 
-    def meta_results(d):
-        """
-        Side effect! This removes meta result data from d!
-        """
-        try:
-            size_limit = d['_sizelimit_']
-        except KeyError:
-            size_limit = False
-        else:
-            del d['_sizelimit_']
-        return size_limit
-
     assert isinstance(anchor_dn, DNObj), ValueError(
         'Expected anchor_dn to be DNObj, got %r' % (anchor_dn,),
     )
@@ -72,14 +50,18 @@ def dit_html(app, anchor_dn, dit_dict, entry_dict, max_levels):
     # Start node's HTML
     res = ['<dl>']
 
-    for dn, d in dit_dict.items():
+    for dn, ddat in dit_dict.items():
 
         assert isinstance(dn, DNObj), ValueError(
             'Expected dn to be DNObj, got %r' % (dn,),
         )
 
-        # Handle special dict items
-        size_limit = meta_results(d)
+        try:
+            size_limit = ddat['_sizelimit_']
+        except KeyError:
+            size_limit = False
+        else:
+            del ddat['_sizelimit_']
 
         # Generate anchor for this node
         if dn:
@@ -103,24 +85,10 @@ def dit_html(app, anchor_dn, dit_dict, entry_dict, max_levels):
         else:
             partial_str = ''
 
-        # Try to determine from entry's attributes if there are subordinates
-        hasSubordinates = node_entry.get('hasSubordinates', ['TRUE'])[0].upper() == 'TRUE'
         try:
-            subordinateCountFlag = int(
-                node_entry.get(
-                    'subordinateCount',
-                    node_entry.get(
-                        'numAllSubordinates',
-                        node_entry.get('msDS-Approx-Immed-Subordinates', ['1'])))[0]
-            )
-        except ValueError:
-            subordinateCountFlag = 1
-        has_subordinates = hasSubordinates and subordinateCountFlag
-
-        try:
-            display_name_list = [app.form.utf2display(node_entry['displayName'][0]), partial_str]
+            display_name_list = [app.form.s2d(node_entry['displayName'][0]), partial_str]
         except KeyError:
-            display_name_list = [app.form.utf2display(str(rdn)), partial_str]
+            display_name_list = [app.form.s2d(str(rdn)), partial_str]
         display_name = ''.join(display_name_list)
 
         title_msg = u'\r\n'.join(
@@ -130,8 +98,8 @@ def dit_html(app, anchor_dn, dit_dict, entry_dict, max_levels):
 
         dn_anchor_id = dn_anchor_hash(dn)
 
-        res.append('<dt id="%s">' % (app.form.utf2display(dn_anchor_id)))
-        if has_subordinates:
+        res.append('<dt id="%s">' % (app.form.s2d(dn_anchor_id)))
+        if has_subordinates(node_entry, default=True):
             if dn == anchor_dn:
                 link_text = '&lsaquo;&lsaquo;'
                 next_dn = dn.parent()
@@ -151,7 +119,7 @@ def dit_html(app, anchor_dn, dit_dict, entry_dict, max_levels):
             # FIX ME! Better solution in pure CSS?
             res.append('&nbsp;&nbsp;&nbsp;&nbsp;')
         res.append('<span title="%s">%s</span>' % (
-            app.form.utf2display(title_msg),
+            app.form.s2d(title_msg),
             display_name
         ))
         res.append(
@@ -165,8 +133,8 @@ def dit_html(app, anchor_dn, dit_dict, entry_dict, max_levels):
 
         # Subordinate nodes' HTML
         res.append('<dd>')
-        if max_levels and d:
-            res.extend(dit_html(app, anchor_dn, d, entry_dict, max_levels-1))
+        if max_levels and ddat:
+            res.extend(dit_html(app, anchor_dn, ddat, entry_dict, max_levels-1))
         res.append('</dd>')
 
     # Finish node's HTML
@@ -241,7 +209,7 @@ def w2l_dit(app):
                             (('dn', str(naming_context)),),
                             title=u'Display tree beneath %s' % (naming_context,),
                         ),
-                        app.form.utf2display(str(naming_context)),
+                        app.form.s2d(str(naming_context)),
                     )
                 )
 
@@ -251,7 +219,7 @@ def w2l_dit(app):
         <h1>Directory Information Tree</h1>
         <div id="DIT">%s</div>
         """ % ('\n'.join(outf_lines)),
-        main_menu_list=web2ldap.app.gui.main_menu(app),
+        main_menu_list=main_menu(app),
         context_menu_list=[]
     )
 
