@@ -20,33 +20,33 @@ from ldap0.pw import random_string
 
 import web2ldapcnf
 
-from web2ldap.web import HTML_ESCAPE_MAP
-import web2ldap.ldaputil
-from web2ldap.ldaputil.oidreg import OID_REG
-import web2ldap.ldapsession
-import web2ldap.ldaputil.passwd
-import web2ldap.app.core
-import web2ldap.app.gui
-import web2ldap.app.searchform
-import web2ldap.app.params
-import web2ldap.app.session
-from web2ldap.ldapsession import AVAILABLE_BOOLEAN_CONTROLS
-import web2ldap.web.forms
-from web2ldap.web.forms import \
-    Input, \
-    Field, \
-    Textarea, \
-    BytesInput, \
-    Select, \
-    Checkbox, \
-    Form, \
-    InvalidValueFormat
+from ..ldapsession import AVAILABLE_BOOLEAN_CONTROLS, CONTROL_TREEDELETE
+from ..web import HTML_ESCAPE_MAP
+from ..ldaputil import RDN_PATTERN, ATTR_TYPE_PATTERN
+from ..ldaputil.oidreg import OID_REG
+from ..ldaputil.passwd import AVAIL_USERPASSWORD_SCHEMES
+from .gui import HIDDEN_FIELD
+from .searchform import (
+    SEARCH_OPTIONS,
+    SEARCH_SCOPE_OPTIONS,
+    SEARCH_SCOPE_STR_SUBTREE,
+)
+from ..web.forms import (
+    Input,
+    Field,
+    Textarea,
+    BytesInput,
+    Select,
+    Checkbox,
+    Form,
+    InvalidValueFormat,
+)
+from ..web.session import SESSION_ID_CHARS, SESSION_ID_LENGTH, SESSION_ID_REGEX
 
 
 # Work around https://bugs.python.org/issue29613
 http.cookies.Morsel._reserved['samesite'] = 'SameSite'
 
-
 class Web2LDAPForm(Form):
     """
     Form sub-class for a web2ldap use-case
@@ -68,8 +68,8 @@ class Web2LDAPForm(Form):
             self.cookies = http.cookies.SimpleCookie()
         self.next_cookie = http.cookies.SimpleCookie()
 
-    def utf2display(
-            self,
+    @staticmethod
+    def s2d(
             value,
             tab_identiation='',
             sp_entity='&nbsp;&nbsp;',
@@ -107,7 +107,7 @@ class Web2LDAPForm(Form):
     def set_cookie(self, name_suffix):
         # Generate a randomized key and value
         cookie_key = random_string(
-            alphabet=web2ldap.web.session.SESSION_ID_CHARS,
+            alphabet=SESSION_ID_CHARS,
             length=self.cookie_length,
         )
         cookie_name = ''.join((self.cookie_name_prefix, name_suffix))
@@ -129,9 +129,9 @@ class Web2LDAPForm(Form):
             Input(
                 'delsid',
                 'Old SID to be deleted',
-                web2ldap.web.session.SESSION_ID_LENGTH,
+                SESSION_ID_LENGTH,
                 1,
-                web2ldap.web.session.SESSION_ID_REGEX,
+                SESSION_ID_REGEX,
             ),
             Input('who', 'Bind DN/AuthcID', 1000, 1, '.*', size=40),
             Input('cred', 'with Password', 200, 1, '.*', size=15),
@@ -149,14 +149,14 @@ class Web2LDAPForm(Form):
             Input(
                 'host', 'Host:Port',
                 255, 1,
-                '(%s|[a-zA-Z0-9/._-]+)' % web2ldap.app.gui.host_pattern,
-                size=30,
+                '[a-zA-Z0-9_.:\\[\\]-]+',
+                size=70,
             ),
             DistinguishedNameInput('dn', 'Distinguished Name'),
             Select(
                 'scope', 'Scope', 1,
-                options=web2ldap.app.searchform.SEARCH_SCOPE_OPTIONS,
-                default=web2ldap.app.searchform.SEARCH_SCOPE_STR_SUBTREE,
+                options=SEARCH_SCOPE_OPTIONS,
+                default=SEARCH_SCOPE_STR_SUBTREE,
             ),
             DistinguishedNameInput('login_search_root', 'Login search root'),
             Select(
@@ -206,32 +206,29 @@ class Web2LDAPForm(Form):
               self.accept_charset
           )
 
-    def hiddenFieldHTML(self, name, value, desc):
-        return web2ldap.app.gui.HIDDEN_FIELD % (
+    def hidden_field_html(self, name, value, desc):
+        return HIDDEN_FIELD % (
             name,
-            self.utf2display(value, sp_entity='  '),
-            self.utf2display(desc, sp_entity='&nbsp;&nbsp;'),
+            self.s2d(value, sp_entity='  '),
+            self.s2d(desc, sp_entity='&nbsp;&nbsp;'),
         )
 
-    def hiddenInputHTML(self, ignoreFieldNames=None):
+    def hidden_input_html(self, ignored_fields=None):
         """
         Return all input parameters as hidden fields in one HTML string.
 
-        ignoreFieldNames
+        ignored_fields
             Names of parameters to be excluded.
         """
-        ignoreFieldNames = set(ignoreFieldNames or [])
-        result = []
-        for f in [
-                self.field[p]
-                for p in self.input_field_names
-                if not p in ignoreFieldNames
-            ]:
-            for val in f.value:
-                if not isinstance(val, str):
-                    val = self.uc_decode(val)[0]
-                result.append(self.hiddenFieldHTML(f.name, val, ''))
-        return '\n'.join(result) # hiddenInputFieldString()
+        ignored_fields = set(ignored_fields or [])
+        res = []
+        for fname in self.input_field_names:
+            if fname in ignored_fields:
+                continue
+            for val in self.field[fname].value:
+                if isinstance(val, str):
+                    res.append(self.hidden_field_html(fname, val, ''))
+        return '\n'.join(res)
 
 
 class SearchAttrs(Input):
@@ -249,7 +246,7 @@ class SearchAttrs(Input):
         Input.set_value(self, value)
 
 
-class Web2LDAPForm_searchform(Web2LDAPForm):
+class Web2LDAPFormSearchform(Web2LDAPForm):
     command = 'searchform'
 
     def fields(self):
@@ -328,7 +325,7 @@ class Web2LDAPForm_searchform(Web2LDAPForm):
             Select(
                 'search_option', 'Search option',
                 web2ldapcnf.max_searchparams,
-                options=web2ldap.app.searchform.search_options,
+                options=SEARCH_OPTIONS,
             ),
             Input(
                 'search_string', 'Search string',
@@ -343,11 +340,11 @@ class Web2LDAPForm_searchform(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_search(Web2LDAPForm_searchform):
+class Web2LDAPFormSearch(Web2LDAPFormSearchform):
     command = 'search'
 
     def fields(self):
-        res = Web2LDAPForm_searchform.fields(self)
+        res = Web2LDAPFormSearchform.fields(self)
         res.extend([
             Input(
                 'search_resminindex',
@@ -365,7 +362,7 @@ class Web2LDAPForm_search(Web2LDAPForm_searchform):
         return res
 
 
-class Web2LDAPForm_conninfo(Web2LDAPForm):
+class Web2LDAPFormConninfo(Web2LDAPForm):
     command = 'conninfo'
 
     def fields(self):
@@ -382,7 +379,7 @@ class Web2LDAPForm_conninfo(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_params(Web2LDAPForm):
+class Web2LDAPFormParams(Web2LDAPForm):
     command = 'params'
 
     def fields(self):
@@ -423,7 +420,7 @@ class Web2LDAPForm_params(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_input(Web2LDAPForm):
+class Web2LDAPFormInput(Web2LDAPForm):
 
     """Base class for entry data input not directly used"""
     def fields(self):
@@ -469,11 +466,11 @@ class Web2LDAPForm_input(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_add(Web2LDAPForm_input):
+class Web2LDAPFormAdd(Web2LDAPFormInput):
     command = 'add'
 
     def fields(self):
-        res = Web2LDAPForm_input.fields(self)
+        res = Web2LDAPFormInput.fields(self)
         res.extend([
             Input('add_rdn', 'RDN of new entry', 255, 1, '.*', size=50),
             DistinguishedNameInput('add_clonedn', 'DN of template entry'),
@@ -488,11 +485,11 @@ class Web2LDAPForm_add(Web2LDAPForm_input):
         return res
 
 
-class Web2LDAPForm_modify(Web2LDAPForm_input):
+class Web2LDAPFormModify(Web2LDAPFormInput):
     command = 'modify'
 
     def fields(self):
-        res = Web2LDAPForm_input.fields(self)
+        res = Web2LDAPFormInput.fields(self)
         res.extend([
             AttributeType(
                 'in_oldattrtypes',
@@ -516,7 +513,7 @@ class Web2LDAPForm_modify(Web2LDAPForm_input):
         return res
 
 
-class Web2LDAPForm_dds(Web2LDAPForm):
+class Web2LDAPFormDds(Web2LDAPForm):
     command = 'dds'
 
     def fields(self):
@@ -545,7 +542,7 @@ class Web2LDAPForm_dds(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_bulkmod(Web2LDAPForm):
+class Web2LDAPFormBulkmod(Web2LDAPForm):
     command = 'bulkmod'
 
     def fields(self):
@@ -614,7 +611,7 @@ class Web2LDAPForm_bulkmod(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_delete(Web2LDAPForm):
+class Web2LDAPFormDelete(Web2LDAPForm):
     command = 'delete'
 
     def fields(self):
@@ -628,7 +625,7 @@ class Web2LDAPForm_delete(Web2LDAPForm):
                 or 'delete' in control_spec[0]
             )
         ]
-        delete_ctrl_options.append((web2ldap.ldapsession.CONTROL_TREEDELETE, 'Tree Deletion'))
+        delete_ctrl_options.append((CONTROL_TREEDELETE, 'Tree Deletion'))
         res.extend([
             Select(
                 'delete_confirm', 'Confirmation',
@@ -656,7 +653,7 @@ class Web2LDAPForm_delete(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_rename(Web2LDAPForm):
+class Web2LDAPFormRename(Web2LDAPForm):
     command = 'rename'
 
     def fields(self):
@@ -666,7 +663,7 @@ class Web2LDAPForm_rename(Web2LDAPForm):
                 'rename_newrdn',
                 'New RDN',
                 255, 1,
-                web2ldap.ldaputil.rdn_pattern,
+                RDN_PATTERN,
                 size=50,
             ),
             DistinguishedNameInput('rename_newsuperior', 'New superior DN'),
@@ -692,7 +689,7 @@ class Web2LDAPForm_rename(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_passwd(Web2LDAPForm):
+class Web2LDAPFormPasswd(Web2LDAPForm):
     command = 'passwd'
     passwd_actions = (
         (
@@ -717,7 +714,7 @@ class Web2LDAPForm_passwd(Web2LDAPForm):
                 'passwd_action', 'Password action', 1,
                 options=[
                     (action, short_desc)
-                    for action, short_desc, _ in Web2LDAPForm_passwd.passwd_actions
+                    for action, short_desc, _ in Web2LDAPFormPasswd.passwd_actions
                 ],
                 default='setuserpassword'
             ),
@@ -726,7 +723,7 @@ class Web2LDAPForm_passwd(Web2LDAPForm):
             Field('passwd_newpasswd', 'New password', 100, 2, '.*'),
             Select(
                 'passwd_scheme', 'Password hash scheme', 1,
-                options=web2ldap.ldaputil.passwd.AVAIL_USERPASSWORD_SCHEMES.items(),
+                options=AVAIL_USERPASSWORD_SCHEMES.items(),
                 default=None,
             ),
             Checkbox(
@@ -765,7 +762,7 @@ class Web2LDAPForm_passwd(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_read(Web2LDAPForm):
+class Web2LDAPFormRead(Web2LDAPForm):
     command = 'read'
 
     def fields(self):
@@ -798,7 +795,7 @@ class Web2LDAPForm_read(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_groupadm(Web2LDAPForm):
+class Web2LDAPFormGroupadm(Web2LDAPForm):
     command = 'groupadm'
 
     def fields(self):
@@ -823,7 +820,7 @@ class Web2LDAPForm_groupadm(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_login(Web2LDAPForm):
+class Web2LDAPFormLogin(Web2LDAPForm):
     command = 'login'
 
     def fields(self):
@@ -834,7 +831,7 @@ class Web2LDAPForm_login(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_locate(Web2LDAPForm):
+class Web2LDAPFormLocate(Web2LDAPForm):
     command = 'locate'
 
     def fields(self):
@@ -845,7 +842,7 @@ class Web2LDAPForm_locate(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_oid(Web2LDAPForm):
+class Web2LDAPFormOid(Web2LDAPForm):
     command = 'oid'
 
     def fields(self):
@@ -863,7 +860,7 @@ class Web2LDAPForm_oid(Web2LDAPForm):
         return res
 
 
-class Web2LDAPForm_dit(Web2LDAPForm):
+class Web2LDAPFormDit(Web2LDAPForm):
     command = 'dit'
 
 
@@ -901,9 +898,9 @@ class LDIFTextArea(Textarea):
             required=required,
         )
         self._max_entries = max_entries
-        self.allRecords = []
 
-    def getLDIFRecords(self):
+    @property
+    def ldif_records(self):
         if self.value:
             return list(
                 ldap0.ldif.LDIFParser.frombuf(
@@ -962,7 +959,7 @@ class ObjectClassSelect(Select):
             ignoreCase=1,
             multiSelect=1
         )
-        self.setRegex('[\\w]+')
+        self.set_regex('[\\w]+')
         self.maxLen = 200
         # end of ObjectClassSelect()
 
@@ -1006,7 +1003,7 @@ class AttributeType(Input):
             text,
             500,
             maxValues,
-            web2ldap.ldaputil.attr_type_pattern,
+            ATTR_TYPE_PATTERN,
             required=False,
             size=30
         )
@@ -1063,11 +1060,11 @@ class AuthMechSelect(Select):
             multiSelect=0
         )
 
-    def setOptions(self, options):
+    def set_options(self, options):
         options_dict = {}
         options_dict[''] = self.supported_bind_mechs['']
-        for o in options or self.supported_bind_mechs.keys():
-            o_upper = o.upper()
-            if o_upper in self.supported_bind_mechs:
-                options_dict[o_upper] = self.supported_bind_mechs[o_upper]
-        Select.setOptions(self, options_dict.items())
+        for sasl_mech in options or self.supported_bind_mechs.keys():
+            sasl_mech = sasl_mech.upper()
+            if sasl_mech in self.supported_bind_mechs:
+                options_dict[sasl_mech] = self.supported_bind_mechs[sasl_mech]
+        Select.set_options(self, options_dict.items())
