@@ -17,8 +17,13 @@ import ldap0.cidict
 from ldap0.dn import DNObj
 from ldap0.res import SearchResultEntry
 
-import web2ldap.app.core
-import web2ldap.app.gui
+from .gui import (
+    footer,
+    main_menu,
+    search_root_field,
+    top_section,
+)
+from . import ErrorExit
 
 ACTION2MODTYPE = {
     'add': ldap0.MOD_ADD,
@@ -87,15 +92,15 @@ def group_select_field(
     option_list = []
     for optgroup_dn in optgroup_list:
         if optgroup_dn:
-            option_list.append('<optgroup label="%s">' % (app.form.utf2display(optgroup_dn)))
+            option_list.append('<optgroup label="%s">' % (app.form.s2d(optgroup_dn)))
         for dn in sorted(optgroup_dict[optgroup_dn], key=str.lower):
-            option_text = app.form.utf2display(
+            option_text = app.form.s2d(
                 groups_dict[dn].get(
                     'cn',
                     [dn[:-len(group_search_root) or len(dn)]]
                 )[0],
             )
-            option_title = app.form.utf2display(
+            option_title = app.form.s2d(
                 groups_dict[dn].get(
                     'description',
                     [dn[:-len(group_search_root)]]
@@ -103,7 +108,7 @@ def group_select_field(
             )
             option_list.append((
                 '<option value="%s" title="%s">%s</option>' % (
-                    app.form.utf2display(dn),
+                    app.form.s2d(dn),
                     option_title,
                     option_text
                 )
@@ -122,7 +127,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
 
     groupadm_defs = ldap0.cidict.CIDict(app.cfg_param('groupadm_defs', {}))
     if not groupadm_defs:
-        raise web2ldap.app.core.ErrorExit(u'Group admin options empty or not set.')
+        raise ErrorExit(u'Group admin options empty or not set.')
     groupadm_defs_keys = groupadm_defs.keys()
 
     all_membership_attrs = [
@@ -133,7 +138,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
 
     search_result = app.ls.l.read_s(app.dn, attrlist=all_membership_attrs)
     if not search_result:
-        raise web2ldap.app.core.ErrorExit(u'No search result when reading entry.')
+        raise ErrorExit(u'No search result when reading entry.')
 
     user_entry = ldap0.schema.models.Entry(app.schema, app.dn, search_result.entry_as)
 
@@ -143,10 +148,10 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
     groupadm_name = app.form.getInputValue('groupadm_name', [None])[0]
 
     filter_components = []
-    for oc in groupadm_defs.keys():
-        if len(groupadm_defs[oc]) == 3 and not groupadm_defs[oc][2]:
+    for ocl in groupadm_defs.keys():
+        if len(groupadm_defs[ocl]) == 3 and not groupadm_defs[ocl][2]:
             continue
-        group_member_attrtype, user_entry_attrtype = groupadm_defs[oc][:2]
+        group_member_attrtype, user_entry_attrtype = groupadm_defs[ocl][:2]
         if user_entry_attrtype is None:
             user_entry_attrvalue = app.dn
         else:
@@ -155,7 +160,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
             except KeyError:
                 continue
         filter_components.append((
-            oc.strip(),
+            ocl.strip(),
             group_member_attrtype.strip(),
             ldap0.filter.escape_str(user_entry_attrvalue),
         ))
@@ -219,19 +224,19 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
                     # => Ignore that condition
                     continue
                 modlist = []
-                for oc in groupadm_defs_keys:
-                    if oc.lower() in [
+                for ocl in groupadm_defs_keys:
+                    if ocl.lower() in [
                             v.lower()
                             for v in all_groups_dict[group_dn].get('objectClass', [])
                         ]:
-                        group_member_attrtype, user_entry_attrtype = groupadm_defs[oc][0:2]
+                        group_member_attrtype, user_entry_attrtype = groupadm_defs[ocl][0:2]
                         if user_entry_attrtype is None:
                             member_value = app.ldap_dn
                         else:
                             if user_entry_attrtype not in user_entry:
-                                raise web2ldap.app.core.ErrorExit(
+                                raise ErrorExit(
                                     u'Object class %s requires attribute %s in group entry.' % (
-                                        oc,
+                                        ocl,
                                         user_entry_attrtype,
                                     )
                                 )
@@ -245,11 +250,11 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
                 if modlist:
                     try:
                         app.ls.modify(group_dn, modlist)
-                    except ldap0.LDAPError as e:
+                    except ldap0.LDAPError as err:
                         ldaperror_entries.append((
                             group_dn,
                             modlist,
-                            app.ldap_error_msg(e),
+                            app.ldap_error_msg(err),
                         ))
                     else:
                         successful_group_mods.append((group_dn, modlist))
@@ -270,7 +275,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
                 info_msg_list.append('<p>Added to:</p>')
                 info_msg_list.append('<ul>')
                 info_msg_list.extend([
-                    '<li>%s</li>' % (app.form.utf2display(group_dn))
+                    '<li>%s</li>' % (app.form.s2d(group_dn))
                     for group_dn, modlist in group_add_list
                 ])
                 info_msg_list.append('</ul>')
@@ -278,7 +283,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
                 info_msg_list.append('<p>Removed from:</p>')
                 info_msg_list.append('<ul>')
                 info_msg_list.extend([
-                    '<li>%s</li>' % (app.form.utf2display(group_dn))
+                    '<li>%s</li>' % (app.form.s2d(group_dn))
                     for group_dn, modlist in group_remove_list
                 ])
                 info_msg_list.append('</ul>')
@@ -288,7 +293,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
             error_msg_list = [error_msg]
             error_msg_list.extend([
                 'Error while modifying {group_dn}:<br>{error_msg}'.format(
-                    group_dn=app.form.utf2display(group_dn),
+                    group_dn=app.form.s2d(group_dn),
                     error_msg=error_msg
                 )
                 for group_dn, modlist, error_msg in ldaperror_entries
@@ -347,14 +352,9 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
     # HTML output
     #########################################################
 
-    web2ldap.app.gui.top_section(
-        app,
-        'Group membership',
-        web2ldap.app.gui.main_menu(app),
-        context_menu_list=[]
-    )
+    top_section(app, 'Group membership', main_menu(app), context_menu_list=[])
 
-    group_search_root_field = web2ldap.app.gui.search_root_field(
+    group_search_root_field = search_root_field(
         app,
         name='groupadm_searchroot',
         default=str(group_search_root),
@@ -387,8 +387,8 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
             """ % (
                 # form for changing group membership
                 app.begin_form('groupadm', 'POST'),
-                app.form.hiddenFieldHTML('dn', app.dn, u''),
-                app.form.hiddenFieldHTML('groupadm_searchroot', str(group_search_root), u''),
+                app.form.hidden_field_html('dn', app.dn, u''),
+                app.form.hidden_field_html('groupadm_searchroot', str(group_search_root), u''),
                 group_select_field(
                     app,
                     all_groups_dict,
@@ -419,7 +419,7 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
         """ % (
             # form for searching group entries
             app.begin_form('groupadm', 'GET'),
-            app.form.hiddenFieldHTML('dn', app.dn, u''),
+            app.form.hidden_field_html('dn', app.dn, u''),
             group_search_root_field.input_html(title='Search root for searching group entries'),
             app.form.field['groupadm_name'].input_html(),
             app.form.field['groupadm_view'].input_html(
@@ -441,10 +441,10 @@ def w2l_groupadm(app, info_msg='', error_msg=''):
                     [('dn', group_dn)],
                     title=u'Display group entry',
                 ),
-                app.form.utf2display(group_dn),
+                app.form.s2d(group_dn),
                 ', '.join(group_entry.get('objectClass', [])),
                 '<br>'.join(group_entry.get('description', []))
             ))
         app.outf.write('</dl>\n')
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
