@@ -12,13 +12,11 @@ Apache License Version 2.0 (Apache-2.0)
 https://www.apache.org/licenses/LICENSE-2.0
 """
 
+import re
 import time
-import os
 from hashlib import md5
-from typing import Sequence, Tuple, Union
 
 import ldap0
-import ldap0.ldapurl
 from ldap0.ldapurl import LDAPUrl
 import ldap0.filter
 from ldap0.dn import DNObj
@@ -27,34 +25,28 @@ from ldap0.res import SearchResultEntry
 try:
     import dns
 except ImportError:
-    dns_available = False
+    DNS_AVAIL = False
 else:
-    dns_available = True
+    DNS_AVAIL = True
 
 import web2ldapcnf
 
-import web2ldap.web.forms
-from web2ldap.web import escape_html
-import web2ldap.__about__
-import web2ldap.msbase
-import web2ldap.app.core
-import web2ldap.app.cnf
-import web2ldap.app.schema.syntaxes
-import web2ldap.app.searchform
-from web2ldap.msbase import GrabKeys
-from web2ldap.ldaputil import logdb_filter
+from ..web.forms import Select as SelectField
+from ..__about__ import __version__
+from ..web import escape_html
+from ..ldaputil import logdb_filter
+from .tmpl import read_template
 
-from web2ldap.log import logger
-logger.debug('dns_available = %r', dns_available)
 
 #---------------------------------------------------------------------------
 # Constants
 #---------------------------------------------------------------------------
 
-host_pattern = r'[a-zA-Z0-9_.:\[\]-]+'
-
 HIDDEN_FIELD = '<input type="hidden" name="%s" value="%s">%s\n'
 
+HTML_OFF_S = {False:'', True:'<!--'}
+HTML_OFF_E = {False:'', True:'-->'}
+
 HTML_FOOTER = """
   <p class="ScrollLink">
     <a href="#web2ldap_top">&uarr; TOP</a>
@@ -70,77 +62,10 @@ HTML_FOOTER = """
 """
 
 
-def get_variant_filename(pathname, variantlist):
-    """
-    returns variant filename
-    """
-    checked_set = set()
-    for v in variantlist:
-        # Strip subtags
-        v = v.lower().split('-', 1)[0]
-        if v == 'en':
-            variant_filename = pathname
-        else:
-            variant_filename = '.'.join((pathname, v))
-        if v not in checked_set and os.path.isfile(variant_filename):
-            break
-        checked_set.add(v)
-    else:
-        variant_filename = pathname
-    return variant_filename
-
-
-def read_template(app, config_key, form_desc=u'', tmpl_filename=None):
-    if not tmpl_filename:
-        tmpl_filename = app.cfg_param(config_key, None)
-    if not tmpl_filename:
-        raise web2ldap.app.core.ErrorExit(u'No template specified for %s.' % (form_desc))
-    tmpl_filename = web2ldap.app.gui.get_variant_filename(tmpl_filename, app.form.accept_language)
-    try:
-        # Read template from file
-        with open(tmpl_filename, 'rb') as tmpl_fileobj:
-            tmpl_str = tmpl_fileobj.read().decode('utf-8')
-    except IOError:
-        raise web2ldap.app.core.ErrorExit(u'I/O error during reading %s template file.' % (form_desc))
-    return tmpl_str # read_template()
-
-
 def dn_anchor_hash(dn):
     return str(md5(dn.encode('utf-8')).hexdigest())
 
 
-def ts2repr(
-        time_divisors: Sequence[Tuple[str, int]],
-        ts_sep: str,
-        ts_value: Union[str, bytes],
-    ) -> str:
-    rest = int(ts_value)
-    result = []
-    for desc, divisor in time_divisors:
-        mult = rest // divisor
-        rest = rest % divisor
-        if mult > 0:
-            result.append(u'%d %s' % (mult, desc))
-        if rest == 0:
-            break
-    return ts_sep.join(result)
-
-
-def repr2ts(time_divisors, ts_sep, value):
-    l1 = [v.strip().split(u' ') for v in value.split(ts_sep)]
-    l2 = [(int(v), d.strip()) for v, d in l1]
-    time_divisors_dict = dict(time_divisors)
-    result = 0
-    for val, desc in l2:
-        try:
-            result += val * time_divisors_dict[desc]
-        except KeyError:
-            raise ValueError
-        else:
-            del time_divisors_dict[desc]
-    return str(result)
-
-
 def command_div(
         commandlist,
         div_id='CommandDiv',
@@ -166,9 +91,9 @@ def command_div(
 
 def simple_main_menu(app):
     main_menu = [app.anchor('', 'Connect', [])]
-    if web2ldap.app.handler.check_access(app.env, 'monitor'):
+    if app.check_access('monitor'):
         main_menu.append(app.anchor('monitor', 'Monitor', []))
-    if dns_available and web2ldap.app.handler.check_access(app.env, 'locate'):
+    if DNS_AVAIL and app.check_access('locate'):
         main_menu.append(app.anchor('locate', 'DNS lookup', []))
     return main_menu
 
@@ -178,7 +103,7 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
     Output the context menu for a single entry
     """
     dn_disp = app.dn or u'Root DSE'
-    result = [
+    mil = [
         app.anchor(
             'read', 'Raw',
             [
@@ -191,7 +116,7 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
     ]
     if app.dn:
         ldap_url_obj = app.ls.ldap_url('', add_login=False)
-        result.extend([
+        mil.extend([
             app.anchor(
                 'login', 'Bind as',
                 [
@@ -201,11 +126,31 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
                 ],
                 title=u'Connect and bind new session as\r\n%s' % (app.dn)
             ),
-            app.anchor('modify', 'Modify', [('dn', app.dn)], title=u'Modify entry\r\n%s' % (app.dn)),
-            app.anchor('rename', 'Rename', [('dn', app.dn)], title=u'Rename/move entry\r\n%s' % (app.dn)),
-            app.anchor('delete', 'Delete', [('dn', app.dn)], title=u'Delete entry and/or subtree\r\n%s' % (app.dn)),
-            app.anchor('passwd', 'Password', [('dn', app.dn), ('passwd_who', app.dn)], title=u'Set password for entry\r\n%s' % (app.dn)),
-            app.anchor('groupadm', 'Groups', [('dn', app.dn)], title=u'Change group membership of entry\r\n%s' % (app.dn)),
+            app.anchor(
+                'modify', 'Modify',
+                [('dn', app.dn)],
+                title=u'Modify entry\r\n%s' % (app.dn)
+            ),
+            app.anchor(
+                'rename', 'Rename',
+                [('dn', app.dn)],
+                title=u'Rename/move entry\r\n%s' % (app.dn)
+            ),
+            app.anchor(
+                'delete', 'Delete',
+                [('dn', app.dn)],
+                title=u'Delete entry and/or subtree\r\n%s' % (app.dn)
+            ),
+            app.anchor(
+                'passwd', 'Password',
+                [('dn', app.dn), ('passwd_who', app.dn)],
+                title=u'Set password for entry\r\n%s' % (app.dn)
+            ),
+            app.anchor(
+                'groupadm', 'Groups',
+                [('dn', app.dn)],
+                title=u'Change group membership of entry\r\n%s' % (app.dn)
+            ),
             app.anchor(
                 'add', 'Clone',
                 [
@@ -218,7 +163,7 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
         ])
 
     if vcard_link:
-        result.append(
+        mil.append(
             app.anchor(
                 'read', 'vCard',
                 [('dn', app.dn), ('read_output', 'vcard')],
@@ -227,7 +172,7 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
         )
 
     if dds_link:
-        result.append(
+        mil.append(
             app.anchor(
                 'dds', 'Refresh',
                 [('dn', app.dn)],
@@ -238,7 +183,7 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
     if app.audit_context:
         accesslog_any_filterstr = logdb_filter(u'auditObject', app.dn, entry_uuid)
         accesslog_write_filterstr = logdb_filter(u'auditWriteObject', app.dn, entry_uuid)
-        result.extend([
+        mil.extend([
             app.anchor(
                 'search', 'Audit access',
                 [
@@ -260,12 +205,12 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
         ])
 
     try:
-        changelog_dn = app.ls.rootDSE['changelog'][0].decode(app.ls.charset)
+        changelog_dn = app.ls.root_dse['changelog'][0].decode(app.ls.charset)
     except KeyError:
         pass
     else:
         changelog_filterstr = logdb_filter(u'changeLogEntry', app.dn, entry_uuid)
-        result.append(
+        mil.append(
             app.anchor(
                 'search', 'Change log',
                 [
@@ -278,11 +223,11 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
         )
 
     try:
-        monitor_context_dn = app.ls.rootDSE['monitorContext'][0].decode(app.ls.charset)
+        monitor_context_dn = app.ls.root_dse['monitorContext'][0].decode(app.ls.charset)
     except KeyError:
         pass
     else:
-        result.append(app.anchor(
+        mil.append(app.anchor(
             'search', 'User conns',
             [
                 ('dn', monitor_context_dn),
@@ -297,84 +242,43 @@ def context_menu_single_entry(app, vcard_link=0, dds_link=0, entry_uuid=None):
             title=u'Find connections of this user in monitor database',
         ))
 
-    return result
+    return mil
     # end of context_menu_single_entry()
 
 
-def display_authz_dn(app, who=None, entry=None):
-    if who is None:
-        if hasattr(app.ls, 'who') and app.ls.who:
-            who = app.ls.who
-            entry = app.ls.userEntry
-        else:
-            return 'anonymous'
-    if ldap0.dn.is_dn(who):
-        # Fall-back is to display the DN
-        result = app.display_dn(who, commandbutton=False)
-        # Determine relevant templates dict
-        bound_as_templates = ldap0.cidict.CIDict(app.cfg_param('boundas_template', {}))
-        # Read entry if necessary
-        if entry is None:
-            read_attrs = set(['objectClass'])
-            for oc in bound_as_templates.keys():
-                read_attrs.update(GrabKeys(bound_as_templates[oc]).keys)
-            try:
-                user_res = app.ls.l.read_s(who, attrlist=read_attrs)
-            except ldap0.LDAPError:
-                entry = None
-            else:
-                if user_res is None:
-                    entry = {}
-                else:
-                    entry = user_res.entry_as
-        if entry:
-            display_entry = web2ldap.app.read.DisplayEntry(app, app.dn, app.schema, entry, 'readSep', True)
-            user_structural_oc = display_entry.entry.get_structural_oc()
-            for oc in bound_as_templates.keys():
-                if app.schema.get_oid(ldap0.schema.models.ObjectClass, oc) == user_structural_oc:
-                    try:
-                        result = bound_as_templates[oc] % display_entry
-                    except KeyError:
-                        pass
-    else:
-        result = app.form.utf2display(who)
-    return result
-    # end of display_authz_dn()
-
-
 def main_menu(app):
     """
     Returns list of main menu items
     """
-    cl = []
+    mil = []
 
     if app.ls is not None and app.ls.uri is not None:
 
         if app.dn and app.dn_obj != app.naming_context:
-            cl.append(
+            mil.append(
                 app.anchor(
                     'search', 'Up',
                     (
                         ('dn', app.parent_dn),
-                        ('scope', web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL),
+                        ('scope', str(ldap0.SCOPE_ONELEVEL)),
                         ('searchform_mode', u'adv'),
                         ('search_attr', u'objectClass'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_ATTR_EXISTS),
+                        ('search_option', '({at}=*)'),
                         ('search_string', ''),
                     ),
                     title=u'List direct subordinates of %s' % (app.parent_dn or u'Root DSE'),
                 )
             )
 
-        cl.extend((
+        mil.extend((
             app.anchor(
                 'search', 'Down',
                 (
                     ('dn', app.dn),
-                    ('scope', web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL),
+                    ('scope', str(ldap0.SCOPE_ONELEVEL)),
                     ('searchform_mode', u'adv'),
                     ('search_attr', u'objectClass'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_ATTR_EXISTS),
+                    ('search_option', '({at}=*)'),
                     ('search_string', u''),
                 ),
                 title=u'List direct subordinates of %s' % (app.dn or u'Root DSE'),
@@ -386,7 +290,7 @@ def main_menu(app):
             ),
         ))
 
-        cl.append(
+        mil.append(
             app.anchor(
                 'dit', 'Tree',
                 [('dn', app.dn)],
@@ -395,7 +299,7 @@ def main_menu(app):
             ),
         )
 
-        cl.append(
+        mil.append(
             app.anchor(
                 'read', 'Read',
                 [('dn', app.dn), ('read_nocache', u'1')],
@@ -403,46 +307,54 @@ def main_menu(app):
             ),
         )
 
-        cl.extend((
+        mil.extend((
             app.anchor(
                 'add', 'New entry',
                 [('dn', app.dn)],
                 title=u'Add a new entry below of %s' % (app.dn or u'Root DSE')
             ),
-            app.anchor('conninfo', 'ConnInfo', [('dn', app.dn)], title=u'Show information about HTTP and LDAP connections'),
-            app.anchor('params', 'Params', [('dn', app.dn)], title=u'Tweak parameters used for LDAP operations (controls etc.)'),
+            app.anchor(
+                'conninfo', 'ConnInfo',
+                [('dn', app.dn)],
+                title=u'Show information about HTTP and LDAP connections'
+            ),
+            app.anchor(
+                'params', 'Params',
+                [('dn', app.dn)],
+                title=u'Tweak parameters used for LDAP operations (controls etc.)'
+            ),
             app.anchor('login', 'Bind', [('dn', app.dn)], title=u'Login to directory'),
             app.anchor('oid', 'Schema', [('dn', app.dn)], title=u'Browse/view subschema'),
         ))
 
-        cl.append(app.anchor('disconnect', 'Disconnect', (), title=u'Disconnect from LDAP server'))
+        mil.append(app.anchor('disconnect', 'Disconnect', (), title=u'Disconnect from LDAP server'))
 
     else:
 
-        cl.append(app.anchor('', 'Connect', (), title=u'New connection to LDAP server'))
+        mil.append(app.anchor('', 'Connect', (), title=u'New connection to LDAP server'))
 
-    return cl
+    return mil
     # end of main_menu()
 
 
 def dit_navigation(app):
-    result = [
+    dnil = [
         app.anchor(
             'read',
-            app.form.utf2display(str(app.dn_obj.slice(i, i+1)) or '[Root DSE]'),
+            app.form.s2d(str(app.dn_obj.slice(i, i+1)) or '[Root DSE]'),
             [('dn', str(app.dn_obj.slice(i, None)))],
             title=u'Jump to %s' % (str(app.dn_obj.slice(i, None))),
         )
         for i in range(len(app.dn_obj))
     ]
-    result.append(
+    dnil.append(
         app.anchor(
             'read', '[Root DSE]',
             [('dn', '')],
             title=u'Jump to root DSE',
         )
     )
-    return result
+    return dnil
     # end of dit_navigation()
 
 
@@ -455,10 +367,10 @@ def top_section(
     ):
 
     # First send the HTTP header
-    Header(app, 'text/html', app.form.accept_charset)
+    header(app, 'text/html', app.form.accept_charset)
 
     # Read the template file for TopSection
-    top_template_str = web2ldap.app.gui.read_template(app, 'top_template', u'top section')
+    top_template_str = read_template(app, 'top_template', u'top section')
 
     script_name = escape_html(app.form.script_name)
 
@@ -469,7 +381,7 @@ def top_section(
         'sid': app.sid or '',
         'title_text': title,
         'script_name': script_name,
-        'web2ldap_version': escape_html(web2ldap.__about__.__version__),
+        'web2ldap_version': escape_html(__version__),
         'command': app.command,
         'ldap_url': '',
         'ldap_uri': '-/-',
@@ -496,42 +408,17 @@ def top_section(
         # Only output something meaningful if valid connection
         template_dict.update({
             'ldap_url': app.ls.ldap_url(app.dn),
-            'ldap_uri': app.form.utf2display(app.ls.uri),
+            'ldap_uri': app.form.s2d(app.ls.uri),
             'description': escape_html(app.cfg_param('description', u'')),
             'dit_navi': ',\n'.join(dit_navigation(app)),
-            'dn': app.form.utf2display(app.dn),
+            'dn': app.form.s2d(app.dn),
         })
-        template_dict['who'] = display_authz_dn(app)
+        template_dict['who'] = app.display_authz_dn()
 
     app.outf.write(top_template_str.format(**template_dict))
     # end of top_section()
 
 
-def ldap_url_anchor(app, data):
-    if isinstance(data, LDAPUrl):
-        l = data
-    else:
-        l = LDAPUrl(ldapUrl=data)
-    command_func = {True:'read', False:'search'}[l.scope == ldap0.SCOPE_BASE]
-    if l.hostport:
-        command_text = 'Connect'
-        return app.anchor(
-            command_func,
-            'Connect and %s' % (command_func),
-            (('ldapurl', str(l)),)
-        )
-    command_text = {True:'Read', False:'Search'}[l.scope == ldap0.SCOPE_BASE]
-    return app.anchor(
-        command_func, command_text,
-        [
-            ('dn', l.dn),
-            ('filterstr', (l.filterstr or '(objectClass=*)')),
-            ('scope', str(l.scope or ldap0.SCOPE_SUBTREE)),
-        ],
-    )
-    # end of ldap_url_anchor()
-
-
 def attrtype_select_field(
         app,
         field_name,
@@ -543,7 +430,10 @@ def attrtype_select_field(
     Return web2ldap.web.forms.Select instance for choosing attribute type names
     """
     attr_options_dict = {}
-    for attr_type in default_attr_options or list(app.schema.sed[ldap0.schema.models.AttributeType].keys())+attr_list:
+    for attr_type in (
+            default_attr_options
+            or list(app.schema.sed[ldap0.schema.models.AttributeType].keys())+attr_list
+        ):
         attr_type_se = app.schema.get_obj(ldap0.schema.models.AttributeType, attr_type)
         if attr_type_se:
             if attr_type_se.names:
@@ -560,7 +450,7 @@ def attrtype_select_field(
         for at in sorted(attr_options_dict.keys(), key=str.lower)
     ]
     # Create a select field instance for attribute type name
-    attr_select = web2ldap.web.forms.Select(
+    attr_select = SelectField(
         field_name, field_desc, 1,
         options=sorted_attr_options,
     )
@@ -579,14 +469,14 @@ def gen_headers(content_type, charset, more_headers=None):
     headers.append(('Date', current_datetime))
     headers.append(('Last-Modified', current_datetime))
     headers.append(('Expires', current_datetime))
-    for h, v in web2ldapcnf.http_headers.items():
-        headers.append((h, v))
+    for name, val in web2ldapcnf.http_headers.items():
+        headers.append((name, val))
     headers.extend(more_headers or [])
     return headers
     # end of gen_headers()
 
 
-def Header(app, content_type, charset, more_headers=None):
+def header(app, content_type, charset, more_headers=None):
     headers = gen_headers(
         content_type=content_type,
         charset=charset,
@@ -601,7 +491,7 @@ def Header(app, content_type, charset, more_headers=None):
         headers.append(('Strict-Transport-Security', 'max-age=15768000 ; includeSubDomains'))
     app.outf.set_headers(headers)
     return headers
-    # end of Header()
+    # end of header()
 
 
 def footer(app):
@@ -637,7 +527,7 @@ def search_root_field(
         dn_select_list.update(map(str, [app.dn_obj] + app.dn_obj.parents()))
     if search_root_searchurl:
         # search for more search bases
-        slu = ldap0.ldapurl.LDAPUrl(search_root_searchurl)
+        slu = LDAPUrl(search_root_searchurl)
         try:
             ldap_results = app.ls.l.search_s(
                 slu.dn,
@@ -658,7 +548,7 @@ def search_root_field(
         dn_select_list.remove('')
     # Add root search base string with description
     dn_select_list.add((u'', u'- World -'))
-    srf = web2ldap.web.forms.Select(
+    srf = SelectField(
         name, text, 1,
         size=1,
         options=sorted(
@@ -675,7 +565,7 @@ def search_root_field(
 
 def invalid_syntax_message(app, invalid_attrs):
     invalid_attr_types_ui = [
-        app.form.utf2display(at)
+        app.form.s2d(at)
         for at in sorted(invalid_attrs.keys())
     ]
     return 'Wrong syntax in following attributes: %s' % (
@@ -686,6 +576,27 @@ def invalid_syntax_message(app, invalid_attrs):
     )
 
 
+def extract_invalid_syntax(app, ldap_err):
+    """
+    try to extract error message and invalid attributes dict from LDAPError instance
+    """
+    try:
+        # try to extract OpenLDAP-specific info message
+        info = ldap_err.args[0].get('info', b'').decode(app.ls.charset)
+        invalid_attr, invalid_index = re.match(
+            '([a-zA-Z0-9;-]+): value #([0-9]+) invalid per syntax',
+            info,
+        ).groups()
+    except (AttributeError, IndexError, UnicodeDecodeError):
+        # could not extract useful info
+        invalid_attrs = {}
+        error_msg = app.ldap_error_msg(ldap_err)
+    else:
+        invalid_attrs = {invalid_attr: [int(invalid_index)]}
+        error_msg = invalid_syntax_message(app, invalid_attrs)
+    return error_msg, invalid_attrs
+
+
 def exception_message(app, h1_msg, error_msg):
     """
     h1_msg
@@ -702,7 +613,7 @@ def exception_message(app, h1_msg, error_msg):
           {error_msg}
         </p>
         """.format(
-            heading=app.form.utf2display(h1_msg),
+            heading=app.form.s2d(h1_msg),
             error_msg=error_msg,
         )
     )
