@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-"""web2ldap.app.handler: base handler
+"""
+web2ldap.app.handler: base handler
 
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
@@ -17,65 +18,82 @@ import socket
 import time
 import urllib.parse
 import logging
-from collections import defaultdict
-
 from ipaddress import ip_address, ip_network
 
 import ldap0
-from ldap0.ldapurl import is_ldapurl
+from ldap0.ldapurl import LDAPUrl, is_ldapurl
 from ldap0.dn import DNObj
 from ldap0.err import PasswordPolicyException, PasswordPolicyExpirationWarning
+from ldap0.schema.models import ObjectClass
 
 import web2ldapcnf
 import web2ldapcnf.hosts
 
-COMMAND_COUNT = defaultdict(lambda: 0)
-
-import web2ldap.web.forms
-import web2ldap.web.helper
-import web2ldap.web.session
-from web2ldap.web.helper import get_remote_ip
-import web2ldap.__about__
-import web2ldap.ldaputil
-import web2ldap.ldapsession
-from web2ldap.ldaputil.extldapurl import ExtendedLDAPUrl
-from web2ldap.ldapsession import LDAPSession
-from web2ldap.log import LogHelper, logger, log_exception
+from . import ErrorExit
+from ..ldaputil import AD_LDAP49_ERROR_CODES, AD_LDAP49_ERROR_PREFIX
+from ..web.forms import FormException
+from ..web.session import SessionException, MaxSessionPerIPExceeded, MaxSessionCountExceeded
+from ..web.helper import get_remote_ip
+from ..ldaputil.extldapurl import ExtendedLDAPUrl
+from ..ldapsession import (
+    LDAP_DEFAULT_TIMEOUT,
+    LDAPSession,
+    START_TLS_REQUIRED,
+    START_TLS_NO,
+    UsernameNotFound,
+    InvalidSimpleBindDN,
+    UsernameNotUnique,
+)
+from ..utctime import ts2repr
+from ..log import LogHelper, logger, log_exception
+from ..msbase import GrabKeys
 # Import the application modules
-import web2ldap.app.gui
-import web2ldap.app.cnf
-import web2ldap.app.passwd
-import web2ldap.app.dit
-import web2ldap.app.searchform
-import web2ldap.app.locate
-import web2ldap.app.search
-import web2ldap.app.addmodifyform
-import web2ldap.app.add
-import web2ldap.app.modify
-import web2ldap.app.dds
-import web2ldap.app.delete
-import web2ldap.app.params
-import web2ldap.app.read
-import web2ldap.app.conninfo
-import web2ldap.app.login
-import web2ldap.app.connect
-import web2ldap.app.referral
-import web2ldap.app.monitor
-import web2ldap.app.groupadm
-import web2ldap.app.rename
-import web2ldap.app.urlredirect
-import web2ldap.app.bulkmod
-import web2ldap.app.srvrr
-import web2ldap.app.schema.viewer
-import web2ldap.app.metrics
-from web2ldap.app.gui import exception_message, dns_available
-from web2ldap.app.form import Web2LDAPForm
-from web2ldap.app.session import session_store
-from web2ldap.app.schema.syntaxes import syntax_registry
-from web2ldap.ldaputil import AD_LDAP49_ERROR_CODES, AD_LDAP49_ERROR_PREFIX
-from web2ldap.app.core import ErrorExit
-if dns_available:
-    from web2ldap.ldaputil.dns import dc_dn_lookup
+from .gui import (
+    footer,
+    header,
+    read_template,
+    top_section,
+)
+from .cnf import LDAP_DEF, LDAP_URI_LIST_CHECK_DICT
+from . import passwd
+from .entry import DisplayEntry
+from .gui import exception_message, DNS_AVAIL
+from .form import Web2LDAPForm
+from .session import (
+    InvalidSessionInstance,
+    WrongSessionCookie,
+    session_store,
+)
+from .schema.syntaxes import syntax_registry
+from .stats import COMMAND_COUNT
+# action functions
+from .connect import w2l_connect
+from .locate import w2l_locate
+from .monitor import w2l_monitor
+from .urlredirect import w2l_urlredirect
+from .searchform import w2l_searchform
+from .search import w2l_search
+from .add import w2l_add
+from .modify import w2l_modify
+from .dds import w2l_dds
+from .bulkmod import w2l_bulkmod
+from .delete import w2l_delete
+from .dit import w2l_dit
+from .rename import w2l_rename
+from .passwd import w2l_passwd
+from .read import w2l_read
+from .conninfo import w2l_conninfo
+from .params import w2l_params
+from .login import w2l_login
+from .groupadm import w2l_groupadm
+from .schema.viewer import w2l_schema_viewer
+from .metrics import w2l_metrics, METRICS_AVAIL
+from .srvrr import w2l_chasesrvrecord
+from .referral import w2l_chasereferral
+from .schema.syntaxes import Timespan
+
+if DNS_AVAIL:
+    from ..ldaputil.dns import dc_dn_lookup
 
 SCOPE2COMMAND = {
     None:'search',
@@ -95,7 +113,7 @@ CONNTYPE2URLSCHEME = {
 FORM_CLASS = {}
 logger.debug('Registering Form classes')
 for _, cls in inspect.getmembers(sys.modules['web2ldap.app.form'], inspect.isclass):
-    if cls.__name__.startswith('Web2LDAPForm_') and cls.command is not None:
+    if issubclass(cls, Web2LDAPForm) and cls.command is not None:
         logger.debug('Register class %s for command %r', cls.__name__, cls.command)
         FORM_CLASS[cls.command] = cls
 
@@ -111,51 +129,35 @@ SIMPLE_MSG_HTML = """
 """
 
 COMMAND_FUNCTION = {
-    '': web2ldap.app.connect.w2l_connect,
+    '': w2l_connect,
     'disconnect': None,
-    'locate': web2ldap.app.locate.w2l_locate,
-    'monitor': web2ldap.app.monitor.w2l_monitor,
-    'urlredirect': web2ldap.app.urlredirect.w2l_urlredirect,
-    'searchform': web2ldap.app.searchform.w2l_searchform,
-    'search': web2ldap.app.search.w2l_search,
-    'add': web2ldap.app.add.w2l_add,
-    'modify': web2ldap.app.modify.w2l_modify,
-    'dds': web2ldap.app.dds.w2l_dds,
-    'bulkmod': web2ldap.app.bulkmod.w2l_bulkmod,
-    'delete': web2ldap.app.delete.w2l_delete,
-    'dit': web2ldap.app.dit.w2l_dit,
-    'rename': web2ldap.app.rename.w2l_rename,
-    'passwd': web2ldap.app.passwd.w2l_passwd,
-    'read': web2ldap.app.read.w2l_read,
-    'conninfo': web2ldap.app.conninfo.w2l_conninfo,
-    'params': web2ldap.app.params.w2l_params,
-    'login': web2ldap.app.login.w2l_login,
-    'groupadm': web2ldap.app.groupadm.w2l_groupadm,
-    'oid': web2ldap.app.schema.viewer.w2l_schema_viewer,
+    'locate': w2l_locate,
+    'monitor': w2l_monitor,
+    'urlredirect': w2l_urlredirect,
+    'searchform': w2l_searchform,
+    'search': w2l_search,
+    'add': w2l_add,
+    'modify': w2l_modify,
+    'dds': w2l_dds,
+    'bulkmod': w2l_bulkmod,
+    'delete': w2l_delete,
+    'dit': w2l_dit,
+    'rename': w2l_rename,
+    'passwd': w2l_passwd,
+    'read': w2l_read,
+    'conninfo': w2l_conninfo,
+    'params': w2l_params,
+    'login': w2l_login,
+    'groupadm': w2l_groupadm,
+    'oid': w2l_schema_viewer,
 }
 
-if web2ldap.app.metrics.METRICS_AVAIL:
-    COMMAND_FUNCTION['metrics'] = web2ldap.app.metrics.w2l_metrics
-
+if METRICS_AVAIL:
+    COMMAND_FUNCTION['metrics'] = w2l_metrics
 
 syntax_registry.check()
 
 
-def check_access(env, command):
-    """
-    simple access control based on client IP address
-    """
-    remote_addr = ip_address(env[web2ldapcnf.httpenv_remote_addr.split(',')[-1].strip()])
-    access_allowed = web2ldapcnf.access_allowed.get(
-        command,
-        web2ldapcnf.access_allowed['_']
-    )
-    for net in access_allowed:
-        if remote_addr in ip_network(net, strict=False):
-            return True
-    return False
-
-
 class AppHandler(LogHelper):
     """
     Class implements web application entry point
@@ -246,7 +248,7 @@ class AppHandler(LogHelper):
             cfg_url = self.ls.uri
         else:
             cfg_url = 'ldap://'
-        return web2ldap.app.cnf.LDAP_DEF.get_param(
+        return LDAP_DEF.get_param(
             cfg_url,
             self.naming_context or u'',
             param_key,
@@ -260,6 +262,20 @@ class AppHandler(LogHelper):
         """
         return self.cfg_param('binddn_mapping', u'ldap:///_??sub?(uid={user})')
 
+    def check_access(self, command):
+        """
+        simple access control based on client IP address
+        """
+        remote_addr = ip_address(self.env[web2ldapcnf.httpenv_remote_addr].split(',')[-1].strip())
+        access_allowed = web2ldapcnf.access_allowed.get(
+            command,
+            web2ldapcnf.access_allowed['_']
+        )
+        for net in access_allowed:
+            if remote_addr in ip_network(net, strict=False):
+                return True
+        return False
+
     def anchor(
             self,
             command,
@@ -287,9 +303,9 @@ class AppHandler(LogHelper):
             target_attr = ' target="%s"' % (target)
         title_attr = ''
         if title:
-            title_attr = ' title="%s"' % (self.form.utf2display(title).replace(' ', '&nbsp;'))
+            title_attr = ' title="%s"' % (self.form.s2d(title).replace(' ', '&nbsp;'))
         if anchor_id:
-            anchor_id = '#%s' % (self.form.utf2display(anchor_id))
+            anchor_id = '#%s' % (self.form.s2d(anchor_id))
         res = '<a class="CL"%s%s href="%s?%s%s">%s</a>' % (
             target_attr,
             title_attr,
@@ -304,6 +320,30 @@ class AppHandler(LogHelper):
         assert isinstance(res, str), TypeError('res must be str, was %r', res)
         return res
 
+    def ldap_url_anchor(self, data):
+        if isinstance(data, LDAPUrl):
+            ldap_url = data
+        else:
+            ldap_url = LDAPUrl(ldapUrl=data)
+        command_func = {True:'read', False:'search'}[ldap_url.scope == ldap0.SCOPE_BASE]
+        if ldap_url.hostport:
+            command_text = 'Connect'
+            return self.anchor(
+                command_func,
+                'Connect and %s' % (command_func),
+                (('ldapurl', str(ldap_url)),)
+            )
+        command_text = {True:'Read', False:'Search'}[ldap_url.scope == ldap0.SCOPE_BASE]
+        return self.anchor(
+            command_func, command_text,
+            [
+                ('dn', ldap_url.dn),
+                ('filterstr', (ldap_url.filterstr or '(objectClass=*)')),
+                ('scope', str(ldap_url.scope or ldap0.SCOPE_SUBTREE)),
+            ],
+        )
+        # end of ldap_url_anchor()
+
     def begin_form(
             self,
             command,
@@ -337,7 +377,7 @@ class AppHandler(LogHelper):
         """
         form_str = [self.begin_form(command, method, target)]
         for param_name, param_value in form_parameters:
-            form_str.append(self.form.hiddenFieldHTML(param_name, param_value, u''))
+            form_str.append(self.form.hidden_field_html(param_name, param_value, u''))
         form_str.append(
             '<p>\n<input type="submit" value="%s">\n%s\n</p>\n</form>' % (
                 submitstr,
@@ -396,11 +436,11 @@ class AppHandler(LogHelper):
         self.log(logging.DEBUG, 'split path_info to (%r, %r)', cmd, sid)
         return cmd, sid # path_info()
 
-    def display_dn(self, dn, commandbutton=False):
+    def display_dn(self, dn, links=False):
         """Display a DN as LDAP URL with or without button"""
         assert isinstance(dn, str), TypeError("Argument 'dn' must be str, was %r" % (dn,))
-        dn_str = self.form.utf2display(dn or u'- World -')
-        if commandbutton:
+        dn_str = self.form.s2d(dn or u'- World -')
+        if links:
             command_buttons = [
                 dn_str,
                 self.anchor('read', 'Read', [('dn', dn)])
@@ -408,6 +448,46 @@ class AppHandler(LogHelper):
             return web2ldapcnf.command_link_separator.join(command_buttons)
         return dn_str
 
+    def display_authz_dn(self, who=None, entry=None):
+        if who is None:
+            if hasattr(self.ls, 'who') and self.ls.who:
+                who = self.ls.who
+                entry = self.ls.user_entry
+            else:
+                return 'anonymous'
+        if ldap0.dn.is_dn(who):
+            # Fall-back is to display the DN
+            result = self.display_dn(who, links=False)
+            # Determine relevant templates dict
+            bound_as_templates = ldap0.cidict.CIDict(self.cfg_param('boundas_template', {}))
+            # Read entry if necessary
+            if entry is None:
+                read_attrs = set(['objectClass'])
+                for ocl in bound_as_templates.keys():
+                    read_attrs.update(GrabKeys(bound_as_templates[ocl]).keys)
+                try:
+                    user_res = self.ls.l.read_s(who, attrlist=read_attrs)
+                except ldap0.LDAPError:
+                    entry = None
+                else:
+                    if user_res is None:
+                        entry = {}
+                    else:
+                        entry = user_res.entry_as
+            if entry:
+                display_entry = DisplayEntry(self, self.dn, self.schema, entry, 'read_sep', True)
+                user_structural_oc = display_entry.entry.get_structural_oc()
+                for ocl in bound_as_templates.keys():
+                    if self.schema.get_oid(ObjectClass, ocl) == user_structural_oc:
+                        try:
+                            result = bound_as_templates[ocl] % display_entry
+                        except KeyError:
+                            pass
+        else:
+            result = self.form.s2d(who)
+        return result
+        # end of display_authz_dn()
+
     def simple_message(
             self,
             title=u'',
@@ -416,7 +496,7 @@ class AppHandler(LogHelper):
             main_menu_list=None,
             context_menu_list=None,
         ):
-        web2ldap.app.gui.top_section(
+        top_section(
             self,
             title,
             main_menu_list,
@@ -424,14 +504,14 @@ class AppHandler(LogHelper):
             main_div_id=main_div_id,
         )
         self.outf.write(message)
-        web2ldap.app.gui.footer(self)
+        footer(self)
         # end of simple_message()
 
     def simple_msg(self, msg):
         """
         Output HTML text.
         """
-        web2ldap.app.gui.Header(self, 'text/html', self.form.accept_charset)
+        header(self, 'text/html', self.form.accept_charset)
         self.outf.write(SIMPLE_MSG_HTML.format(message=msg))
 
     def url_redirect(
@@ -447,7 +527,7 @@ class AppHandler(LogHelper):
         if self.form is None:
             self.form = Web2LDAPForm(None, self.env)
         target_url = target_url or self.script_name
-        url_redirect_template_str = web2ldap.app.gui.read_template(
+        url_redirect_template_str = read_template(
             self, None, u'redirect',
             tmpl_filename=web2ldapcnf.redirect_template,
         )
@@ -455,14 +535,14 @@ class AppHandler(LogHelper):
             message_class = 'ErrorMessage'
         else:
             message_class = 'SuccessMessage'
-        web2ldap.app.gui.Header(self, 'text/html', self.form.accept_charset)
+        header(self, 'text/html', self.form.accept_charset)
         # Write out stub body with just a short redirect HTML snippet
         self.outf.write(
             url_redirect_template_str.format(
                 refresh_time=refresh_time,
                 target_url=target_url,
                 message_class=message_class,
-                redirect_msg=self.form.utf2display(redirect_msg),
+                redirect_msg=self.form.s2d(redirect_msg),
                 link_text=link_text,
             )
         )
@@ -492,9 +572,9 @@ class AppHandler(LogHelper):
                 last_session_timestamp, _ = self._session_store.sessiondict[self.sid]
             except KeyError:
                 pass
-            self.ls = self._session_store.retrieveSession(self.sid, self.env)
+            self.ls = self._session_store.retrieve(self.sid, self.env)
             if not isinstance(self.ls, LDAPSession):
-                raise web2ldap.app.session.InvalidSessionInstance()
+                raise InvalidSessionInstance()
             if self.ls.cookie:
                 # Check whether HTTP_COOKIE contains the cookie of this particular session
                 cookie_name = ''.join((self.form.cookie_name_prefix, str(id(self.ls))))
@@ -502,7 +582,7 @@ class AppHandler(LogHelper):
                         cookie_name in self.form.cookies and
                         self.ls.cookie[cookie_name].value == self.form.cookies[cookie_name].value
                     ):
-                    raise web2ldap.app.session.WrongSessionCookie()
+                    raise WrongSessionCookie()
             if web2ldapcnf.session_paranoid and \
                self.current_access_time-last_session_timestamp > web2ldapcnf.session_paranoid:
                 # Store session with new session ID
@@ -529,8 +609,8 @@ class AppHandler(LogHelper):
         except IndexError:
             return
         try:
-            old_ls = self._session_store.retrieveSession(del_sid, self.env)
-        except web2ldap.web.session.SessionException:
+            old_ls = self._session_store.retrieve(del_sid, self.env)
+        except SessionException:
             pass
         else:
             # Remove session cookie
@@ -548,8 +628,8 @@ class AppHandler(LogHelper):
             try:
                 input_ldapurl = ExtendedLDAPUrl(self.form.query_string)
             except ValueError as err:
-                raise ErrorExit(u'Error parsing LDAP URL: %s.' % (
-                    self.form.utf2display(str(err))
+                raise ErrorExit('Error parsing LDAP URL: %s.' % (
+                    self.form.s2d(str(err))
                 ))
             else:
                 self.command = self.command or SCOPE2COMMAND[input_ldapurl.scope]
@@ -575,8 +655,8 @@ class AppHandler(LogHelper):
                 conntype = int(self.form.getInputValue('conntype', [0])[0])
                 input_ldapurl.urlscheme = CONNTYPE2URLSCHEME[conntype]
                 input_ldapurl.hostport = self.form.getInputValue('host', [None])[0]
-                input_ldapurl.x_startTLS = str(
-                    web2ldap.ldapsession.START_TLS_REQUIRED * (conntype == 1)
+                input_ldapurl.start_tls = str(
+                    START_TLS_REQUIRED * (conntype == 1)
                 )
 
         # Separate parameters for dn, who, cred and scope
@@ -616,7 +696,7 @@ class AppHandler(LogHelper):
         )
 
         if not ldap0.dn.is_dn(dn, flags=1):
-            raise ErrorExit(u'Invalid DN.')
+            raise ErrorExit('Invalid DN.')
 
         scope_str = self.form.getInputValue(
             'scope',
@@ -674,11 +754,11 @@ class AppHandler(LogHelper):
                 matched_dn = ldap_err.args[0].get('matched', b'').decode(self.ls.charset)
             except AttributeError:
                 matched_dn = None
-        error_msg = error_msg.replace(u'\r', '').replace(u'\t', '')
-        error_msg_html = self.form.utf2display(error_msg, lf_entity='<br>')
+        error_msg = error_msg.replace('\r', '').replace('\t', '')
+        error_msg_html = self.form.s2d(error_msg, lf_entity='<br>')
         # Add matchedDN to error message HTML if needed
         if matched_dn:
-            matched_dn_html = '<br>Matched DN: %s' % (self.form.utf2display(matched_dn))
+            matched_dn_html = '<br>Matched DN: %s' % (self.form.s2d(matched_dn))
         else:
             matched_dn_html = ''
         return template.format(
@@ -696,7 +776,7 @@ class AppHandler(LogHelper):
         if self.command not in COMMAND_FUNCTION:
 
             self.log(logging.WARN, 'Received invalid command %r', self.command)
-            self.url_redirect(u'Invalid web2ldap command')
+            self.url_redirect('Invalid web2ldap command')
             return
 
         # count command
@@ -716,14 +796,14 @@ class AppHandler(LogHelper):
                 self.form.getInputFields()
 
             # Check access here
-            if not check_access(self.env, self.command):
+            if not self.check_access(self.command):
                 self.log(
                     logging.WARN,
                     'Access denied from %r to command %r',
                     self.env[web2ldapcnf.httpenv_remote_addr],
                     self.command,
                 )
-                raise ErrorExit(u'Access denied.')
+                raise ErrorExit('Access denied.')
 
             # Handle simple early-exit commands
             if self.command in {'', 'urlredirect', 'monitor', 'locate', 'metrics'}:
@@ -739,7 +819,7 @@ class AppHandler(LogHelper):
                 self._session_store.delete(self.sid)
                 self.sid = None
                 # Redirect to start page to avoid people bookmarking disconnect URL
-                self.url_redirect(u'Disconnecting...', refresh_time=0)
+                self.url_redirect('Disconnecting...', refresh_time=0)
                 return
 
             self.ldap_url, self.dn, who, cred = self._get_ldapconn_params()
@@ -756,7 +836,7 @@ class AppHandler(LogHelper):
             #-------------------------------------------------
 
             if (
-                    dns_available
+                    DNS_AVAIL
                     and self.ldap_url.hostport == ''
                     and self.ldap_url.urlscheme == 'ldap'
                     and (self.ls is None or self.ls.uri is None)
@@ -772,7 +852,7 @@ class AppHandler(LogHelper):
                     # No host specified in user's input
                     self._session_store.delete(self.sid)
                     self.sid = None
-                    web2ldap.app.connect.w2l_connect(
+                    w2l_connect(
                         self,
                         h1_msg='Connect failed',
                         error_msg='No host specified.'
@@ -782,7 +862,7 @@ class AppHandler(LogHelper):
                     init_uri = init_uri_list[0]
                 else:
                     # more than one possible servers => let user choose one
-                    web2ldap.app.srvrr.w2l_chasesrvrecord(self, init_uri_list)
+                    w2l_chasesrvrecord(self, init_uri_list)
                     return
             elif self.ldap_url.hostport is not None:
                 init_uri = str(self.ldap_url.connect_uri()[:])
@@ -797,16 +877,16 @@ class AppHandler(LogHelper):
                 self._new_session()
                 # Check whether access to target LDAP server is allowed
                 if web2ldapcnf.hosts.restricted_ldap_uri_list and \
-                   init_uri not in web2ldap.app.cnf.LDAP_URI_LIST_CHECK_DICT:
-                    raise ErrorExit(u'Only pre-configured LDAP servers allowed.')
+                   init_uri not in LDAP_URI_LIST_CHECK_DICT:
+                    raise ErrorExit('Only pre-configured LDAP servers allowed.')
                 # set this to make .cfg_param() retrieve correct site-specific config parameters
                 self.ls.uri = init_uri
                 # Connect to new specified host
                 self.ls.open(
                     init_uri,
-                    self.cfg_param('timeout', web2ldap.ldapsession.LDAP_DEFAULT_TIMEOUT),
+                    self.cfg_param('timeout', LDAP_DEFAULT_TIMEOUT),
                     self.ldap_url.get_starttls_extop(
-                        self.cfg_param('starttls', web2ldap.ldapsession.START_TLS_NO)
+                        self.cfg_param('starttls', START_TLS_NO)
                     ),
                     self.env,
                     self.cfg_param('session_track_control', 0),
@@ -827,7 +907,7 @@ class AppHandler(LogHelper):
             if self.ls.uri is None:
                 self._session_store.delete(self.sid)
                 self.sid = None
-                web2ldap.app.connect.w2l_connect(
+                w2l_connect(
                     self,
                     h1_msg='Connect failed',
                     error_msg='No valid LDAP connection.'
@@ -841,7 +921,7 @@ class AppHandler(LogHelper):
 
             login_mech = self.form.getInputValue(
                 'login_mech',
-                [self.ldap_url.saslMech or '']
+                [self.ldap_url.sasl_mech or '']
             )[0].upper() or None
 
             if (
@@ -850,11 +930,11 @@ class AppHandler(LogHelper):
                     (login_mech or '').encode('ascii') not in ldap0.sasl.SASL_NONINTERACTIVE_MECHS
                 ):
                 # first ask for password in a login form
-                web2ldap.app.login.w2l_login(
+                w2l_login(
                     self,
                     login_msg='',
                     who=who, relogin=0, nomenu=1,
-                    login_default_mech=self.ldap_url.saslMech
+                    login_default_mech=self.ldap_url.sasl_mech
                 )
                 return
 
@@ -882,15 +962,15 @@ class AppHandler(LogHelper):
                             self.form.getInputValue('login_authzid_prefix', [''])[0],
                             self.form.getInputValue(
                                 'login_authzid',
-                                [self.ldap_url.saslAuthzId or ''],
+                                [self.ldap_url.sasl_authzid or ''],
                             )[0],
                         )) or None,
-                        self.form.getInputValue('login_realm', [self.ldap_url.saslRealm])[0],
+                        self.form.getInputValue('login_realm', [self.ldap_url.sasl_realm])[0],
                         self.binddn_mapping,
                         loginSearchRoot=login_search_root,
                     )
                 except ldap0.NO_SUCH_OBJECT as err:
-                    web2ldap.app.login.w2l_login(
+                    w2l_login(
                         self,
                         login_msg=self.ldap_error_msg(err),
                         who=who, relogin=True
@@ -904,7 +984,7 @@ class AppHandler(LogHelper):
             # error message instead of logging exception in case user is playing
             # with manually generated URLs
             if not isinstance(self.ls, LDAPSession) or self.ls.uri is None:
-                self.url_redirect(u'No valid LDAP connection!')
+                self.url_redirect('No valid LDAP connection!')
                 return
             # Store session data in case anything goes wrong after here
             # to give the exception handler a good chance
@@ -924,13 +1004,13 @@ class AppHandler(LogHelper):
                 # Store current session
                 self._session_store.save(self.sid, self.ls)
 
-        except web2ldap.web.forms.FormException as form_error:
+        except FormException as form_error:
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
             exception_message(
                 self,
                 u'Error parsing form',
                 u'Error parsing form:<br>%s' % (
-                    self.form.utf2display(str(form_error)),
+                    self.form.s2d(str(form_error)),
                 ),
             )
 
@@ -939,24 +1019,24 @@ class AppHandler(LogHelper):
             self._session_store.delete(self.sid)
             self.sid = None
             # Redirect to entry page
-            web2ldap.app.connect.w2l_connect(
+            w2l_connect(
                 self,
                 h1_msg='Connect failed',
                 error_msg='Connecting to %s impossible!<br>%s' % (
-                    self.form.utf2display(init_uri or '-'),
+                    self.form.s2d(init_uri or '-'),
                     self.ldap_error_msg(err)
                 )
             )
 
         except ldap0.NO_SUCH_OBJECT as ldap_err:
 
-            if dns_available:
+            if DNS_AVAIL:
                 # first try to lookup dc-style DN via DNS
                 host_list = dc_dn_lookup(self.dn)
                 self.log(logging.DEBUG, 'host_list = %r', host_list)
                 if host_list and ExtendedLDAPUrl(self.ls.uri).hostport not in host_list:
                     # Found LDAP server for this naming context via DNS SRV RR
-                    web2ldap.app.srvrr.w2l_chasesrvrecord(self, host_list)
+                    w2l_chasesrvrecord(self, host_list)
                     return
 
             # Normal error handling
@@ -976,37 +1056,33 @@ class AppHandler(LogHelper):
             )
 
         except (ldap0.PARTIAL_RESULTS, ldap0.REFERRAL) as err:
-            web2ldap.app.referral.w2l_chasereferral(self, err)
+            w2l_chasereferral(self, err)
 
         except (
                 ldap0.INSUFFICIENT_ACCESS,
                 ldap0.STRONG_AUTH_REQUIRED,
                 ldap0.INAPPROPRIATE_AUTH,
-                web2ldap.ldapsession.UsernameNotFound,
+                UsernameNotFound,
             ) as err:
-            web2ldap.app.login.w2l_login(
+            log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
+            w2l_login(
                 self,
                 who=u'',
                 login_msg=self.ldap_error_msg(err),
                 relogin=True,
             )
 
-        except (
-                ldap0.INVALID_CREDENTIALS,
-            ) as err:
-            web2ldap.app.login.w2l_login(
+        except ldap0.INVALID_CREDENTIALS as err:
+            w2l_login(
                 self,
                 login_msg=self.ldap_error_msg(err),
                 who=who, relogin=True,
             )
 
-        except (
-                web2ldap.ldapsession.InvalidSimpleBindDN,
-                web2ldap.ldapsession.UsernameNotUnique,
-            ) as err:
-            web2ldap.app.login.w2l_login(
+        except (InvalidSimpleBindDN, UsernameNotUnique) as err:
+            w2l_login(
                 self,
-                login_msg=self.form.utf2display(str(err)),
+                login_msg=self.form.s2d(str(err)),
                 who=who, relogin=True,
             )
 
@@ -1014,16 +1090,16 @@ class AppHandler(LogHelper):
             # Setup what's required for executing command 'passwd'
             self.dn = self.ls.l.whoami_s()[3:] or err.who
             # Output the change password form
-            web2ldap.app.passwd.passwd_form(
+            passwd.passwd_form(
                 self,
                 u'',
                 self.dn,
                 None,
                 'Password change needed',
-                self.form.utf2display(
+                self.form.s2d(
                     u'Password will expire in %s!' % (
-                        web2ldap.app.gui.ts2repr(
-                            web2ldap.app.schema.syntaxes.Timespan.time_divisors,
+                        ts2repr(
+                            Timespan.time_divisors,
                             u' ',
                             err.timeBeforeExpiration,
                         )
@@ -1035,26 +1111,21 @@ class AppHandler(LogHelper):
             # Setup what's required for executing command 'passwd'
             self.dn = self.ls.l.get_whoami_dn() or err.who
             # Output the change password form
-            web2ldap.app.passwd.passwd_form(
+            passwd.passwd_form(
                 self,
                 u'',
                 self.dn,
                 None,
                 'Password change needed',
-                self.form.utf2display(err.desc)
+                self.form.s2d(err.desc)
             )
 
-        except (
-                socket.error,
-                socket.gaierror,
-                IOError,
-                UnicodeError,
-            ) as err:
+        except (socket.error, socket.gaierror, IOError, UnicodeError) as err:
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
             exception_message(
                 self,
                 u'Unhandled %s' % err.__class__.__name__,
-                self.form.utf2display(str(err)),
+                self.form.s2d(str(err)),
             )
 
         except ldap0.LDAPError as ldap_err:
@@ -1066,14 +1137,10 @@ class AppHandler(LogHelper):
             )
 
         except ErrorExit as error_exit:
-            self.log(logging.WARN, 'ErrorExit: %r', error_exit.Msg)
-            exception_message(
-                self,
-                u'Error',
-                error_exit.Msg,
-            )
+            self.log(logging.WARN, 'ErrorExit: %r', error_exit.error_message)
+            exception_message(self, 'Error', error_exit.error_message)
 
-        except web2ldap.web.session.MaxSessionPerIPExceeded as session_err:
+        except MaxSessionPerIPExceeded as session_err:
             self.log(logging.WARN, str(session_err))
             self.simple_msg(
                 u'Client %s exceeded limit of max. %d sessions! Try later...' % (
@@ -1082,17 +1149,17 @@ class AppHandler(LogHelper):
                 )
             )
 
-        except web2ldap.web.session.MaxSessionCountExceeded as session_err:
+        except MaxSessionCountExceeded as session_err:
             self.log(logging.WARN, str(session_err))
-            self.simple_msg(u'Too many web sessions! Try later...')
+            self.simple_msg('Too many web sessions! Try later...')
 
-        except web2ldap.web.session.SessionException:
+        except SessionException:
             if self.command == 'disconnect':
                 # Probably already disconnected => ignore exception and redirect to start page
-                self.url_redirect(u'Disconnecting...', refresh_time=0)
+                self.url_redirect('Disconnecting...', refresh_time=0)
             else:
                 log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
-                self.url_redirect(u'Session handling error.')
+                self.url_redirect('Session handling error.')
 
         except Exception:
             if hasattr(self, 'ls'):
@@ -1100,6 +1167,6 @@ class AppHandler(LogHelper):
             else:
                 error_ls = None
             log_exception(self.env, error_ls, self.dn, web2ldapcnf.log_error_details)
-            self.simple_msg(u'Unhandled error!')
+            self.simple_msg('Unhandled error!')
 
         # end of run()
