@@ -18,20 +18,13 @@ import ldap0
 from ldap0.dn import DNObj
 from ldap0.ldapurl import LDAPUrlExtension, LDAPUrlExtensions
 
-from web2ldap.ldaputil.extldapurl import ExtendedLDAPUrl
-
-# Modules shipped with web2ldap
-import web2ldap.ldaputil
-from web2ldap.log import logger
-from web2ldap.app.core import ErrorExit
-from web2ldap.app.gui import ldap_url_anchor, simple_main_menu
-try:
-    from web2ldap.ldaputil.dns import srv_lookup
-except ImportError:
-    srv_lookup = None
-else:
-    # from dnspython
+from ..ldaputil.extldapurl import ExtendedLDAPUrl
+from ..log import logger
+from . import ErrorExit
+from .gui import simple_main_menu, DNS_AVAIL
+if DNS_AVAIL:
     from dns.exception import DNSException
+    from ..ldaputil.dns import srv_lookup
 
 
 LDAP_HOSTNAME_ALIASES = (
@@ -88,7 +81,7 @@ def w2l_locate(app):
     Try to locate a LDAP server in DNS by several heuristics
     """
 
-    if srv_lookup is None:
+    if not DNS_AVAIL:
         logger.warning('Module package dnspython not installed!')
         raise ErrorExit('No DNS support!')
 
@@ -141,7 +134,7 @@ def w2l_locate(app):
                     lu_extensions = None
 
                 outf_lines.append('<h1><em>%s</em></h1>\n' % (
-                    app.form.utf2display(dns_name),
+                    app.form.s2d(dns_name),
                 ))
 
                 ldap_srv_results = []
@@ -157,7 +150,7 @@ def w2l_locate(app):
                         outf_lines.append(
                             'DNS or socket error when querying %s: %s' % (
                                 srv_prefix,
-                                app.form.utf2display(str(dns_err)),
+                                app.form.s2d(str(dns_err)),
                             )
                         )
                     else:
@@ -179,10 +172,14 @@ def w2l_locate(app):
                             )
                             try:
                                 host_address = socket.gethostbyname(hostname)
-                            except socket.error as e:
+                            except socket.error:
                                 outf_lines.append(
-                                    '<p class="ErrorMessage">Did not find IP address for hostname <em>%s</em>.</p>' % (
-                                        app.form.utf2display(hostname.decode('ascii'))
+                                    (
+                                        '<p class="ErrorMessage">'
+                                        'Did not find IP address for hostname <em>%s</em>.'
+                                        '</p>'
+                                    ) % (
+                                        app.form.s2d(hostname.decode('ascii'))
                                     )
                                 )
                             else:
@@ -204,7 +201,7 @@ def w2l_locate(app):
                                     """ % (
                                         hostname,
                                         host_address,
-                                        ldap_url_anchor(app, str(ldap_url)),
+                                        app.ldap_url_anchor(ldap_url),
                                         ldap_url.unparse(),
                                         ldap_url.unparse(),
                                     )
@@ -225,7 +222,7 @@ def w2l_locate(app):
                                     <td><a href="%s">Search %s</a></td>
                                     </tr>
                                     """ % (
-                                        ldap_url_anchor(app, ldap_url),
+                                        app.ldap_url_anchor(ldap_url),
                                         ldap_url.unparse(),
                                         ldap_url.unparse(),
                                     )
@@ -256,7 +253,7 @@ def w2l_locate(app):
                             LOCATE_HOST_RESULT_TMPL % (
                                 alias_name,
                                 host_address,
-                                ldap_url_anchor(app, ldap_url),
+                                app.ldap_url_anchor(ldap_url),
                                 ldap_url.unparse(),
                                 ldap_url.unparse(),
                             )
