@@ -14,10 +14,8 @@ https://www.apache.org/licenses/LICENSE-2.0
 
 import time
 
-import web2ldap.app.core
-import web2ldap.app.gui
-import web2ldap.app.cnf
-from web2ldap.log import logger
+from ..log import logger
+from .gui import footer, main_menu, read_template, search_root_field, top_section
 
 
 def w2l_login(
@@ -41,20 +39,20 @@ def w2l_login(
     if 'login_who' in app.form.input_field_names:
         who = app.form.field['login_who'].value[0]
 
-    login_search_root_field = web2ldap.app.gui.search_root_field(
+    login_search_root_field = search_root_field(
         app,
         name='login_search_root',
         default=str(login_search_root),
     )
 
-    login_template_str = web2ldap.app.gui.read_template(app, 'login_template', u'login form')
+    login_template_str = read_template(app, 'login_template', u'login form')
 
     if nomenu:
         main_menu_list = []
     else:
-        main_menu_list = web2ldap.app.gui.main_menu(app)
+        main_menu_list = main_menu(app)
 
-    web2ldap.app.gui.top_section(
+    top_section(
         app,
         login_msg,
         main_menu_list,
@@ -62,8 +60,8 @@ def w2l_login(
         main_div_id='Input',
     )
 
-    if app.ls.rootDSE:
-        app.form.field['login_mech'].setOptions(app.ls.supportedSASLMechanisms or [])
+    if app.ls.root_dse:
+        app.form.field['login_mech'].set_options(app.ls.supportedSASLMechanisms or [])
 
     # Determine the bind mech to be used from the
     # form data or the key-word argument login_default_mech
@@ -75,11 +73,11 @@ def w2l_login(
         login_msg_html = ''
 
     login_form_html = login_template_str.format(
-        text_heading=app.form.utf2display(title_msg),
+        text_heading=app.form.s2d(title_msg),
         text_error=login_msg_html,
         field_login_mech=app.form.field['login_mech'].input_html(default=login_mech),
-        value_ldap_who=app.form.utf2display(who or u''),
-        value_ldap_mapping=app.form.utf2display(app.binddn_mapping),
+        value_ldap_who=app.form.s2d(who or u''),
+        value_ldap_mapping=app.form.s2d(app.binddn_mapping),
         field_login_search_root=login_search_root_field.input_html(),
         field_login_authzid_prefix=app.form.field['login_authzid_prefix'].input_html(),
         value_submit={False:'Login', True:'Retry w/login'}[relogin],
@@ -90,7 +88,7 @@ def w2l_login(
     if not scope_str and app.ldap_url.scope is not None:
         scope_str = str(app.ldap_url.scope)
     if scope_str:
-        scope_hidden_field = app.form.hiddenFieldHTML('scope', scope_str, u'')
+        scope_hidden_field = app.form.hidden_field_html('scope', scope_str, u'')
     else:
         scope_hidden_field = ''
 
@@ -102,15 +100,17 @@ def w2l_login(
     else:
         filterstr = app.ldap_url.filterstr or ''
     if filterstr:
-        filterstr_hidden_field = app.form.hiddenFieldHTML('filterstr', filterstr, u'')
+        filterstr_hidden_field = app.form.hidden_field_html('filterstr', filterstr, u'')
     else:
         filterstr_hidden_field = ''
 
     search_attrs_hidden_field = ''
     if 'search_attrs' in app.form.field:
-        search_attrs = app.form.getInputValue('search_attrs', [u','.join(app.ldap_url.attrs or [])])[0]
+        search_attrs = app.form.getInputValue(
+            'search_attrs', [u','.join(app.ldap_url.attrs or [])]
+        )[0]
         if search_attrs:
-            search_attrs_hidden_field = app.form.hiddenFieldHTML('search_attrs', search_attrs, u'')
+            search_attrs_hidden_field = app.form.hidden_field_html('search_attrs', search_attrs, u'')
 
     # determine which command will be put in form's action attribute
     if not app.command or app.command == 'login':
@@ -123,10 +123,10 @@ def w2l_login(
     app.outf.write(
         '\n'.join((
             app.form.begin_form(action_command, None, 'POST', None),
-            app.form.hiddenFieldHTML('ldapurl', str(app.ls.ldap_url('')), u''),
-            app.form.hiddenFieldHTML('dn', app.dn, u''),
-            app.form.hiddenFieldHTML('delsid', app.sid, u''),
-            app.form.hiddenFieldHTML('conntype', str(int(app.ls.startTLSOption > 0)), u''),
+            app.form.hidden_field_html('ldapurl', str(app.ls.ldap_url('')), u''),
+            app.form.hidden_field_html('dn', app.dn, u''),
+            app.form.hidden_field_html('delsid', app.sid, u''),
+            app.form.hidden_field_html('conntype', str(int(app.ls.use_start_tls > 0)), u''),
             scope_hidden_field,
             filterstr_hidden_field,
             login_form_html,
@@ -135,8 +135,8 @@ def w2l_login(
     )
     if relogin:
         app.outf.write(
-            app.form.hiddenInputHTML(
-                ignoreFieldNames=set([
+            app.form.hidden_input_html(
+                ignored_fields=set([
                     'sid', 'delsid',
                     'ldapurl', 'conntype', 'host', 'who', 'cred',
                     'dn', 'scope', 'filterstr', 'search_attrs',
@@ -146,4 +146,4 @@ def w2l_login(
             )
         )
     app.outf.write('</form>\n')
-    web2ldap.app.gui.footer(app)
+    footer(app)
