@@ -20,28 +20,35 @@ import ldap0.schema
 from ldap0.schema.models import AttributeType
 from ldap0.schema.util import modify_modlist
 
-import web2ldap.ldapsession
-import web2ldap.app.core
-import web2ldap.app.cnf
-import web2ldap.app.gui
-import web2ldap.app.add
-import web2ldap.app.schema
-from web2ldap.app.schema.syntaxes import syntax_registry
-from .addmodifyform import w2l_modifyform, get_entry_input, read_old_entry
+from . import ErrorExit
+from .schema.syntaxes import syntax_registry
+from .add import ADD_IGNORE_ATTR_TYPES
+from .addmodifyform import (
+    cfg_constant_attributes,
+    w2l_modifyform,
+    get_entry_input,
+    read_old_entry,
+)
+from .gui import (
+    context_menu_single_entry,
+    invalid_syntax_message,
+    extract_invalid_syntax,
+    main_menu,
+)
 
 
 def modlist_ldif(dn, form, modlist):
     """
     Return a string containing a HTML-formatted LDIF change record
     """
-    s = []
-    s.append('<pre>')
-    f = BytesIO()
-    ldif_writer = ldap0.ldif.LDIFWriter(f)
+    lines = []
+    lines.append('<pre>')
+    bio = BytesIO()
+    ldif_writer = ldap0.ldif.LDIFWriter(bio)
     ldif_writer.unparse(dn.encode('utf-8'), modlist)
-    s.append(form.utf2display(f.getvalue().decode('utf-8')).replace('\n', '<br>'))
-    s.append('</pre>')
-    return ''.join(s) # modlist_ldif()
+    lines.append(form.s2d(bio.getvalue().decode('utf-8')).replace('\n', '<br>'))
+    lines.append('</pre>')
+    return ''.join(lines)
 
 
 ##############################################################################
@@ -70,14 +77,16 @@ def w2l_modify(app):
         app.form.field['in_avi'].value = map(str, range(0, len(app.form.field['in_av'].value)))
     elif input_modrow[0] == '+':
         insert_row_num = int(input_modrow[1:])
-        app.form.field['in_at'].value.insert(insert_row_num+1, app.form.field['in_at'].value[insert_row_num])
+        app.form.field['in_at'].value.insert(
+            insert_row_num+1, app.form.field['in_at'].value[insert_row_num]
+        )
         app.form.field['in_av'].value.insert(insert_row_num+1, '')
         app.form.field['in_avi'].value = map(str, range(0, len(app.form.field['in_av'].value)))
 
     new_entry, invalid_attrs = get_entry_input(app)
 
     if invalid_attrs:
-        error_msg = web2ldap.app.gui.invalid_syntax_message(app, invalid_attrs)
+        error_msg = invalid_syntax_message(app, invalid_attrs)
     else:
         error_msg = ''
 
@@ -102,7 +111,7 @@ def w2l_modify(app):
     try:
         old_entry, dummy = read_old_entry(app, app.dn, app.schema, in_assertion)
     except ldap0.NO_SUCH_OBJECT:
-        raise web2ldap.app.core.ErrorExit(u'Old entry was removed or modified in between! You have to edit it again.')
+        raise ErrorExit(u'Old entry was removed or modified in between! You have to edit it again.')
 
     # Filter out empty values
     for attr_type, attr_values in new_entry.items():
@@ -112,7 +121,7 @@ def w2l_modify(app):
     ignore_attr_types = ldap0.schema.models.SchemaElementOIDSet(
         app.schema,
         AttributeType,
-        web2ldap.app.add.ADD_IGNORE_ATTR_TYPES,
+        ADD_IGNORE_ATTR_TYPES,
     )
 
     if not app.ls.relax_rules:
@@ -120,7 +129,7 @@ def w2l_modify(app):
         # ignore all attributes which have NO-USER-MODIFICATION set
         ignore_attr_types.update(app.schema.no_user_mod_attr_oids)
         # Ignore attributes which are assumed to be constant (some operational attributes)
-        ignore_attr_types.update(web2ldap.app.addmodifyform.ConfiguredConstantAttributes(app).values())
+        ignore_attr_types.update(cfg_constant_attributes(app).values())
 
     # All attributes currently read which were not visible before
     # must be ignored to avoid problems with different access rights
@@ -163,10 +172,10 @@ def w2l_modify(app):
         app.simple_message(
             'Modify result',
             '<p class="SuccessMessage">No attributes modified of entry %s</p>' % (
-                app.display_dn(app.dn, commandbutton=True),
+                app.display_dn(app.dn, links=True),
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
+            main_menu_list=main_menu(app),
+            context_menu_list=context_menu_single_entry(app)
         )
         return
 
@@ -179,15 +188,19 @@ def w2l_modify(app):
             assertion_filter=in_assertion,
         )
     except ldap0.ASSERTION_FAILED:
-        raise web2ldap.app.core.ErrorExit(
+        raise ErrorExit(
             'Assertion failed '
             '=> Entry was removed or modified in between! '
             'You have to edit it again.'
         )
+    except ldap0.INVALID_SYNTAX as err:
+        error_msg, invalid_attrs = extract_invalid_syntax(app, err)
+        # go back to input form so the user can correct something
+        w2l_modifyform(app, new_entry, msg=error_msg, invalid_attrs=invalid_attrs)
+        return
     except (
             ldap0.CONSTRAINT_VIOLATION,
             ldap0.INVALID_DN_SYNTAX,
-            ldap0.INVALID_SYNTAX,
             ldap0.NAMING_VIOLATION,
             ldap0.OBJECT_CLASS_VIOLATION,
             ldap0.OTHER,
@@ -202,10 +215,14 @@ def w2l_modify(app):
     # Display success message
     app.simple_message(
         'Modify result',
-        '<p class="SuccessMessage">Modified entry %s</p><dt>LDIF change record:</dt>\n<dd>%s</dd>' % (
-            app.display_dn(app.dn, commandbutton=True),
+        (
+            '<p class="SuccessMessage">Modified entry %s</p>\n'
+            '<dt>LDIF change record:</dt>\n'
+            '<dd>%s</dd>\n'
+        ) % (
+            app.display_dn(app.dn, links=True),
             modlist_ldif(app.dn, app.form, modlist),
         ),
-        main_menu_list=web2ldap.app.gui.main_menu(app),
-        context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
+        main_menu_list=main_menu(app),
+        context_menu_list=context_menu_single_entry(app)
     )
