@@ -20,16 +20,19 @@ import pwd
 
 import web2ldapcnf
 
-import web2ldap.__about__
-import web2ldap.app.gui
-import web2ldap.app.handler
-from web2ldap.app.session import session_store
-from web2ldap.utctime import strftimeiso8601
-from ..ldapsession import LDAPSession
+from ..__about__ import __version__
+from ..utctime import strftimeiso8601
 from ..log import EXC_TYPE_COUNTER
-from .core import STARTUP_TIME
+from ..ldapsession import LDAPSession
+from .. import STARTUP_TIME
+from .gui import (
+    footer,
+    simple_main_menu,
+    top_section,
+)
+from .session import session_store
 from .metrics import METRICS_AVAIL
-
+from .stats import COMMAND_COUNT
 
 MONITOR_TEMPLATE = """
 <h1>Monitor</h1>
@@ -183,20 +186,15 @@ def w2l_monitor(app):
     posix_uid, posix_username = get_user_info()
     _session_store = session_store()
 
-    web2ldap.app.gui.top_section(
-        app,
-        'Monitor',
-        web2ldap.app.gui.simple_main_menu(app),
-        [],
-    )
+    top_section(app, 'Monitor', simple_main_menu(app), [])
 
     monitor_tmpl_vars = dict(
         text_metricsurl=METRICS_AVAIL*app.anchor('metrics', 'Metrics endpoint', []),
-        text_version=web2ldap.__about__.__version__,
+        text_version=__version__,
         text_sysfqdn=socket.getfqdn(),
         int_pid=os.getpid(),
         int_ppid=os.getppid(),
-        text_username=app.form.utf2display(posix_username or '-/-'),
+        text_username=app.form.s2d(posix_username or '-/-'),
         int_uid=posix_uid,
         text_currenttime=strftimeiso8601(time.gmtime(time.time())),
         text_startuptime=strftimeiso8601(time.gmtime(STARTUP_TIME)),
@@ -206,7 +204,7 @@ def w2l_monitor(app):
             [
                 '<li>%s</li>' % ''.join(
                     [
-                        app.form.utf2display(str(repr(t))),
+                        app.form.s2d(str(repr(t))),
                         ', alive'*t.is_alive(),
                         ', daemon'*t.isDaemon(),
                     ]
@@ -225,7 +223,7 @@ def w2l_monitor(app):
         text_remoteiphitlist='\n'.join(
             [
                 '<tr><td>%s</td><td>%d</td></tr>' % (
-                    app.form.utf2display((ip or '-')),
+                    app.form.s2d((ip or '-')),
                     count,
                 )
                 for ip, count in _session_store.remote_ip_counter.most_common()
@@ -234,16 +232,16 @@ def w2l_monitor(app):
         text_cmd_counters='\n'.join(
             [
                 '<tr><td>%s</td><td>%d</td></tr>' % (
-                    app.form.utf2display(cmd),
+                    app.form.s2d(cmd),
                     ctr,
                 )
-                for cmd, ctr in sorted(web2ldap.app.handler.COMMAND_COUNT.items())
+                for cmd, ctr in sorted(COMMAND_COUNT.items())
             ]
         ),
         text_exc_counters='\n'.join(
             [
                 '<tr><td>%s</td><td>%d</td></tr>' % (
-                    app.form.utf2display(str(exc_type)),
+                    app.form.s2d(str(exc_type)),
                     exc_ctr,
                 )
                 for exc_type, exc_ctr in EXC_TYPE_COUNTER.items()
@@ -269,10 +267,10 @@ def w2l_monitor(app):
                     len(real_ldap_sessions),
                     '\n'.join([
                         '<tr><td>{}</td><td>{}</td><td>{}</td><td>{}</td></tr>'.format(
-                            app.form.utf2display((i[1].onBehalf or '') or u'unknown'),
+                            app.form.s2d((i[1].on_behalf or '') or u'unknown'),
                             strftimeiso8601(time.gmtime(i[0])),
-                            app.form.utf2display(i[1].uri or u'no connection'),
-                            app.form.utf2display(i[1].who or u'anonymous'),
+                            app.form.s2d(i[1].uri or u'no connection'),
+                            app.form.s2d(i[1].who or u'anonymous'),
                         )
                         for k, i in real_ldap_sessions
                     ]),
@@ -293,4 +291,4 @@ def w2l_monitor(app):
     else:
         app.outf.write('No active sessions.\n')
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
