@@ -12,12 +12,13 @@ Apache License Version 2.0 (Apache-2.0)
 https://www.apache.org/licenses/LICENSE-2.0
 """
 
-import web2ldap.ldapsession
-import web2ldap.app.cnf
-import web2ldap.app.core
-import web2ldap.app.gui
-from web2ldap.ldaputil.oidreg import OID_REG
-from web2ldap.ldapsession import AVAILABLE_BOOLEAN_CONTROLS
+from ..ldaputil.oidreg import OID_REG
+from ..ldapsession import AVAILABLE_BOOLEAN_CONTROLS
+from .gui import (
+    footer,
+    main_menu,
+    top_section,
+)
 
 
 ##############################################################################
@@ -31,10 +32,10 @@ def w2l_params(app):
     if ldap_deref:
         app.ls.l.deref = int(ldap_deref[0])
 
-    web2ldap.app.gui.top_section(
+    top_section(
         app,
         'LDAP Connection Parameters',
-        web2ldap.app.gui.main_menu(app),
+        main_menu(app),
         context_menu_list=[]
     )
 
@@ -77,7 +78,11 @@ def w2l_params(app):
     control_table_rows = []
     for control_oid in AVAILABLE_BOOLEAN_CONTROLS:
         control_enabled = (control_oid in enabled_controls)
-        if not (control_enabled or ldapparam_all_controls or control_oid in app.ls.supportedControl):
+        if not (
+                control_enabled
+                or ldapparam_all_controls
+                or control_oid in app.ls.supportedControl
+            ):
             continue
         name, description, _ = OID_REG[control_oid]
         control_table_rows.append(
@@ -108,10 +113,10 @@ def w2l_params(app):
                     ),
                 ),
                 {False:'<strike>', True:''}[control_oid in app.ls.supportedControl],
-                app.form.utf2display(name),
+                app.form.s2d(name),
                 {False:'</strike>', True:''}[control_oid in app.ls.supportedControl],
-                app.form.utf2display(control_oid),
-                app.form.utf2display(description),
+                app.form.s2d(control_oid),
+                app.form.s2d(description),
             )
         )
 
@@ -158,4 +163,4 @@ def w2l_params(app):
         )
     )
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
