@@ -19,19 +19,25 @@ from ldap0.pw import random_string, unicode_pwd, ntlm_password_hash, PWD_ALPHABE
 from ldap0.schema.models import AttributeType, ObjectClass, SchemaElementOIDSet
 from ldap0.extop.passmod import PassmodRequest
 
-import web2ldap.web.forms
-import web2ldap.ldapsession
-import web2ldap.app.cnf
-import web2ldap.app.core
-import web2ldap.app.gui
-import web2ldap.app.login
-from web2ldap.ldaputil.passwd import user_password_hash
-from web2ldap.app.form import Web2LDAPForm_passwd
+from ..ldapsession import CONTROL_RELAXRULES
+from ..ldaputil.passwd import user_password_hash, AVAIL_USERPASSWORD_SCHEMES
+from .form import Web2LDAPFormPasswd
+from . import ErrorExit
+from .gui import (
+    context_menu_single_entry,
+    footer,
+    main_menu,
+    read_template,
+    top_section,
+    HTML_OFF_S,
+    HTML_OFF_E,
+)
+from .login import w2l_login
 
 
 PASSWD_ACTIONS_DICT = {
     action: (short_desc, long_desc)
-    for action, short_desc, long_desc in Web2LDAPForm_passwd.passwd_actions
+    for action, short_desc, long_desc in Web2LDAPFormPasswd.passwd_actions
 }
 
 PASSWD_GEN_DEFAULT_LENGTH = 20
@@ -41,7 +47,6 @@ PASSWD_USERPASSWORD_OBJECT_CLASSES = (
     'simpleAuthObject',
 )
 
-
 def get_all_attributes(schema, oc_list):
     """
     returns single dictionary with all possible attributes
@@ -65,7 +70,7 @@ def password_change_url(app, passwd_who, passwd_input):
     passwd_who_ldapurl_obj.scope = ldap0.SCOPE_BASE
     passwd_who_ldapurl_obj.who = passwd_who
     passwd_who_ldapurl_obj.cred = passwd_input
-    passwd_who_ldapurl_obj.saslMech = None
+    passwd_who_ldapurl_obj.sasl_mech = None
     return '?'.join((
         app.form.action_url('passwd', None),
         str(passwd_who_ldapurl_obj),
@@ -86,12 +91,12 @@ def passwd_context_menu(app):
             ],
             title=long_desc
         )
-        for pa, short_desc, long_desc in Web2LDAPForm_passwd.passwd_actions
+        for pa, short_desc, long_desc in Web2LDAPFormPasswd.passwd_actions
     ]
     # Menu entry for unlocking entry
     delete_param_list = [
         ('dn', app.dn),
-        ('delete_ctrl', web2ldap.ldapsession.CONTROL_RELAXRULES),
+        ('delete_ctrl', CONTROL_RELAXRULES),
     ]
     delete_param_list.extend([
         ('delete_attr', attr_type)
@@ -144,11 +149,11 @@ def passwd_context_menu(app):
     return result
 
 
-def password_self_change(ls, dn):
+def password_self_change(who, dn):
     """
     returns True, if user changes own password
     """
-    return (ls.who is None) or (ls.who == dn)
+    return (who is None) or (who == dn)
 
 
 def passwd_form(
@@ -165,7 +170,7 @@ def passwd_form(
 
     # depending on the calling code part the necessary
     # input fields must be added to the form
-    for field in Web2LDAPForm_passwd.passwd_fields():
+    for field in Web2LDAPFormPasswd.passwd_fields():
         if field.name not in app.form.field:
             app.form.add_field(field)
 
@@ -176,7 +181,7 @@ def passwd_form(
     unicode_pwd_avail = '1.2.840.113556.1.4.90' in app.schema.sed[AttributeType]
 
     # Determine whether user changes own password
-    own_pwd_change = password_self_change(app.ls, passwd_who)
+    own_pwd_change = password_self_change(app.ls.who, passwd_who)
 
     all_attrs = get_all_attributes(app.schema, user_objectclasses)
 
@@ -187,7 +192,7 @@ def passwd_form(
             # The set of hash types are restricted by local configuration
             default_hashtypes = [
                 hash_type
-                for hash_type in web2ldap.ldaputil.passwd.AVAIL_USERPASSWORD_SCHEMES.items()
+                for hash_type in AVAIL_USERPASSWORD_SCHEMES.items()
                 if hash_type[0] in config_hashtypes
             ]
             app.form.field['passwd_scheme'].options = default_hashtypes
@@ -195,45 +200,47 @@ def passwd_form(
     nthash_available = '1.3.6.1.4.1.7165.2.1.25' in all_attrs
     show_clientside_pw_fields = passwd_action == 'setuserpassword' and not unicode_pwd_avail
 
-    passwd_template_str = web2ldap.app.gui.read_template(
+    passwd_template_str = read_template(
         app,
         'passwd_template',
         'password form',
     )
 
-    web2ldap.app.gui.top_section(
+    top_section(
         app,
         'Change password',
-        web2ldap.app.gui.main_menu(app),
+        main_menu(app),
         context_menu_list=passwd_context_menu(app),
         main_div_id='Input',
     )
 
     app.outf.write(passwd_template_str.format(
         text_heading=heading,
-        text_msg=error_msg or app.form.utf2display(PASSWD_ACTIONS_DICT[passwd_action][1]),
+        text_msg=error_msg or app.form.s2d(PASSWD_ACTIONS_DICT[passwd_action][1]),
         form_begin=app.begin_form('passwd', 'POST'),
-        value_dn=app.form.hiddenFieldHTML('dn', app.dn, ''),
-        value_passwd_action=app.form.hiddenFieldHTML('passwd_action', passwd_action, ''),
-        value_passwd_who=app.form.hiddenFieldHTML('passwd_who', passwd_who, ''),
+        value_dn=app.form.hidden_field_html('dn', app.dn, ''),
+        value_passwd_action=app.form.hidden_field_html('passwd_action', passwd_action, ''),
+        value_passwd_who=app.form.hidden_field_html('passwd_who', passwd_who, ''),
         text_desc={False:'Change password for', True:'Change own password of'}[own_pwd_change],
-        text_whoami=web2ldap.app.gui.display_authz_dn(app, passwd_who),
-        disable_oldpw_start={False:'', True:'<!--'}[not own_pwd_change],
-        disable_oldpw_end={False:'', True:'-->'}[not own_pwd_change],
-        disable_ownuser_start={False:'', True:'<!--'}[own_pwd_change],
-        disable_ownuser_end={False:'', True:'-->'}[own_pwd_change],
-        disable_clientsidehashing_start={False:'', True:'<!--'}[not show_clientside_pw_fields],
-        disable_clientsidehashing_end={False:'', True:'-->'}[not show_clientside_pw_fields],
-        disable_syncnthash_start={False:'', True:'<!--'}[not (show_clientside_pw_fields and nthash_available)],
-        disable_syncnthash_end={False:'', True:'-->'}[not (show_clientside_pw_fields and nthash_available)],
-        disable_settimesync_start={False:'', True:'<!--'}[own_pwd_change or not show_clientside_pw_fields],
-        disable_settimesync_end={False:'', True:'-->'}[own_pwd_change or not show_clientside_pw_fields],
+        text_whoami=app.display_authz_dn(passwd_who),
+        disable_oldpw_start=HTML_OFF_S[not own_pwd_change],
+        disable_oldpw_end=HTML_OFF_E[not own_pwd_change],
+        disable_ownuser_start=HTML_OFF_S[own_pwd_change],
+        disable_ownuser_end=HTML_OFF_E[own_pwd_change],
+        disable_clientsidehashing_start=HTML_OFF_S[not show_clientside_pw_fields],
+        disable_clientsidehashing_end=HTML_OFF_E[not show_clientside_pw_fields],
+        disable_syncnthash_start=HTML_OFF_S[not (show_clientside_pw_fields and nthash_available)],
+        disable_syncnthash_end=HTML_OFF_E[not (show_clientside_pw_fields and nthash_available)],
+        disable_settimesync_start=HTML_OFF_S[own_pwd_change or not show_clientside_pw_fields],
+        disable_settimesync_end=HTML_OFF_E[own_pwd_change or not show_clientside_pw_fields],
         form_field_passwd_scheme=app.form.field['passwd_scheme'].input_html(),
         form_field_passwd_ntpasswordsync=app.form.field['passwd_ntpasswordsync'].input_html(),
-        form_field_passwd_settimesync=app.form.field['passwd_settimesync'].input_html(checked=(not own_pwd_change)),
+        form_field_passwd_settimesync=app.form.field['passwd_settimesync'].input_html(
+            checked=(not own_pwd_change)
+        ),
     ))
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
     # end of passwd_form()
 
 
@@ -253,11 +260,16 @@ def w2l_passwd(app):
     passwd_action = app.form.getInputValue('passwd_action', [None])[0] or passwd_action_default
     passwd_who = app.form.getInputValue('passwd_who', [app.dn])[0]
 
-    user = app.ls.l.read_s(passwd_who, attrlist=['objectClass'])
+    try:
+        user = app.ls.l.read_s(passwd_who, attrlist=['objectClass'])
+    except ldap0.INSUFFICIENT_ACCESS:
+        user_entry = {}
+    else:
+        user_entry = user.entry_s
     user_objectclasses = SchemaElementOIDSet(
         app.schema,
         ObjectClass,
-        user.entry_s.get('objectClass', []),
+        user_entry.get('objectClass', []),
     )
 
     if 'passwd_newpasswd' not in app.form.input_field_names:
@@ -277,7 +289,7 @@ def w2l_passwd(app):
     #----------------------------------------------
 
     if len(app.form.field['passwd_newpasswd'].value) != 2:
-        raise web2ldap.app.core.ErrorExit('Repeat password!')
+        raise ErrorExit('Repeat password!')
 
     if app.form.field['passwd_newpasswd'].value[0] != app.form.field['passwd_newpasswd'].value[1]:
         passwd_form(
@@ -329,12 +341,12 @@ def w2l_passwd(app):
         except (
                 ldap0.CONSTRAINT_VIOLATION,
                 ldap0.UNWILLING_TO_PERFORM,
-            ) as e:
+            ) as err:
             passwd_form(
                 app,
                 passwd_action, passwd_who, user_objectclasses,
                 heading='Password Error',
-                error_msg=app.ldap_error_msg(e)
+                error_msg=app.ldap_error_msg(err)
             )
             return
         else:
@@ -342,7 +354,7 @@ def w2l_passwd(app):
                 app.ls.modify(passwd_who, passwd_modlist)
             if no_passwd_input:
                 password_attr_types_msg = 'Generated password set by the server: %s' % (
-                    app.form.utf2display(passwd_input)
+                    app.form.s2d(passwd_input)
                 )
             else:
                 password_attr_types_msg = 'Password set by the server.'
@@ -369,7 +381,9 @@ def w2l_passwd(app):
                     # Ensure supplemental class is not already in set of object classes
                     if aux_class in user_objectclasses:
                         continue
-                    passwd_modlist.append((ldap0.MOD_ADD, b'objectClass', [aux_class.encode('ascii')]))
+                    passwd_modlist.append(
+                        (ldap0.MOD_ADD, b'objectClass', [aux_class.encode('ascii')])
+                    )
                     break
                 except KeyError:
                     pass
@@ -394,7 +408,7 @@ def w2l_passwd(app):
             if old_password:
                 old_passwd_value = user_password_hash(old_password.encode(app.ls.charset), '')
 
-        if password_self_change(app.ls, passwd_who) and old_password:
+        if password_self_change(app.ls.who, passwd_who) and old_password:
             passwd_modlist.extend((
                 (
                     ldap0.MOD_DELETE,
@@ -451,13 +465,13 @@ def w2l_passwd(app):
 
         password_attr_types_msg = 'Password-related attributes set: %s' % (', '.join(
             [
-                app.form.utf2display(attr_type.decode('ascii'))
+                app.form.s2d(attr_type.decode('ascii'))
                 for _, attr_type, _ in passwd_modlist
             ]
         ))
         if no_passwd_input:
             password_attr_types_msg += '<br>Generated password is: %s' % (
-                app.form.utf2display(passwd_input)
+                app.form.s2d(passwd_input)
             )
 
         # Modify password
@@ -467,27 +481,27 @@ def w2l_passwd(app):
         except (
                 ldap0.CONSTRAINT_VIOLATION,
                 ldap0.UNWILLING_TO_PERFORM,
-            ) as e:
+            ) as err:
             passwd_form(
                 app,
                 passwd_action, passwd_who, user_objectclasses,
                 heading='Password Error',
-                error_msg=app.ldap_error_msg(e)
+                error_msg=app.ldap_error_msg(err)
             )
             return
-        except ldap0.NO_SUCH_ATTRIBUTE as e:
+        except ldap0.NO_SUCH_ATTRIBUTE as err:
             passwd_form(
                 app,
                 passwd_action, passwd_who, user_objectclasses,
                 heading='Password Error',
                 error_msg=app.ldap_error_msg(
-                    e, template=r"%s (Hint: Try without old password.)"
+                    err, template=r"%s (Hint: Try without old password.)"
                 )
             )
             return
 
     # Check if relogin is necessary
-    if password_self_change(app.ls, passwd_who):
+    if password_self_change(app.ls.who, passwd_who):
         # Force current connection to anonymous
         try:
             app.ls.l.reconnect(app.ls.uri, reset_last_bind=True)
@@ -496,7 +510,7 @@ def w2l_passwd(app):
         app.ls.who = None
         # Display login form with search form as landing page
         app.command = 'searchform'
-        web2ldap.app.login.w2l_login(
+        w2l_login(
             app,
             login_msg='New login is required!<br>'+password_attr_types_msg,
             who=passwd_who,
@@ -520,8 +534,8 @@ def w2l_passwd(app):
                 password_attr_types_msg,
                 passwd_link,
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.context_menu_single_entry(app)
+            main_menu_list=main_menu(app),
+            context_menu_list=context_menu_single_entry(app)
         )
 
     # end of w2l_passwd()
