@@ -11,13 +11,12 @@ from typing import Dict
 from ldap0.dn import is_dn
 from ldap0.msad import sid2sddl, sddl2sid
 
-import web2ldapcnf
-
-import web2ldap.web.forms
-import web2ldap.app.searchform
-from web2ldap.utctime import strftimeiso8601
-from web2ldap.app.plugins.groups import GroupEntryDN
-from web2ldap.app.schema.syntaxes import (
+from ... import ETC_DIR
+from ...web.forms import Field, Textarea
+from ...utctime import strftimeiso8601
+from ..searchform import SEARCH_OPT_IS_EQUAL
+from .groups import GroupEntryDN
+from ..schema.syntaxes import (
     Binary,
     BitArrayInteger,
     Boolean,
@@ -73,8 +72,8 @@ class ObjectVersion(Integer, SelectList):
         '14247': 'Exchange 2010 SP2',
     }
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        return SelectList.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        return SelectList.display(self, vidx, links)
 
 # Register certain attribute types for syntax classes
 syntax_registry.reg_at(
@@ -97,26 +96,26 @@ class ObjectSID(OctetString, IA5String):
           [32 bits]
     """
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return OctetString._validate(self, attrValue)
+    def _validate(self, attr_value: bytes) -> bool:
+        return OctetString._validate(self, attr_value)
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        if not attrValue:
+    def sanitize(self, attr_value: bytes) -> bytes:
+        if not attr_value:
             return b''
-        return sddl2sid(attrValue.decode('ascii'))
+        return sddl2sid(attr_value.decode('ascii'))
 
-    def formValue(self) -> str:
+    def form_value(self) -> str:
         if not self._av:
             return ''
         return sid2sddl(self._av)
 
-    def formField(self) -> web2ldap.web.forms.Field:
-        return IA5String.formField(self)
+    def input_field(self) -> Field:
+        return IA5String.input_field(self)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         return '%s<br>%s' % (
-            self._app.form.utf2display(sid2sddl(self._av)),
-            OctetString.display(self, valueindex, commandbutton),
+            self._app.form.s2d(sid2sddl(self._av)),
+            OctetString.display(self, vidx, links),
         )
 
 syntax_registry.reg_at(
@@ -179,25 +178,25 @@ class OtherSID(ObjectSID):
         'S-1-5-32-556': 'BUILTIN_NETWORK_CONF_OPERATORS',
     }
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         sddl_str = sid2sddl(self._av)
         search_anchor = self.well_known_sids.get(sddl_str, '')
-        if commandbutton and sddl_str not in self.well_known_sids:
+        if links and sddl_str not in self.well_known_sids:
             search_anchor = self._app.anchor(
                 'searchform', '&raquo;',
                 [
                     ('dn', self._dn),
                     ('searchform_mode', 'adv'),
                     ('search_attr', 'objectSid'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
                     ('search_string', sddl_str),
                 ],
                 title='Search by SID',
             )
         return '%s %s<br>%s' % (
-            self._app.form.utf2display(sddl_str),
+            self._app.form.s2d(sddl_str),
             search_anchor,
-            OctetString.display(self, valueindex, commandbutton),
+            OctetString.display(self, vidx, links),
         )
 
 syntax_registry.reg_at(
@@ -214,7 +213,7 @@ syntax_registry.reg_at(
 class SAMAccountName(DirectoryString):
     oid: str = 'SAMAccountName-oid'
     desc: str = 'SAM-Account-Name in MS AD'
-    maxLen: int = 20
+    max_len: int = 20
 
 # Register certain attribute types for syntax classes
 syntax_registry.reg_at(
@@ -419,13 +418,13 @@ class LogonHours(OctetString):
                 hour_flags.append({0:'-', 1:'X'}[(eight_hours>>i)&1])
         return hour_flags
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        if not attrValue:
+    def sanitize(self, attr_value: bytes) -> bytes:
+        if not attr_value:
             return b''
-        attrValue = attrValue.replace(b'\r', b'').replace(b'\n', b'')
+        attr_value = attr_value.replace(b'\r', b'').replace(b'\n', b'')
         hour_flags = [
-            int(attrValue[i:i+1] == b'X')<<i%8
-            for i in range(len(attrValue))
+            int(attr_value[i:i+1] == b'X')<<i%8
+            for i in range(len(attr_value))
         ]
         res = [
             sum(hour_flags[i*8:(i+1)*8])
@@ -433,10 +432,10 @@ class LogonHours(OctetString):
         ]
         return bytes(res)
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return len(attrValue) == 21
+    def _validate(self, attr_value: bytes) -> bool:
+        return len(attr_value) == 21
 
-    def formValue(self) -> str:
+    def form_value(self) -> str:
         hour_flags = self._extract_hours(self._av)
         if hour_flags:
             day_bits = [
@@ -447,19 +446,19 @@ class LogonHours(OctetString):
             day_bits = []
         return '\r\n'.join(day_bits)
 
-    def formField(self) -> web2ldap.web.forms.Field:
-        return web2ldap.web.forms.Textarea(
+    def input_field(self) -> Field:
+        return Textarea(
             self._at,
             ': '.join([self._at, self.desc]),
-            self.maxLen,
+            self.max_len,
             1,
             None,
-            default=self.formValue(),
+            default=self.form_value(),
             rows=7,
             cols=24,
         )
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         hour_flags = self._extract_hours(self._av)
         result_lines = [
             """<tr>
@@ -483,7 +482,7 @@ class LogonHours(OctetString):
                 )
             )
         return '<p>%s</p><table>%s</table>' % (
-            OctetString.display(self, valueindex, commandbutton),
+            OctetString.display(self, vidx, links),
             '\n'.join(result_lines)
         )
 
@@ -499,16 +498,16 @@ class CountryCode(PropertiesSelectList):
     oid: str = 'CountryCode-oid'
     desc: str = 'Numerical country code'
     properties_pathname = os.path.join(
-        web2ldapcnf.etc_dir, 'properties', 'attribute_select_countryCode.properties'
+        ETC_DIR, 'properties', 'attribute_select_countryCode.properties'
     )
-    simpleSanitizers = (
+    sani_funcs = (
         bytes.strip,
     )
 
-    def _get_attr_value_dict(self):
+    def get_attr_value_dict(self) -> Dict[str, str]:
         # Enable empty value in any case
         attr_value_dict: Dict[str, str] = {'0': '-/-'}
-        attr_value_dict.update(PropertiesSelectList._get_attr_value_dict(self))
+        attr_value_dict.update(PropertiesSelectList.get_attr_value_dict(self))
         del attr_value_dict['']
         return attr_value_dict
 
@@ -530,7 +529,11 @@ class InstanceType(BitArrayInteger):
         ('This replica is not instantiated.', 0x00000002),
         ('The object is writable on this directory.', 0x00000004),
         ('The naming context above this one on this directory is held.', 0x00000008),
-        ('The naming context is in the process of being constructed for the first time via replication.', 0x00000010),
+        (
+            'The naming context is in the process of being '
+            'constructed for the first time via replication.',
+            0x00000010
+        ),
         ('The naming context is in the process of being removed from the local DSA.', 0x00000020),
     )
 
@@ -546,9 +549,9 @@ class DNWithOctetString(DistinguishedName):
     desc: str = 'DNWithOctetString'
     octetTag = 'B'
 
-    def _validate(self, attrValue: bytes) -> bool:
+    def _validate(self, attr_value: bytes) -> bool:
         try:
-            octet_tag, count, octet_string, dn = self._app.ls.uc_decode(attrValue)[0].split(':')
+            octet_tag, count, octet_string, dn = self._app.ls.uc_decode(attr_value)[0].split(':')
         except ValueError:
             return False
         try:
@@ -557,19 +560,16 @@ class DNWithOctetString(DistinguishedName):
             return False
         return len(octet_string) == count and octet_tag.upper() == self.octetTag and is_dn(dn)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         try:
             octet_tag, count, octet_string, dn = self.av_u.split(':')
         except ValueError:
-            return self._app.form.utf2display(self.av_u)
+            return self._app.form.s2d(self.av_u)
         return ':'.join([
-            self._app.form.utf2display(octet_tag),
-            self._app.form.utf2display(count),
-            self._app.form.utf2display(octet_string),
-            self._app.display_dn(
-                dn,
-                commandbutton=commandbutton,
-            )
+            self._app.form.s2d(octet_tag),
+            self._app.form.s2d(count),
+            self._app.form.s2d(octet_string),
+            self._app.display_dn(dn, links=links),
         ])
 
 
@@ -593,18 +593,18 @@ class MsAdGUID(OctetString):
     oid: str = 'MsAdGUID-oid'
     desc: str = 'GUID in Active Directory'
 
-    def sanitize(self, attrValue: bytes) -> bytes:
+    def sanitize(self, attr_value: bytes) -> bytes:
         try:
-            object_guid_uuid = uuid.UUID(attrValue.decode('ascii').replace(':', ''))
+            object_guid_uuid = uuid.UUID(attr_value.decode('ascii').replace(':', ''))
         except ValueError:
-            return OctetString.sanitize(self, attrValue)
+            return OctetString.sanitize(self, attr_value)
         return object_guid_uuid.bytes
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         object_guid_uuid = uuid.UUID(bytes=self._av)
         return '{%s}<br>%s' % (
             str(object_guid_uuid),
-            OctetString.display(self, valueindex=0, commandbutton=False),
+            OctetString.display(self, vidx, links),
         )
 
 syntax_registry.reg_at(
@@ -622,17 +622,17 @@ class Interval(MicrosoftLargeInteger):
     desc: str = 'Large integer with timestamp expressed as 100 nanoseconds since 1601-01-01 00:00'
 
     @staticmethod
-    def _delta(attrValue):
-        return (int(attrValue)-116444736000000000)/10000000
+    def _delta(attr_value):
+        return (int(attr_value)-116444736000000000)/10000000
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         if self.av_u == '9223372036854775807':
             return '-1: unlimited/off'
         delta = self._delta(self.av_u)
         if delta >= 0:
             return '%s (%s)' % (
-                MicrosoftLargeInteger.display(self, valueindex, commandbutton),
-                self._app.form.utf2display(str(strftimeiso8601(time.gmtime(delta)))),
+                MicrosoftLargeInteger.display(self, vidx, links),
+                self._app.form.s2d(str(strftimeiso8601(time.gmtime(delta)))),
             )
         return self.av_u
 
@@ -641,15 +641,17 @@ class LockoutTime(Interval):
     oid: str = 'LockoutTime-oid'
     desc: str = 'Timestamp of password failure lockout'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         delta = self._delta(self._av)
         if delta == 0:
-            return '%s (not locked)' % (MicrosoftLargeInteger.display(self, valueindex, commandbutton))
+            return '%s (not locked)' % (
+                MicrosoftLargeInteger.display(self, vidx, links)
+            )
         if delta < 0:
-            return MicrosoftLargeInteger.display(self, valueindex, commandbutton)
+            return MicrosoftLargeInteger.display(self, vidx, links)
         return '%s (locked since %s)' % (
-            MicrosoftLargeInteger.display(self, valueindex, commandbutton),
-            self._app.form.utf2display(str(strftimeiso8601(time.gmtime(delta)))),
+            MicrosoftLargeInteger.display(self, vidx, links),
+            self._app.form.s2d(str(strftimeiso8601(time.gmtime(delta)))),
         )
 
 syntax_registry.reg_at(
@@ -752,8 +754,8 @@ class ClassSchemaLDAPName(DynamicValueSelectList, OID):
     desc: str = 'lDAPDisplayName of the classSchema entry'
     ldap_url = 'ldap:///_?lDAPDisplayName,lDAPDisplayName?one?(objectClass=classSchema)'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        return OID.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        return OID.display(self, vidx, links)
 
 syntax_registry.reg_at(
     ClassSchemaLDAPName.oid, [
@@ -770,8 +772,8 @@ class AttributeSchemaLDAPName(DynamicValueSelectList, OID):
     desc: str = 'lDAPDisplayName of the classSchema entry'
     ldap_url = 'ldap:///_?lDAPDisplayName,lDAPDisplayName?one?(objectClass=attributeSchema)'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        return OID.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        return OID.display(self, vidx, links)
 
 syntax_registry.reg_at(
     AttributeSchemaLDAPName.oid, [
@@ -837,8 +839,8 @@ class MsDSReplAttributeMetaData(XmlValue):
     oid: str = 'MsDSReplAttributeMetaData-oid'
     editable: bool = False
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return attrValue.endswith(b'\n\x00') and XmlValue._validate(self, attrValue[:-1])
+    def _validate(self, attr_value: bytes) -> bool:
+        return attr_value.endswith(b'\n\x00') and XmlValue._validate(self, attr_value[:-1])
 
 syntax_registry.reg_at(
     MsDSReplAttributeMetaData.oid, [
