@@ -3,10 +3,14 @@
 web2ldap plugin classes for attributes defined in apple.schema
 """
 
-import web2ldap.web.forms
-import web2ldap.app.searchform
-
-from web2ldap.app.schema.syntaxes import XmlValue, UUID, DynamicValueSelectList, syntax_registry
+from ...web.forms import Field
+from ..searchform import SEARCH_OPT_IS_EQUAL
+from ..schema.syntaxes import (
+    XmlValue,
+    UUID,
+    DynamicValueSelectList,
+    syntax_registry,
+)
 
 
 syntax_registry.reg_at(
@@ -20,8 +24,8 @@ class UUIDReference(DynamicValueSelectList, UUID):
     oid: str = 'UUIDReference-oid'
     ldap_url = 'ldap:///_?apple-generateduid,entryDN?sub?(apple-generateduid=*)'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        value_disp = self._app.form.utf2display(self.av_u)
+    def display(self, vidx, links) -> str:
+        value_disp = self._app.form.s2d(self.av_u)
         return ' '.join((
             value_disp,
             self._app.anchor(
@@ -30,15 +34,15 @@ class UUIDReference(DynamicValueSelectList, UUID):
                     ('dn', self._dn),
                     ('searchform_mode', u'adv'),
                     ('search_attr', u'apple-generateduid'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
                     ('search_string', value_disp),
                 ),
                 title=u'Search entry by UUID',
             )
         ))
 
-    def formField(self) -> web2ldap.web.forms.Field:
-        return DynamicValueSelectList.formField(self)
+    def input_field(self) -> Field:
+        return DynamicValueSelectList.input_field(self)
 
 syntax_registry.reg_at(
     UUIDReference.oid, [
