@@ -5,19 +5,19 @@ web2ldap plugin classes for dynamic entries (see RFC 2589)
 
 import time
 
-from web2ldap.utctime import strftimeiso8601
+from ...utctime import strftimeiso8601
 
-from web2ldap.app.schema.syntaxes import Timespan, DistinguishedName, syntax_registry
+from ..schema.syntaxes import Timespan, DistinguishedName, syntax_registry
 
 
 class EntryTTL(Timespan):
     oid: str = 'EntryTTL-oid'
     desc: str = 'Time-to-live of dynamic entry'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         expiration_time = time.time()+int(self._av)
         return '%s, expires %s' % (
-            Timespan.display(self, valueindex, commandbutton),
+            Timespan.display(self, vidx, links),
             strftimeiso8601(time.gmtime(expiration_time)),
         )
 
