@@ -3,7 +3,7 @@
 web2ldap plugin classes for attributes used on ldap://db.debian.org
 """
 
-from web2ldap.app.schema.syntaxes import DynamicValueSelectList, syntax_registry
+from ..schema.syntaxes import DynamicValueSelectList, syntax_registry
 from .opensshlpk import SshPublicKey
 
 
