@@ -11,17 +11,21 @@ from typing import Dict
 
 import web2ldapcnf
 
-import web2ldap.app.searchform
-from web2ldap.app.schema.syntaxes import \
-    MultilineText, \
-    IA5String, \
-    SelectList, \
-    Integer, \
-    BitArrayInteger, \
-    MacAddress, \
-    DynamicDNSelectList, \
-    DNSDomain, \
-    syntax_registry
+from ..searchform import (
+    SEARCH_OPT_IS_EQUAL,
+    SEARCH_OPT_BEGINS_WITH,
+)
+from ..schema.syntaxes import (
+    MultilineText,
+    IA5String,
+    SelectList,
+    Integer,
+    BitArrayInteger,
+    MacAddress,
+    DynamicDNSelectList,
+    DNSDomain,
+    syntax_registry,
+)
 
 
 class DHCPConfigStatement(MultilineText):
@@ -29,11 +33,11 @@ class DHCPConfigStatement(MultilineText):
     desc: str = 'DHCP configuration statement'
     lineSep = b''
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         res = ['<code>%s</code>' % (
-            MultilineText.display(self, valueindex, commandbutton)
+            MultilineText.display(self, vidx, links)
         )]
-        if commandbutton:
+        if links:
             try:
                 dhcp_type, dhcp_value = self.av_u.split(' ', 1)
             except ValueError:
@@ -41,7 +45,7 @@ class DHCPConfigStatement(MultilineText):
             dhcp_type = dhcp_type.lower().strip()
             dhcp_value = dhcp_value.replace('"', '').strip()
             if dhcp_type == 'host-name':
-                host_name = dhcp_value.lower()
+                host_name = dhcp_value.lower().split('.', 1)[0]
                 res.append(self._app.anchor(
                     'search', 'DNS RR',
                     (
@@ -49,13 +53,13 @@ class DHCPConfigStatement(MultilineText):
                         ('searchform_mode', 'adv'),
                         ('search_mode', '(|%s)'),
                         ('search_attr', 'dc'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                        ('search_option', SEARCH_OPT_IS_EQUAL),
                         ('search_string', host_name),
                         ('search_attr', 'pTRRecord'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_BEGINS_WITH),
+                        ('search_option', SEARCH_OPT_BEGINS_WITH),
                         ('search_string', host_name+'.'),
                         ('search_attr', 'associatedDomain'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_BEGINS_WITH),
+                        ('search_option', SEARCH_OPT_BEGINS_WITH),
                         ('search_string', host_name+'.'),
                     ),
                     title='Search related DNS RR entry',
@@ -66,10 +70,10 @@ class DHCPConfigStatement(MultilineText):
                     ('searchform_mode', 'adv'),
                     ('search_mode', '(|%s)'),
                     ('search_attr', 'aRecord'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
                     ('search_string', dhcp_value),
                     ('search_attr', 'aAAARecord'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
                     ('search_string', dhcp_value),
                 ]
                 try:
@@ -79,7 +83,7 @@ class DHCPConfigStatement(MultilineText):
                 else:
                     search_params.extend((
                         ('search_attr', 'associatedDomain'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                        ('search_option', SEARCH_OPT_IS_EQUAL),
                         ('search_string', reverse_dns),
                     ))
                 res.append(
@@ -240,14 +244,14 @@ syntax_registry.reg_at(
 class DHCPHWAddress(MacAddress):
     oid: str = 'DHCPHWAddress-oid'
     desc: str = 'Network classifier and MAC address'
-    maxLen: str = 26
-    reObj = re.compile(r'^(ethernet|token-ring|fddi) ([0-9a-fA-F]{2}\:){5}[0-9a-fA-F]{2}$')
+    max_len: str = 26
+    pattern = re.compile(r'^(ethernet|token-ring|fddi) ([0-9a-fA-F]{2}\:){5}[0-9a-fA-F]{2}$')
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        attrValue = attrValue.strip()
-        if len(attrValue) == 17:
-            return b'ethernet %s' % attrValue
-        return attrValue
+    def sanitize(self, attr_value: bytes) -> bytes:
+        attr_value = attr_value.strip()
+        if len(attr_value) == 17:
+            return b'ethernet %s' % attr_value
+        return attr_value
 
 syntax_registry.reg_at(
     DHCPHWAddress.oid, [
@@ -259,12 +263,12 @@ syntax_registry.reg_at(
 class DHCPNetMask(Integer):
     oid: str = 'DHCPNetMask-oid'
     desc: str = 'Network address mask bits'
-    maxValue = 0
-    maxValue = 32
-    inputSize = 15
+    min_value = 0
+    max_value = 32
+    input_size = 15
 
-    def _maxlen(self, form_value):
-        return self.inputSize
+    def _maxlen(self, fval):
+        return self.input_size
 
 syntax_registry.reg_at(
     DHCPNetMask.oid, [
@@ -278,13 +282,13 @@ class DHCPRange(IA5String):
     desc: str = 'Network address range'
 
     def _get_ipnetwork(self):
-        cn = self._entry['cn'][0].strip().decode('ascii')
+        name = self._entry['cn'][0].strip().decode('ascii')
         net_mask = self._entry['dhcpNetMask'][0].strip().decode('ascii')
-        return ipaddress.ip_network(('%s/%s' % (cn, net_mask)), strict=False)
+        return ipaddress.ip_network(('%s/%s' % (name, net_mask)), strict=False)
 
-    def formValue(self) -> str:
-        form_value = IA5String.formValue(self)
-        if not form_value:
+    def form_value(self) -> str:
+        fval = IA5String.form_value(self)
+        if not fval:
             try:
                 ipv4_hosts = self._get_ipnetwork().hosts()
                 first_address = next(ipv4_hosts)
@@ -293,22 +297,22 @@ class DHCPRange(IA5String):
                         last_address = next(ipv4_hosts)
                 except StopIteration:
                     pass
-                form_value = '{0} {1}'.format(first_address, last_address)
+                fval = '{0} {1}'.format(first_address, last_address)
             except ipaddress.AddressValueError:
                 pass
-        return form_value
+        return fval
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        return attrValue.strip().replace(b'  ', b' ').replace(b'-', b' ').replace(b'..', b' ')
+    def sanitize(self, attr_value: bytes) -> bytes:
+        return attr_value.strip().replace(b'  ', b' ').replace(b'-', b' ').replace(b'..', b' ')
 
-    def _validate(self, attrValue: bytes) -> bool:
+    def _validate(self, attr_value: bytes) -> bool:
         try:
-            l, h = attrValue.split(b' ', 1)
+            l_s, h_s = attr_value.decode(self._app.ls.charset).split(' ', 1)
         except (IndexError, ValueError):
             return False
         try:
-            l_a = ipaddress.ip_address(l.decode(self._app.ls.charset))
-            h_a = ipaddress.ip_address(h.decode(self._app.ls.charset))
+            l_a = ipaddress.ip_address(l_s)
+            h_a = ipaddress.ip_address(h_s)
         except Exception:
             return False
         if l_a > h_a:
@@ -342,7 +346,7 @@ class DHCPAddressState(SelectList):
         'ABANDONED': 'ABANDONED',
         'BACKUP': 'BACKUP',
         'UNKNOWN': 'UNKNOWN',
-        'RESERVED': 'RESERVED (an address that is managed by DHCP that is reserved for a specific client)',
+        'RESERVED': 'RESERVED (address managed by DHCP that is reserved for a specific client)',
         'RESERVED-ACTIVE': 'RESERVED-ACTIVE (same as reserved, but address is currently in use)',
         'ASSIGNED': 'ASSIGNED (assigned manually or by some other mechanism)',
         'UNASSIGNED': 'UNASSIGNED',
