@@ -12,33 +12,38 @@ import ldap0
 import ldap0.schema.models
 from ldap0.dn import DNObj
 from ldap0.res import SearchResultEntry
+from ldap0.schema.models import AttributeType
 
 import web2ldapcnf
 
-import web2ldap.app.searchform
-from web2ldap.app.schema.syntaxes import \
-    IA5String, \
-    DNSDomain, \
-    DynamicValueSelectList, \
-    IPv4HostAddress, \
-    IPv6HostAddress, \
-    syntax_registry
+from ..searchform import (
+    SEARCH_OPT_ATTR_EXISTS,
+    SEARCH_OPT_IS_EQUAL,
+)
+from ..schema.syntaxes import (
+    IA5String,
+    DNSDomain,
+    DynamicValueSelectList,
+    IPv4HostAddress,
+    IPv6HostAddress,
+    syntax_registry,
+)
 
 
 class AssociatedDomain(DNSDomain):
     oid: str = 'AssociatedDomain-oid'
     desc: str = 'Associated DNS domain name (see RFC 4524, section 2.1.)'
 
-    def _validate(self, attrValue: bytes) -> bool:
-        result = DNSDomain._validate(self, attrValue)
+    def _validate(self, attr_value: bytes) -> bool:
+        result = DNSDomain._validate(self, attr_value)
         ocs = self._entry.object_class_oid_set()
         if 'dNSDomain' in ocs or 'dNSDomain2' in ocs:
             try:
-                dc = self._entry['dc'][0]
+                dc_aval = self._entry['dc'][0]
             except KeyError:
                 pass
             else:
-                result = result and (attrValue == dc or attrValue.startswith(dc+b'.'))
+                result = result and (attr_value == dc_aval or attr_value.startswith(dc_aval+b'.'))
         return result
 
     def _parent_domain(self):
@@ -68,34 +73,34 @@ class AssociatedDomain(DNSDomain):
         return dn2domain.get(matched_dn, None)
         # end of _parent_domain()
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        attrValue = DNSDomain.sanitize(self, attrValue)
-        if not attrValue:
+    def sanitize(self, attr_value: bytes) -> bytes:
+        attr_value = DNSDomain.sanitize(self, attr_value)
+        if not attr_value:
             parent_domain = (self._parent_domain() or '').encode(self._app.ls.charset)
             try:
                 dc_value = self._entry['dc'][0]
             except (KeyError, IndexError):
                 pass
             else:
-                attrValue = DNSDomain.sanitize(self, b'.'.join((dc_value, parent_domain)))
-        return attrValue
+                attr_value = DNSDomain.sanitize(self, b'.'.join((dc_value, parent_domain)))
+        return attr_value
 
-    def formValue(self) -> str:
-        form_value = DNSDomain.formValue(self)
+    def form_value(self) -> str:
+        fval = DNSDomain.form_value(self)
         parent_domain = self._parent_domain() or ''
-        if not form_value:
+        if not fval:
             try:
                 dc_value = self._entry['dc'][0].decode(self._app.ls.charset)
             except (KeyError, IndexError):
                 pass
             else:
-                form_value = '.'.join((dc_value, parent_domain))
-        return form_value
+                fval = '.'.join((dc_value, parent_domain))
+        return fval
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        res = [DNSDomain.display(self, valueindex, commandbutton)]
-        if commandbutton:
-            av = self.av_u.lower()
+    def display(self, vidx, links) -> str:
+        res = [DNSDomain.display(self, vidx, links)]
+        if links:
+            aval = self.av_u.lower()
             res.append(self._app.anchor(
                 'search', 'Ref. RRs',
                 (
@@ -103,18 +108,18 @@ class AssociatedDomain(DNSDomain):
                     ('searchform_mode', 'adv'),
                     ('search_mode', '(|%s)'),
                     ('search_attr', 'cNAMERecord'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
-                    ('search_string', av),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
+                    ('search_string', aval),
                     ('search_attr', 'nSRecord'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
-                    ('search_string', av),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
+                    ('search_string', aval),
                     ('search_attr', 'pTRRecord'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
-                    ('search_string', av),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
+                    ('search_string', aval),
                 ),
                 title='Search referencing DNS RR entries',
             ))
-            parent_domain = '.'.join(av.strip().split('.')[1:])
+            parent_domain = '.'.join(aval.strip().split('.')[1:])
             if parent_domain and 'sOARecord' not in self._entry:
                 res.append(self._app.anchor(
                     'search', 'SOA RR',
@@ -122,18 +127,18 @@ class AssociatedDomain(DNSDomain):
                         ('dn', str(self._app.naming_context)),
                         ('searchform_mode', 'adv'),
                         ('search_attr', 'sOARecord'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_ATTR_EXISTS),
+                        ('search_option', SEARCH_OPT_ATTR_EXISTS),
                         ('search_string', ''),
                         ('search_attr', 'associatedDomain'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                        ('search_option', SEARCH_OPT_IS_EQUAL),
                         ('search_string', parent_domain),
                     ),
                     title='Search SOA RR entry of parent domain',
                 ))
-            if av.endswith('.in-addr.arpa'):
+            if aval.endswith('.in-addr.arpa'):
                 try:
                     ip_addr_u = '.'.join(
-                        map(str, reversed(list(map(int, av.split('.')[0:4]))))
+                        map(str, reversed(list(map(int, aval.split('.')[0:4]))))
                     )
                 except ValueError:
                     pass
@@ -144,31 +149,31 @@ class AssociatedDomain(DNSDomain):
                             ('dn', str(self._app.naming_context)),
                             ('searchform_mode', 'adv'),
                             ('search_attr', 'aRecord'),
-                            ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                            ('search_option', SEARCH_OPT_IS_EQUAL),
                             ('search_string', ip_addr_u),
                         ),
                         title='Search referencing DNS A RR entries',
                     ))
-                    if '1.3.6.1.1.1.1.19' in self._schema.sed[ldap0.schema.models.AttributeType]:
+                    if '1.3.6.1.1.1.1.19' in self._schema.sed[AttributeType]:
                         res.append(self._app.anchor(
                             'search', 'IP host(s)',
                             (
                                 ('dn', str(self._app.naming_context)),
                                 ('searchform_mode', 'adv'),
                                 ('search_attr', 'ipHostNumber'),
-                                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                                ('search_option', SEARCH_OPT_IS_EQUAL),
                                 ('search_string', ip_addr_u),
                             ),
                             title='Search IP host(s) for this A address',
                         ))
-                    if '2.16.840.1.113719.1.203.4.3' in self._schema.sed[ldap0.schema.models.AttributeType]:
+                    if '2.16.840.1.113719.1.203.4.3' in self._schema.sed[AttributeType]:
                         res.append(self._app.anchor(
                             'search', 'DHCP host(s)',
                             (
                                 ('dn', str(self._app.naming_context)),
                                 ('searchform_mode', 'adv'),
                                 ('search_attr', 'dhcpStatements'),
-                                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                                ('search_option', SEARCH_OPT_IS_EQUAL),
                                 ('search_string', 'fixed-address %s' % ip_addr_u),
                             ),
                             title='Search DHCP host(s) for this A address',
@@ -191,11 +196,11 @@ class ResourceRecord(DNSDomain, DynamicValueSelectList):
     desc: str = 'A resource record pointing to another DNS RR'
     ldap_url = 'ldap:///_?associatedDomain,associatedDomain?sub?(objectClass=domainRelatedObject)'
 
-    def __init__(self, app, dn: str, schema, attrType: str, attrValue: bytes, entry=None):
-        DynamicValueSelectList.__init__(self, app, dn, schema, attrType, attrValue, entry)
+    def __init__(self, app, dn: str, schema, attrType: str, attr_value: bytes, entry=None):
+        DynamicValueSelectList.__init__(self, app, dn, schema, attrType, attr_value, entry)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        return DynamicValueSelectList.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        return DynamicValueSelectList.display(self, vidx, links)
 
 syntax_registry.reg_at(
     ResourceRecord.oid, [
@@ -208,7 +213,7 @@ syntax_registry.reg_at(
 class CNAMERecord(ResourceRecord):
     oid: str = 'CNAMERecord-oid'
     desc: str = 'A resource record used as alias (CNAME)'
-    maxValues = 1 # It's illegal to have multiple CNAME RR values
+    max_values = 1 # It's illegal to have multiple CNAME RR values
 
 syntax_registry.reg_at(
     CNAMERecord.oid, [
@@ -220,11 +225,11 @@ syntax_registry.reg_at(
 class MXRecord(ResourceRecord):
     oid: str = 'MXRecord-oid'
     desc: str = 'A resource record pointing to a mail exchanger (MX)'
-    reObj = re.compile(r'^[0-9]+[ ]+[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)*$')
+    pattern = re.compile(r'^[0-9]+[ ]+[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)*$')
 
-    def _search_ref(self, attrValue: str):
+    def _search_ref(self, attr_value: str):
         try:
-            _, hostname = attrValue.split(' ', 1)
+            _, hostname = attr_value.split(' ', 1)
         except ValueError:
             return None
         return ResourceRecord._search_ref(self, hostname.strip())
@@ -240,9 +245,9 @@ class ARecord(IPv4HostAddress):
     oid: str = 'ARecord-oid'
     desc: str = 'A resource record pointing to IPv4 address'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        res = [IPv4HostAddress.display(self, valueindex, commandbutton)]
-        if commandbutton:
+    def display(self, vidx, links) -> str:
+        res = [IPv4HostAddress.display(self, vidx, links)]
+        if links:
             ip_addr = self.addr_class(self.av_u)
             res.append(self._app.anchor(
                 'search', 'PTR RR',
@@ -250,31 +255,31 @@ class ARecord(IPv4HostAddress):
                     ('dn', str(self._app.naming_context)),
                     ('searchform_mode', 'adv'),
                     ('search_attr', 'associatedDomain'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
                     ('search_string', ip_addr.reverse_pointer),
                 ),
                 title='Search PTR RR for this A address',
             ))
-            if '1.3.6.1.1.1.1.19' in self._schema.sed[ldap0.schema.models.AttributeType]:
+            if '1.3.6.1.1.1.1.19' in self._schema.sed[AttributeType]:
                 res.append(self._app.anchor(
                     'search', 'IP host(s)',
                     (
                         ('dn', str(self._app.naming_context)),
                         ('searchform_mode', 'adv'),
                         ('search_attr', 'ipHostNumber'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                        ('search_option', SEARCH_OPT_IS_EQUAL),
                         ('search_string', str(ip_addr)),
                     ),
                     title='Search IP host(s) for this A address',
                 ))
-            if '2.16.840.1.113719.1.203.4.3' in self._schema.sed[ldap0.schema.models.AttributeType]:
+            if '2.16.840.1.113719.1.203.4.3' in self._schema.sed[AttributeType]:
                 res.append(self._app.anchor(
                     'search', 'DHCP host(s)',
                     (
                         ('dn', str(self._app.naming_context)),
                         ('searchform_mode', 'adv'),
                         ('search_attr', 'dhcpStatements'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                        ('search_option', SEARCH_OPT_IS_EQUAL),
                         ('search_string', 'fixed-address %s' % str(ip_addr)),
                     ),
                     title='Search DHCP host(s) for this A address',
@@ -292,9 +297,9 @@ class AAAARecord(IPv6HostAddress):
     oid: str = 'AAAARecord-oid'
     desc: str = 'AAAA resource record pointing to IPv6 address'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        res = [IPv6HostAddress.display(self, valueindex, commandbutton)]
-        if commandbutton:
+    def display(self, vidx, links) -> str:
+        res = [IPv6HostAddress.display(self, vidx, links)]
+        if links:
             ip_addr = self.addr_class(self.av_u)
             try:
                 ip_addr.reverse_dns
@@ -307,7 +312,7 @@ class AAAARecord(IPv6HostAddress):
                         ('dn', str(self._app.naming_context)),
                         ('searchform_mode', 'adv'),
                         ('search_attr', 'associatedDomain'),
-                        ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                        ('search_option', SEARCH_OPT_IS_EQUAL),
                         ('search_string', self._app.ls.uc_decode(ip_addr.reverse_dns)[0][:-1]),
                     ),
                     title='Search PTR RR for this AAAA address',
@@ -324,7 +329,7 @@ syntax_registry.reg_at(
 class SSHFPRecord(IA5String):
     oid: str = 'SSHFPRecord-oid'
     desc: str = 'A resource record with SSH fingerprint (SSHFP)'
-    reObj = re.compile('^[0-4]? [0-2]? [0-9a-fA-F]+$')
+    pattern = re.compile('^[0-4]? [0-2]? [0-9a-fA-F]+$')
     key_algo_dict = {
         b'0': 'reserved',
         b'1': 'RSA',
@@ -342,18 +347,23 @@ class SSHFPRecord(IA5String):
         b'2': 2*hashlib.sha256().digest_size,
     }
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        if not attrValue:
-            return attrValue
+    def sanitize(self, attr_value: bytes) -> bytes:
+        if not attr_value:
+            return attr_value
         try:
-            key_algo, fp_algo, fp_value = filter(None, map(bytes.strip, attrValue.lower().split(b' ')))
+            key_algo, fp_algo, fp_value = filter(
+                None,
+                map(bytes.strip, attr_value.lower().split(b' '))
+            )
         except ValueError:
-            return attrValue
+            return attr_value
         return b' '.join((key_algo, fp_algo, fp_value))
 
-    def _validate(self, attrValue: bytes) -> bool:
+    def _validate(self, attr_value: bytes) -> bool:
         try:
-            key_algo, fp_algo, fp_value = tuple(filter(None, map(bytes.strip, attrValue.split(b' '))))
+            key_algo, fp_algo, fp_value = tuple(
+                filter(None, map(bytes.strip, attr_value.split(b' ')))
+            )
         except ValueError:
             return False
         else:
@@ -366,8 +376,8 @@ class SSHFPRecord(IA5String):
                 result = result and len(fp_value) == fp_algo_len
         return result
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        display_value = IA5String.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        display_value = IA5String.display(self, vidx, links)
         try:
             key_algo, fp_algo, _ = tuple(filter(None, map(bytes.strip, self._av.split(b' '))))
         except ValueError:
@@ -381,7 +391,11 @@ class SSHFPRecord(IA5String):
                 fp_algo_name = self.fp_algo_dict[fp_algo]
             except KeyError:
                 fp_algo_name = '?'
-            res = 'key_algo={key_algo_name} fp_algo={fp_algo_name}:<br><code>{display_value}</code>'.format(
+            res = (
+                'key_algo={key_algo_name} '
+                'fp_algo={fp_algo_name}:<br>'
+                '<code>{display_value}</code>'
+            ).format(
                 key_algo_name=key_algo_name,
                 fp_algo_name=fp_algo_name,
                 display_value=display_value,
