@@ -8,7 +8,7 @@ See http://middleware.internet2.edu/eduperson/
 import re
 from typing import Dict
 
-from web2ldap.app.schema.syntaxes import IA5String, SelectList, DynamicDNSelectList, syntax_registry
+from ..schema.syntaxes import IA5String, SelectList, DynamicDNSelectList, syntax_registry
 
 
 class EduPersonAffiliation(SelectList):
@@ -38,7 +38,9 @@ syntax_registry.reg_at(
 class EduPersonScopedAffiliation(IA5String):
     oid: str = 'EduPersonScopedAffiliation-oid'
     desc: str = 'Scoped affiliation (see eduPerson)'
-    reObj = re.compile('^(faculty|student|staff|alum|member|affiliate|employee|library-walk-in)@[a-zA-Z0-9.-]+$')
+    pattern = re.compile(
+        '^(faculty|student|staff|alum|member|affiliate|employee|library-walk-in)@[a-zA-Z0-9.-]+$'
+    )
 
 syntax_registry.reg_at(
     EduPersonScopedAffiliation.oid, [
