@@ -3,7 +3,7 @@
 web2ldap plugin classes for Entrust PKI
 """
 
-from web2ldap.app.schema.syntaxes import Binary, syntax_registry
+from ..schema.syntaxes import Binary, syntax_registry
 
 # This overrides the eventually configured OctetString syntax
 # and treats these attribute types as not human-readable and
