@@ -3,8 +3,8 @@
 web2ldap plugin classes for MS Exchange 5.5
 """
 
-from web2ldap.app.schema.syntaxes import syntax_registry, RFC822Address, Binary
-from web2ldap.app.plugins.activedirectory import MsAdGUID
+from ..schema.syntaxes import syntax_registry, RFC822Address, Binary
+from .activedirectory import MsAdGUID
 
 syntax_registry.reg_at(
     RFC822Address.oid, [
