@@ -1,12 +1,19 @@
 # -*- coding: utf-8 -*-
 """
 web2ldap plugin classes for FreeRADIUS/LDAP schema
+
+See also:
+https://github.com/FreeRADIUS/freeradius-server/tree/master/doc/schemas/ldap/openldap
 """
 
-from web2ldap.app.schema.syntaxes import DynamicDNSelectList, syntax_registry
+from ..schema.syntaxes import DynamicDNSelectList, syntax_registry
 
 
 class RadiusProfileDN(DynamicDNSelectList):
+    """
+    Select plugin for choosing DN where rlm_ldap should find the
+    RADIUS profile associated with an entry
+    """
     oid: str = 'RadiusProfileDN-oid'
     desc: str = 'DN of a radius profile entry with real data'
     ldap_url = 'ldap:///_??sub?(&(objectClass=radiusprofile)(!(radiusProfileDn=*)))'
