@@ -6,11 +6,12 @@ web2ldap plugin classes for PGP key server
 import re
 from typing import Dict
 
-from web2ldap.app.schema.syntaxes import \
-    DynamicDNSelectList, \
-    MultilineText, \
-    SelectList, \
-    syntax_registry
+from ..schema.syntaxes import (
+    DynamicDNSelectList,
+    MultilineText,
+    SelectList,
+    syntax_registry,
+)
 
 
 class YesNoIntegerFlag(SelectList):
@@ -35,14 +36,14 @@ syntax_registry.reg_at(
 class DominoCertificate(MultilineText):
     oid: str = 'DominoCertificate-oid'
     desc: str = 'Domino certificate'
-    reObj = re.compile('^([A-Z0-9]{8} [A-Z0-9]{8} [A-Z0-9]{8} [A-Z0-9]{8}[\x00]?)+[A-Z0-9 ]*$')
+    pattern = re.compile('^([A-Z0-9]{8} [A-Z0-9]{8} [A-Z0-9]{8} [A-Z0-9]{8}[\x00]?)+[A-Z0-9 ]*$')
     lineSep = b'\x00'
-    mimeType = 'text/plain'
+    mime_type = 'text/plain'
     cols = 36
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         lines = [
-            self._app.form.utf2display(l)
+            self._app.form.s2d(l)
             for l in self._split_lines(self.av_u)
         ]
         return '<code>%s</code>' % '<br>'.join(lines)
