@@ -4,46 +4,47 @@ web2ldap plugin classes for schema elements defined in RFC2307
 """
 
 import re
-from typing import Dict, Union
+from typing import Dict
 
-import web2ldap.web.forms
-import web2ldap.app.searchform
-from web2ldap.app.schema.syntaxes import \
-    DaysSinceEpoch, \
-    DNSDomain, \
-    DynamicValueSelectList, \
-    IA5String, \
-    Integer, \
-    IPHostAddress, \
-    IPServicePortNumber, \
-    MacAddress, \
-    SelectList, \
-    syntax_registry
+from ...web.forms import Field
+from ..searchform import SEARCH_OPT_IS_EQUAL
+from ..schema.syntaxes import (
+    DaysSinceEpoch,
+    DNSDomain,
+    DynamicValueSelectList,
+    IA5String,
+    Integer,
+    IPHostAddress,
+    IPServicePortNumber,
+    MacAddress,
+    SelectList,
+    syntax_registry,
+)
 
 
 class RFC2307BootParameter(IA5String):
     oid: str = '1.3.6.1.1.1.0.1'
     desc: str = 'RFC2307 Boot Parameter'
-    reObj = None # just a stub, should be made stricter
+    pattern = None # just a stub, should be made stricter
 
 
 class GidNumber(DynamicValueSelectList, Integer):
     oid: str = 'GidNumber-oid'
     desc: str = 'RFC2307: An integer uniquely identifying a group in an administrative domain'
-    minValue = 0
-    maxValue = 4294967295
+    min_value = 0
+    max_value = 4294967295
     ldap_url = 'ldap:///_?gidNumber,cn?sub?(objectClass=posixGroup)'
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return Integer._validate(self, attrValue)
+    def _validate(self, attr_value: bytes) -> bool:
+        return Integer._validate(self, attr_value)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         # Possibly display a link
         ocs = self._entry.object_class_oid_set()
         if 'posixAccount' in ocs or 'shadowAccount' in ocs:
-            return DynamicValueSelectList.display(self, valueindex, commandbutton)
-        res = [Integer.display(self, valueindex, commandbutton=False)]
-        if not commandbutton:
+            return DynamicValueSelectList.display(self, vidx, links)
+        res = [Integer.display(self, vidx, False)]
+        if not links:
             return res[0]
         if 'posixGroup' in ocs:
             title = 'Search primary group members'
@@ -51,10 +52,10 @@ class GidNumber(DynamicValueSelectList, Integer):
                 ('dn', self._dn),
                 ('searchform_mode', 'adv'),
                 ('search_attr', 'objectClass'),
-                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                ('search_option', SEARCH_OPT_IS_EQUAL),
                 ('search_string', 'posixAccount'),
                 ('search_attr', 'gidNumber'),
-                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                ('search_option', SEARCH_OPT_IS_EQUAL),
                 ('search_string', self.av_u),
             ]
         else:
@@ -68,11 +69,11 @@ class GidNumber(DynamicValueSelectList, Integer):
             ))
         return ' '.join(res)
 
-    def formField(self) -> web2ldap.web.forms.Field:
+    def input_field(self) -> Field:
         ocs = self._entry.object_class_oid_set()
         if 'posixAccount' in ocs or 'shadowAccount' in ocs:
-            return DynamicValueSelectList.formField(self)
-        return Integer.formField(self)
+            return DynamicValueSelectList.input_field(self)
+        return Integer.input_field(self)
 
 syntax_registry.reg_at(
     GidNumber.oid, [
@@ -87,31 +88,31 @@ class MemberUID(IA5String, DynamicValueSelectList):
     ldap_url = None
     #ldap_url = 'ldap:///_?uid,cn?sub?(objectClass=posixAccount)'
 
-    def __init__(self, app, dn: str, schema, attrType: str, attrValue: bytes, entry=None):
-        IA5String.__init__(self, app, dn, schema, attrType, attrValue, entry)
+    def __init__(self, app, dn: str, schema, attrType: str, attr_value: bytes, entry=None):
+        IA5String.__init__(self, app, dn, schema, attrType, attr_value, entry)
         if self.ldap_url:
-            DynamicValueSelectList.__init__(self, app, dn, schema, attrType, attrValue, entry)
+            DynamicValueSelectList.__init__(self, app, dn, schema, attrType, attr_value, entry)
 
-    def _validate(self, attrValue: bytes) -> bool:
+    def _validate(self, attr_value: bytes) -> bool:
         if self.ldap_url:
-            return DynamicValueSelectList._validate(self, attrValue)
-        return IA5String._validate(self, attrValue)
+            return DynamicValueSelectList._validate(self, attr_value)
+        return IA5String._validate(self, attr_value)
 
-    def formField(self) -> web2ldap.web.forms.Field:
+    def input_field(self) -> Field:
         if self.ldap_url:
-            return DynamicValueSelectList.formField(self)
-        return IA5String.formField(self)
+            return DynamicValueSelectList.input_field(self)
+        return IA5String.input_field(self)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        res = [IA5String.display(self, valueindex, commandbutton=False)]
-        if commandbutton:
+    def display(self, vidx, links) -> str:
+        res = [IA5String.display(self, vidx, False)]
+        if links:
             res.append(self._app.anchor(
                 'searchform', '&raquo;',
                 [
                     ('dn', self._dn),
                     (
                         'filterstr', '(&(objectClass=posixAccount)(uid=%s))' % (
-                            self._app.form.utf2display(self.av_u)
+                            self._app.form.s2d(self.av_u)
                         )
                     ),
                     ('searchform_mode', 'exp'),
@@ -130,14 +131,14 @@ syntax_registry.reg_at(
 class RFC2307NISNetgroupTriple(IA5String):
     oid: str = '1.3.6.1.1.1.0.0'
     desc: str = 'RFC2307 NIS Netgroup Triple'
-    reObj = re.compile(r'^\([a-z0-9.-]*,[a-z0-9.-]*,[a-z0-9.-]*\)$')
+    pattern = re.compile(r'^\([a-z0-9.-]*,[a-z0-9.-]*,[a-z0-9.-]*\)$')
 
 
 class UidNumber(Integer):
     oid: str = 'UidNumber-oid'
     desc: str = 'Numerical user ID for Posix systems'
-    minValue = 0
-    maxValue = 4294967295
+    min_value = 0
+    max_value = 4294967295
 
 syntax_registry.reg_at(
     UidNumber.oid, [
