@@ -12,20 +12,20 @@ from typing import Dict
 
 from ldap0 import LDAPError
 
-import web2ldap.app.gui
-from web2ldap.utctime import strptime
-from web2ldap.app.schema.syntaxes import \
-    DirectoryString, \
-    DynamicDNSelectList, \
-    GeneralizedTime, \
-    HMACAlgorithmOID, \
-    JSONValue, \
-    LDAPv3ResultCode, \
-    OctetString, \
-    SelectList, \
-    Timespan, \
-    syntax_registry
-from web2ldap import cmp
+from ... import cmp
+from ...utctime import strptime, ts2repr
+from ..schema.syntaxes import (
+    DirectoryString,
+    DynamicDNSelectList,
+    GeneralizedTime,
+    HMACAlgorithmOID,
+    JSONValue,
+    LDAPv3ResultCode,
+    OctetString,
+    SelectList,
+    Timespan,
+    syntax_registry,
+)
 
 
 syntax_registry.reg_at(
@@ -128,8 +128,8 @@ class OathTokenIdentifier(DirectoryString):
     """
     oid: str = 'OathTokenIdentifier-oid'
     desc: str = 'Globally unique token identifier'
-    maxLen: str = 12
-    reObj = re.compile(r'^[a-zA-Z0-9]{12}$')
+    max_len: str = 12
+    pattern = re.compile(r'^[a-zA-Z0-9]{12}$')
 
 syntax_registry.reg_at(
     OathTokenIdentifier.oid, [
@@ -142,11 +142,11 @@ class OathInitPwAlphabet(DirectoryString):
     oid: str = 'OathInitPwAlphabet-oid'
     desc: str = 'Alphabet used to generate init passwords'
 
-    def sanitize(self, attrValue: bytes) -> bytes:
+    def sanitize(self, attr_value: bytes) -> bytes:
         return b''.join([
             self._app.ls.uc_encode(c)[0]
             for c in sorted(set(
-                self._app.ls.uc_decode(attrValue or '')[0].replace(' ', '')
+                self._app.ls.uc_decode(attr_value or '')[0].replace(' ', '')
             ))
         ])
 
@@ -170,10 +170,10 @@ class OathSecret(OctetString):
     oid: str = 'OathSecret-oid'
     desc: str = 'OATH shared secret'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         return '<br>'.join((
-            self._app.form.utf2display(base64.b32encode(self._av).decode('ascii')),
-            OctetString.display(self, valueindex, commandbutton),
+            self._app.form.s2d(base64.b32encode(self._av).decode('ascii')),
+            OctetString.display(self, vidx, links),
         ))
 
 syntax_registry.reg_at(
@@ -188,9 +188,9 @@ class OathSecretTime(GeneralizedTime):
     desc: str = 'OATH secret change time'
     time_divisors = Timespan.time_divisors
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         ocs = self._entry.object_class_oid_set()
-        gt_disp_html = GeneralizedTime.display(self, valueindex, commandbutton)
+        gt_disp_html = GeneralizedTime.display(self, vidx, links)
         if 'oathHOTPToken' in ocs:
             oath_params_dn_attr = 'oathHOTPParams'
         elif 'oathTOTPToken' in ocs:
@@ -229,8 +229,8 @@ class OathSecretTime(GeneralizedTime):
                         1: 'will expire',
                     }[expire_cmp],
                     expire_dt.strftime('%c'),
-                    self._app.form.utf2display(
-                        web2ldap.app.gui.ts2repr(
+                    self._app.form.s2d(
+                        ts2repr(
                             self.time_divisors,
                             ' ',
                             abs(expired_since),
@@ -244,7 +244,7 @@ class OathSecretTime(GeneralizedTime):
                 )
             else:
                 expire_msg = 'will never expire'
-        return self.readSep.join((gt_disp_html, expire_msg))
+        return self.read_sep.join((gt_disp_html, expire_msg))
 
 
 syntax_registry.reg_at(
