@@ -9,18 +9,19 @@ from typing import Dict
 import ldap0
 from ldap0.dn import DNObj
 
-from web2ldap.app.schema.syntaxes import \
-    BindDN, \
-    DirectoryString, \
-    DynamicDNSelectList, \
-    MultilineText, \
-    OctetString, \
-    SelectList, \
-    syntax_registry
-from web2ldap.app.plugins.x509 import Certificate
-from web2ldap.app.plugins.groups import MemberOf
-from web2ldap.app.plugins.quirks import NamingContexts
-from web2ldap.app.schema import no_humanreadable_attr
+from ..schema.syntaxes import (
+    BindDN,
+    DirectoryString,
+    DynamicDNSelectList,
+    MultilineText,
+    OctetString,
+    SelectList,
+    syntax_registry,
+)
+from .x509 import Certificate
+from .groups import MemberOf
+from .quirks import NamingContexts
+from ..schema import no_humanreadable_attr
 
 
 syntax_registry.reg_at(
@@ -54,6 +55,7 @@ syntax_registry.reg_at(
     ]
 )
 
+
 class OpenDSCfgPasswordGenerator(DynamicDNSelectList):
     oid: str = 'OpenDSCfgPasswordGenerator-oid'
     desc: str = 'DN of the ds-cfg-password-generator entry'
@@ -372,7 +374,7 @@ syntax_registry.reg_at(
 class OpenDSCfgTimeInterval(DirectoryString):
     oid: str = 'OpenDSCfgTimeInterval-oid'
     desc: str = 'A time interval consisting of integer value and time unit'
-    reObj = re.compile('^[0-9]+ (seconds|minutes|hours|days)$')
+    pattern = re.compile('^[0-9]+ (seconds|minutes|hours|days)$')
 
 syntax_registry.reg_at(
     OpenDSCfgTimeInterval.oid, [
@@ -392,18 +394,18 @@ class OpenDSSyncHist(OctetString, DirectoryString):
     oid: str = 'OpenDSSyncHist-oid'
     desc: str = 'List of modifications'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         try:
             mod_attr_type, mod_number, mod_type, mod_value = self._av.split(':', 3)
         except ValueError:
-            return OctetString.display(self, valueindex, commandbutton)
-        first_str = self._app.form.utf2display(
+            return OctetString.display(self, vidx, links)
+        first_str = self._app.form.s2d(
             ':'.join((mod_attr_type, mod_number, mod_type)).decode(self._app.ls.charset)
         )
         if no_humanreadable_attr(self._schema, mod_attr_type):
             mod_value_html = mod_value.hex().upper()
         else:
-            mod_value_html = self._app.form.utf2display(mod_value.decode(self._app.ls.charset))
+            mod_value_html = self._app.form.s2d(mod_value.decode(self._app.ls.charset))
         return ':<br>'.join((first_str, mod_value_html))
 
 syntax_registry.reg_at(
@@ -417,13 +419,13 @@ class OpenDSdsCfgAlternatebindDn(BindDN):
     oid: str = 'OpenDSdsCfgAlternatebindDn-oid'
     desc: str = 'OpenDS/OpenDJ alternative bind DN'
 
-    def formValue(self) -> str:
+    def form_value(self) -> str:
         if not self._av:
             return ''
         try:
             dn_obj = DNObj(self.av_u)
         except ldap0.DECODING_ERROR:
-            return BindDN.formValue(self)
+            return BindDN.form_value(self)
         new_rdn = DNObj(tuple([
             (
                 rdn_attr,
