@@ -16,26 +16,87 @@ from ldap0.controls import KNOWN_RESPONSE_CONTROLS
 
 import web2ldapcnf
 
-import web2ldap.app.gui
-from web2ldap.app.schema.syntaxes import \
-    AuthzDN, \
-    BindDN, \
-    DirectoryString, \
-    DistinguishedName, \
-    DynamicDNSelectList, \
-    IA5String, \
-    Integer, \
-    LDAPUrl, \
-    LDAPv3ResultCode, \
-    MultilineText, \
-    NotBefore, \
-    OctetString, \
-    SelectList, \
-    Uri, \
-    UUID, \
-    syntax_registry
-from web2ldap.ldaputil.oidreg import OID_REG
-from web2ldap.app.plugins.quirks import NamingContexts
+from ..searchform import SEARCH_OPT_IS_EQUAL, SEARCH_SCOPE_STR_ONELEVEL
+from ..schema.syntaxes import (
+    AuthzDN,
+    BindDN,
+    DirectoryString,
+    DistinguishedName,
+    DynamicDNSelectList,
+    IA5String,
+    Integer,
+    LDAPUrl,
+    LDAPv3ResultCode,
+    MultilineText,
+    NotBefore,
+    OctetString,
+    SchemaDescription,
+    SelectList,
+    Uri,
+    UUID,
+    syntax_registry,
+)
+from ...ldaputil.oidreg import OID_REG
+from .quirks import NamingContexts
+
+#---------------------------------------------------------------------------
+# Schema information
+#---------------------------------------------------------------------------
+
+class OlcSchemaDescription(SchemaDescription):
+    oid: str = 'OlcSchemaDescription-oid'
+
+    def _validate(self, attr_value: bytes) -> bool:
+        try:
+            # strip X-ORDERED number
+            schema_desc = attr_value.split(b'}', 1)[1]
+        except IndexError:
+            schema_desc = attr_value
+        return SchemaDescription._validate(self, schema_desc)
+
+
+class OlcObjectClasses(OlcSchemaDescription):
+    oid: str = 'OlcObjectClasses-oid'
+    schema_cls = ldap0.schema.models.ObjectClass
+
+syntax_registry.reg_at(
+    OlcObjectClasses.oid, [
+        '1.3.6.1.4.1.4203.1.12.2.3.0.32', # olcObjectClasses
+    ]
+)
+
+
+class OlcAttributeTypes(OlcSchemaDescription):
+    oid: str = 'OlcAttributeTypes-oid'
+    schema_cls = ldap0.schema.models.AttributeType
+
+syntax_registry.reg_at(
+    OlcAttributeTypes.oid, [
+        '1.3.6.1.4.1.4203.1.12.2.3.0.4', # olcAttributeTypes
+    ]
+)
+
+
+class OlcLdapSyntaxes(OlcSchemaDescription):
+    oid: str = 'OlcLdapSyntaxes-oid'
+    schema_cls = ldap0.schema.models.LDAPSyntax
+
+syntax_registry.reg_at(
+    OlcLdapSyntaxes.oid, [
+        '1.3.6.1.4.1.4203.1.12.2.3.0.85', # olcLdapSyntaxes
+    ]
+)
+
+
+class OlcDitContentRules(OlcSchemaDescription):
+    oid: str = 'OlcDitContentRules-oid'
+    schema_cls = ldap0.schema.models.DITContentRule
+
+syntax_registry.reg_at(
+    OlcDitContentRules.oid, [
+        '1.3.6.1.4.1.4203.1.12.2.3.0.16', # olcDitContentRules
+    ]
+)
 
 #---------------------------------------------------------------------------
 # slapo-syncprov
@@ -45,18 +106,18 @@ from web2ldap.app.plugins.quirks import NamingContexts
 class CSNSid(IA5String):
     oid: str = '1.3.6.1.4.1.4203.666.11.2.4'
     desc: str = 'change sequence number SID (CSN SID)'
-    minLen: int = 3
-    maxLen: int = 3
-    reObj = re.compile('^[a-fA-F0-9]{3}$')
+    min_len: int = 3
+    max_len: int = 3
+    pattern = re.compile('^[a-fA-F0-9]{3}$')
 
 
 # see https://www.openldap.org/faq/data/cache/1145.html
 class CSN(IA5String):
     oid: str = '1.3.6.1.4.1.4203.666.11.2.1'
     desc: str = 'change sequence number (CSN)'
-    minLen: int = 40
-    maxLen: int = 40
-    reObj = re.compile('^[0-9]{14}\\.[0-9]{6}Z#[a-fA-F0-9]{6}#[a-fA-F0-9]{3}#[a-fA-F0-9]{6}$')
+    min_len: int = 40
+    max_len: int = 40
+    pattern = re.compile('^[0-9]{14}\\.[0-9]{6}Z#[a-fA-F0-9]{6}#[a-fA-F0-9]{3}#[a-fA-F0-9]{6}$')
 
 syntax_registry.reg_at(
     CSN.oid, [
@@ -82,7 +143,7 @@ syntax_registry.reg_at(
 class OlcDbIndex(DirectoryString):
     oid: str = 'OlcDbIndex-oid'
     desc: str = 'OpenLDAP indexing directive'
-    reObj = re.compile("^[a-zA-Z]?[a-zA-Z0-9.,;-]* (pres|eq|sub)(,(pres|eq|sub))*$")
+    pattern = re.compile("^[a-zA-Z]?[a-zA-Z0-9.,;-]* (pres|eq|sub)(,(pres|eq|sub))*$")
 
 syntax_registry.reg_at(
     OlcDbIndex.oid, [
@@ -112,19 +173,19 @@ class OlcRootDN(BindDN):
     desc: str = 'The rootdn in the database'
     default_rdn = u'cn=admin'
 
-    def formValue(self) -> str:
-        form_value = BindDN.formValue(self)
+    def form_value(self) -> str:
+        fval = BindDN.form_value(self)
         try:
             olc_suffix = self._entry['olcSuffix'][0].decode()
         except KeyError:
             pass
         else:
-            if not form_value or not form_value.endswith(olc_suffix):
+            if not fval or not fval.endswith(olc_suffix):
                 try:
-                    form_value = u','.join((self.default_rdn, olc_suffix))
+                    fval = u','.join((self.default_rdn, olc_suffix))
                 except KeyError:
                     pass
-        return form_value
+        return fval
 
 syntax_registry.reg_at(
     OlcRootDN.oid, [
@@ -137,10 +198,10 @@ class OlcMultilineText(MultilineText):
     oid: str = 'OlcMultilineText-oid'
     desc: str = 'OpenLDAP multiline configuration strings'
     cols = 90
-    minInputRows = 3
+    min_input_rows = 3
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        return '<code>%s</code>' % MultilineText.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        return '<code>%s</code>' % MultilineText.display(self, vidx, links)
 
 syntax_registry.reg_at(
     OlcMultilineText.oid, [
@@ -153,21 +214,18 @@ syntax_registry.reg_at(
 class OlcSyncRepl(OlcMultilineText, LDAPUrl):
     oid: str = 'OlcSyncRepl-oid'
     desc: str = 'OpenLDAP syncrepl directive'
-    minInputRows = 5
+    min_input_rows = 5
 
-    def __init__(self, app, dn: str, schema, attrType: str, attrValue: bytes, entry=None):
-        OlcMultilineText.__init__(self, app, dn, schema, attrType, attrValue, entry)
+    def __init__(self, app, dn: str, schema, attrType: str, attr_value: bytes, entry=None):
+        OlcMultilineText.__init__(self, app, dn, schema, attrType, attr_value, entry)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        if not commandbutton or not self._av:
-            return OlcMultilineText.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        if not links or not self._av:
+            return OlcMultilineText.display(self, vidx, links)
         srd = ldap0.openldap.SyncReplDesc(self.av_u)
         return ' '.join((
-            OlcMultilineText.display(self, valueindex, commandbutton),
-            web2ldap.app.gui.ldap_url_anchor(
-                self._app,
-                srd.ldap_url(),
-            ),
+            OlcMultilineText.display(self, vidx, links),
+            self._app.ldap_url_anchor(srd.ldap_url()),
         ))
 
 syntax_registry.reg_at(
@@ -205,11 +263,11 @@ class OlcPPolicyDefault(DynamicDNSelectList, DistinguishedName):
     desc: str = 'DN of a pwdPolicy object for uncustomized objects'
     ldap_url = 'ldap:///_?cn?sub?(objectClass=pwdPolicy)'
 
-    def __init__(self, app, dn: str, schema, attrType: str, attrValue: bytes, entry=None):
-        DynamicDNSelectList.__init__(self, app, dn, schema, attrType, attrValue, entry)
+    def __init__(self, app, dn: str, schema, attrType: str, attr_value: bytes, entry=None):
+        DynamicDNSelectList.__init__(self, app, dn, schema, attrType, attr_value, entry)
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return DynamicDNSelectList._validate(self, attrValue)
+    def _validate(self, attr_value: bytes) -> bool:
+        return DynamicDNSelectList._validate(self, attr_value)
 
 syntax_registry.reg_at(
     OlcPPolicyDefault.oid, [
@@ -252,9 +310,9 @@ class AuditContext(NamingContexts):
     oid: str = 'AuditContext'
     desc: str = 'OpenLDAP DN pointing to audit naming context'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        res = [DistinguishedName.display(self, valueindex, commandbutton)]
-        if commandbutton:
+    def display(self, vidx, links) -> str:
+        res = [DistinguishedName.display(self, vidx, links)]
+        if links:
             res.extend([
                 self._app.anchor(
                     'searchform', 'Search',
@@ -309,10 +367,10 @@ class ReqMod(OctetString, DirectoryString):
     desc: str = 'List of modifications/old values'
     known_modtypes = {b'+', b'-', b'=', b'#', b''}
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return OctetString._validate(self, attrValue)
+    def _validate(self, attr_value: bytes) -> bool:
+        return OctetString._validate(self, attr_value)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         if self._av == b':':
             # magic value used for fixing OpenLDAP ITS#6545
             return ':'
@@ -320,14 +378,14 @@ class ReqMod(OctetString, DirectoryString):
             mod_attr_type, mod_attr_rest = self._av.split(b':', 1)
             mod_type = mod_attr_rest[0:1].strip()
         except (ValueError, IndexError):
-            return OctetString.display(self, valueindex, commandbutton)
+            return OctetString.display(self, vidx, links)
         if not mod_type in self.known_modtypes:
-            return OctetString.display(self, valueindex, commandbutton)
+            return OctetString.display(self, vidx, links)
         if len(mod_attr_rest) > 1:
             try:
                 mod_type, mod_attr_value = mod_attr_rest.split(b' ', 1)
             except ValueError:
-                return OctetString.display(self, valueindex, commandbutton)
+                return OctetString.display(self, vidx, links)
         else:
             mod_attr_value = b''
         mod_attr_type_u = mod_attr_type.decode(self._app.ls.charset)
@@ -336,12 +394,12 @@ class ReqMod(OctetString, DirectoryString):
             mod_attr_value.decode(self._app.ls.charset)
         except UnicodeDecodeError:
             return '%s:%s<br>\n<code>\n%s\n</code>\n' % (
-                self._app.form.utf2display(mod_attr_type_u),
-                self._app.form.utf2display(mod_type_u),
+                self._app.form.s2d(mod_attr_type_u),
+                self._app.form.s2d(mod_type_u),
                 mod_attr_value.hex().upper(),
             )
         else:
-            return DirectoryString.display(self, valueindex, commandbutton)
+            return DirectoryString.display(self, vidx, links)
         raise ValueError
 
 syntax_registry.reg_at(
@@ -356,8 +414,8 @@ class ReqControls(IA5String):
     oid: str = '1.3.6.1.4.1.4203.666.11.5.3.1'
     desc: str = 'List of LDAPv3 extended controls sent along with a request'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        result_lines = [IA5String.display(self, valueindex, commandbutton)]
+    def display(self, vidx, links) -> str:
+        result_lines = [IA5String.display(self, vidx, links)]
         # Eliminate X-ORDERED prefix
         _, rest = self.av_u.strip().split('}{', 1)
         # check whether it ends with }
@@ -377,7 +435,7 @@ class ReqControls(IA5String):
                 except KeyError:
                     ctrl_name = None
             if ctrl_name:
-                result_lines.append(self._app.form.utf2display(ctrl_name))
+                result_lines.append(self._app.form.s2d(ctrl_name))
             # Extract criticality
             try:
                 ctrl_criticality = {
@@ -389,7 +447,9 @@ class ReqControls(IA5String):
             result_lines.append('criticality %s' % str(ctrl_criticality).upper())
             # Extract controlValue
             try:
-                ctrl_value = binascii.unhexlify(ctrl_tokens[ctrl_tokens.index('controlValue')+1].upper()[1:-1])
+                ctrl_value = binascii.unhexlify(
+                    ctrl_tokens[ctrl_tokens.index('controlValue')+1].upper()[1:-1]
+                )
             except (KeyError, ValueError, IndexError):
                 pass
             else:
@@ -399,7 +459,7 @@ class ReqControls(IA5String):
                     decoded_control_value = ctrl_value
                 result_lines.append(
                     'controlValue %s' % (
-                        self._app.form.utf2display(
+                        self._app.form.s2d(
                             repr(decoded_control_value)
                         ).replace('\n', '<br>')
                     )
@@ -417,9 +477,9 @@ syntax_registry.reg_at(
 class ReqEntryUUID(UUID):
     oid: str = 'ReqEntryUUID-oid'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        display_value = UUID.display(self, valueindex, commandbutton)
-        if not commandbutton:
+    def display(self, vidx, links) -> str:
+        display_value = UUID.display(self, vidx, links)
+        if not links:
             return display_value
         return web2ldapcnf.command_link_separator.join((
             display_value,
@@ -433,7 +493,11 @@ class ReqEntryUUID(UUID):
                     ),
                     (
                         'search_root',
-                        str(self._app.ls.get_search_root(self._app.ls.uc_decode(self._entry['reqDN'][0])[0])),
+                        str(
+                            self._app.ls.get_search_root(
+                                self._app.ls.uc_decode(self._entry['reqDN'][0])[0]
+                            )
+                        ),
                     ),
                 ),
                 title='Search entry by UUID',
@@ -450,9 +514,9 @@ syntax_registry.reg_at(
 class ReqSession(Integer):
     oid: str = 'ReqSession-oid'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        display_value = Integer.display(self, valueindex, commandbutton)
-        if not commandbutton:
+    def display(self, vidx, links) -> str:
+        display_value = Integer.display(self, vidx, links)
+        if not links:
             return display_value
         return web2ldapcnf.command_link_separator.join((
             display_value,
@@ -463,7 +527,7 @@ class ReqSession(Integer):
                     ('search_root', str(self._app.naming_context)),
                     ('searchform_mode', u'adv'),
                     ('search_attr', u'reqSession'),
-                    ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                    ('search_option', SEARCH_OPT_IS_EQUAL),
                     ('search_string', self.av_u),
                 ),
                 title='Search all audit entries with same session number',
@@ -538,14 +602,14 @@ class OpenLDAPSpecialBackendSuffix(NamingContexts):
     def _config_link(self):
         attr_type_u = self._at[:-7]
         try:
-            config_context = self._app.ls.uc_decode(self._app.ls.rootDSE['configContext'][0])[0]
+            config_context = self._app.ls.uc_decode(self._app.ls.root_dse['configContext'][0])[0]
         except KeyError:
             return None
         return self._app.anchor(
             'search', 'Config',
             (
                 ('dn', config_context),
-                ('scope', web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL),
+                ('scope', SEARCH_SCOPE_STR_ONELEVEL),
                 (
                     'filterstr',
                     u'(&(objectClass=olcDatabaseConfig)(olcDatabase=%s))' % (attr_type_u),
