@@ -8,7 +8,7 @@ Experimental => you have to understand what it internally does when enabling it!
 import ldap0
 from ldap0.res import SearchReference
 
-from web2ldap.app.plugins.nis import syntax_registry, UidNumber, GidNumber, IA5String
+from .nis import syntax_registry, UidNumber, GidNumber, IA5String
 
 
 class HomeDirectory(IA5String):
@@ -17,19 +17,21 @@ class HomeDirectory(IA5String):
     uid_attr = 'uid'
     homeDirectoryTemplate = '/home/{uid}'
 
-    def transmute(self, attrValues):
+    def transmute(self, attr_values):
         if self.uid_attr not in self._entry:
-            return attrValues
+            return attr_values
         if (
-                not attrValues or
-                not attrValues[0] or
-                attrValues[0].decode(self._app.ls.charset) == self.homeDirectoryTemplate.format(**{self.uid_attr:''})
+                not attr_values or
+                not attr_values[0] or
+                attr_values[0].decode(self._app.ls.charset) == self.homeDirectoryTemplate.format(
+                    **{self.uid_attr:''}
+                )
             ):
             fmt_dict = {self.uid_attr:self._entry[self.uid_attr][0].decode(self._app.ls.charset)}
-            attrValues = [
+            attr_values = [
                 self.homeDirectoryTemplate.format(**fmt_dict).encode(self._app.ls.charset)
             ]
-        return attrValues
+        return attr_values
 
 syntax_registry.reg_at(
     HomeDirectory.oid, [
@@ -39,13 +41,17 @@ syntax_registry.reg_at(
 
 
 class AutogenNumberMixIn:
-    inputSize = 12
+    input_size = 12
     minNewValue = 10000
     maxNewValue = 19999
     object_class = 'posixAccount'
 
-    def formValue(self) -> str:
-        if self.object_class.lower() not in {oc.lower().decode('ascii') for oc in self._entry['objectClass']}:
+    def form_value(self) -> str:
+        oc_set = {
+            oc.lower().decode('ascii')
+            for oc in self._entry['objectClass']
+        }
+        if self.object_class.lower() not in oc_set:
             return ''
         try:
             ldap_results = self._app.ls.l.search_s(
@@ -91,11 +97,11 @@ class AutogenUIDNumber(UidNumber, AutogenNumberMixIn):
     maxNewValue = 19999
     object_class = 'posixAccount'
 
-    def formValue(self) -> str:
-        form_value = UidNumber.formValue(self)
-        if not form_value:
-            form_value = AutogenNumberMixIn.formValue(self)
-        return form_value # formValue()
+    def form_value(self) -> str:
+        fval = UidNumber.form_value(self)
+        if not fval:
+            fval = AutogenNumberMixIn.form_value(self)
+        return fval # form_value()
 
 syntax_registry.reg_at(
     AutogenUIDNumber.oid, [
@@ -109,11 +115,11 @@ class AutogenGIDNumber(GidNumber, AutogenNumberMixIn):
     desc: str = 'numeric Unix-GID'
     object_class = 'posixGroup'
 
-    def formValue(self) -> str:
-        form_value = GidNumber.formValue(self)
-        if not form_value:
-            form_value = AutogenNumberMixIn.formValue(self)
-        return form_value # formValue()
+    def form_value(self) -> str:
+        fval = GidNumber.form_value(self)
+        if not fval:
+            fval = AutogenNumberMixIn.form_value(self)
+        return fval # form_value()
 
 syntax_registry.reg_at(
     AutogenGIDNumber.oid, [
