@@ -9,16 +9,21 @@ from typing import Dict
 
 from ldap0 import LDAPError
 
-import web2ldap.app.searchform
-from web2ldap.utctime import strptime
-from web2ldap.app.schema.syntaxes import \
-    SelectList, \
-    DynamicDNSelectList, \
-    Timespan, \
-    GeneralizedTime, \
-    syntax_registry
-from web2ldap.app.plugins.quirks import UserPassword
-from web2ldap import cmp
+from ...utctime import strptime, ts2repr
+from ..searchform import (
+    SEARCH_OPT_LE_THAN,
+    SEARCH_OPT_IS_EQUAL,
+    SEARCH_OPT_GE_THAN,
+)
+from ..schema.syntaxes import (
+    SelectList,
+    DynamicDNSelectList,
+    Timespan,
+    GeneralizedTime,
+    syntax_registry,
+)
+from .quirks import UserPassword
+from ... import cmp
 
 
 class PwdCheckQuality(SelectList):
@@ -44,10 +49,10 @@ class PwdAttribute(SelectList):
         '2.5.4.35': 'userPassword',
     }
 
-    def _validate(self, attrValue: bytes) -> bool:
+    def _validate(self, attr_value: bytes) -> bool:
         return (
-            not attrValue or
-            attrValue.lower() in {b'2.5.4.35', b'userpassword'}
+            not attr_value or
+            attr_value.lower() in {b'2.5.4.35', b'userpassword'}
         )
 
 syntax_registry.reg_at(
@@ -82,15 +87,15 @@ class PwdMaxAge(Timespan):
     def _timespan_search_params(self):
         return (
             ('search_attr', 'pwdChangedTime'),
-            ('search_option', web2ldap.app.searchform.SEARCH_OPT_LE_THAN),
+            ('search_option', SEARCH_OPT_LE_THAN),
             ('search_string', self._search_timestamp(int(self.av_u.strip()))),
         )
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        ts_dv = Timespan.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        ts_dv = Timespan.display(self, vidx, links)
         # Possibly display a link
         ocs = self._entry.object_class_oid_set()
-        if not commandbutton or not 'pwdPolicy' in ocs:
+        if not links or 'pwdPolicy' not in ocs:
             return ts_dv
         try:
             ts_search_params = self._timespan_search_params()
@@ -102,7 +107,7 @@ class PwdMaxAge(Timespan):
                 ('dn', self._dn),
                 ('searchform_mode', 'adv'),
                 ('search_attr', 'pwdPolicySubentry'),
-                ('search_option', web2ldap.app.searchform.SEARCH_OPT_IS_EQUAL),
+                ('search_option', SEARCH_OPT_IS_EQUAL),
                 ('search_string', self._dn),
             ) + ts_search_params,
             title=self.title_text,
@@ -128,10 +133,10 @@ class PwdExpireWarning(PwdMaxAge):
         warn_timestamp = pwd_max_age-pwd_expire_warning
         return (
             ('search_attr', 'pwdChangedTime'),
-            ('search_option', web2ldap.app.searchform.SEARCH_OPT_GE_THAN),
+            ('search_option', SEARCH_OPT_GE_THAN),
             ('search_string', self._search_timestamp(pwd_max_age)),
             ('search_attr', 'pwdChangedTime'),
-            ('search_option', web2ldap.app.searchform.SEARCH_OPT_LE_THAN),
+            ('search_option', SEARCH_OPT_LE_THAN),
             ('search_string', self._search_timestamp(warn_timestamp)),
         )
 
@@ -146,14 +151,14 @@ class PwdAccountLockedTime(GeneralizedTime):
     oid: str = 'PwdAccountLockedTime-oid'
     desc: str = 'user entry: time that the account was locked'
     magic_values = {
-        '000001010000Z': 'permanently locked',
+        b'000001010000Z': 'permanently locked',
     }
 
-    def _validate(self, attrValue: bytes) -> bool:
-        return attrValue in self.magic_values or GeneralizedTime._validate(self, attrValue)
+    def _validate(self, attr_value: bytes) -> bool:
+        return attr_value in self.magic_values or GeneralizedTime._validate(self, attr_value)
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        gt_disp_html = GeneralizedTime.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        gt_disp_html = GeneralizedTime.display(self, vidx, links)
         if self._av in self.magic_values:
             return '%s (%s)' % (gt_disp_html, self.magic_values[self._av])
         return gt_disp_html
@@ -170,19 +175,19 @@ class PwdChangedTime(GeneralizedTime):
     desc: str = 'user entry: Last password change time'
     time_divisors = Timespan.time_divisors
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
-        gt_disp_html = GeneralizedTime.display(self, valueindex, commandbutton)
+    def display(self, vidx, links) -> str:
+        gt_disp_html = GeneralizedTime.display(self, vidx, links)
         try:
             pwd_changed_dt = strptime(self._av)
         except ValueError:
             return gt_disp_html
         try:
-            pwd_policy_subentry_dn = self._entry['pwdPolicySubentry'][0].decode(self._app.ls.charset)
+            pwdpolicysubentry_dn = self._entry['pwdPolicySubentry'][0].decode(self._app.ls.charset)
         except KeyError:
             return gt_disp_html
         try:
             pwd_policy = self._app.ls.l.read_s(
-                pwd_policy_subentry_dn,
+                pwdpolicysubentry_dn,
                 filterstr='(objectClass=pwdPolicy)',
                 attrlist=['pwdMaxAge', 'pwdExpireWarning'],
             )
@@ -208,8 +213,8 @@ class PwdChangedTime(GeneralizedTime):
                         1: 'will expire',
                     }[expire_cmp],
                     expire_dt.strftime('%c'),
-                    self._app.form.utf2display(
-                        web2ldap.app.gui.ts2repr(
+                    self._app.form.s2d(
+                        ts2repr(
                             self.time_divisors,
                             ' ',
                             abs(expired_since),
@@ -223,7 +228,7 @@ class PwdChangedTime(GeneralizedTime):
                 )
             else:
                 expire_msg = 'will never expire'
-        return self.readSep.join((gt_disp_html, expire_msg))
+        return self.read_sep.join((gt_disp_html, expire_msg))
 
 
 syntax_registry.reg_at(
