@@ -7,29 +7,94 @@ a server is erroneous or could not be retrieved.
 
 import ldap0.ldapurl
 
-import web2ldap.app.searchform
-from web2ldap.app.schema.syntaxes import \
-    syntax_registry, \
-    Audio, \
-    AuthzDN, \
-    Binary, \
-    Boolean, \
-    CountryString, \
-    DirectoryString, \
-    DistinguishedName, \
-    DomainComponent, \
-    Integer, \
-    JPEGImage, \
-    LDAPUrl, \
-    OctetString, \
-    OID, \
-    PhotoG3Fax, \
-    PostalAddress, \
-    RFC822Address, \
-    Uri, \
-    UTCTime
+from ..searchform import SEARCH_SCOPE_STR_ONELEVEL
+from ..schema.syntaxes import (
+    syntax_registry,
+    Audio,
+    AuthzDN,
+    Binary,
+    Boolean,
+    CountryString,
+    DirectoryString,
+    DistinguishedName,
+    DomainComponent,
+    Integer,
+    JPEGImage,
+    LDAPUrl,
+    OctetString,
+    OID,
+    PhotoG3Fax,
+    PostalAddress,
+    RFC822Address,
+    Uri,
+    UTCTime,
+    ObjectClassDescription,
+    AttributeTypeDescription,
+    MatchingRuleDescription,
+    MatchingRuleUseDescription,
+    LDAPSyntaxDescription,
+    DITContentRuleDescription,
+    DITStructureRuleDescription,
+    NameFormDescription,
+)
 
 
+syntax_registry.reg_at(
+    ObjectClassDescription.oid,
+    [
+        '2.5.21.6', 'objectClasses',
+    ]
+)
+
+syntax_registry.reg_at(
+    AttributeTypeDescription.oid,
+    [
+        '2.5.21.5', 'attributeTypes',
+    ]
+)
+
+syntax_registry.reg_at(
+    MatchingRuleDescription.oid,
+    [
+        '2.5.21.4', 'matchingRules',
+    ]
+)
+
+syntax_registry.reg_at(
+    MatchingRuleUseDescription.oid,
+    [
+        '2.5.21.8', 'matchingRuleUse',
+    ]
+)
+
+syntax_registry.reg_at(
+    LDAPSyntaxDescription.oid,
+    [
+        '1.3.6.1.4.1.1466.101.120.16', 'ldapSyntaxes',
+    ]
+)
+
+syntax_registry.reg_at(
+    DITContentRuleDescription.oid,
+    [
+        '2.5.21.2', 'dITContentRules',
+    ]
+)
+
+syntax_registry.reg_at(
+    DITStructureRuleDescription.oid,
+    [
+        '2.5.21.1', 'dITStructureRules',
+    ]
+)
+
+syntax_registry.reg_at(
+    NameFormDescription.oid,
+    [
+        '2.5.21.7', 'nameForms',
+    ]
+)
+
 syntax_registry.reg_at(
     OID.oid,
     [
@@ -156,13 +221,17 @@ syntax_registry.reg_at(
 
 
 class UserPassword(OctetString, DirectoryString):
+    """
+    Attribute userPassword can be textual or arbitrary octet strings.
+    This plugin displays textual passwords as readable text.
+    """
     oid: str = 'UserPassword-oid'
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         try:
-            result = DirectoryString.display(self, valueindex, commandbutton)
+            result = DirectoryString.display(self, vidx, links)
         except UnicodeDecodeError:
-            result = OctetString.display(self, valueindex, commandbutton)
+            result = OctetString.display(self, vidx, links)
         return result
 
 syntax_registry.reg_at(
@@ -173,6 +242,10 @@ syntax_registry.reg_at(
 
 
 class NamingContexts(DistinguishedName):
+    """
+    Plugin class for attribute namingContexts present in rootDSE
+    https://datatracker.ietf.org/doc/html/rfc4512#section-5.1.2
+    """
     oid: str = 'NamingContexts-oid'
     desc: str = 'Naming contexts in rootDSE'
     ldap_url = 'ldap:///cn=cn=config?olcSuffix?one?(objectClass=olcDatabaseConfig)'
@@ -183,20 +256,20 @@ class NamingContexts(DistinguishedName):
         config_filter = None
         # Check for OpenLDAP's config context attribute
         try:
-            config_context = self._app.ls.uc_decode(self._app.ls.rootDSE['configContext'][0])[0]
+            config_context = self._app.ls.uc_decode(self._app.ls.root_dse['configContext'][0])[0]
         except KeyError:
             # Check for OpenDJ's config context attribute
             try:
-                _ = self._app.ls.rootDSE['ds-private-naming-contexts']
+                _ = self._app.ls.root_dse['ds-private-naming-contexts']
             except KeyError:
                 pass
             else:
                 config_context = 'cn=Backends,cn=config'
                 config_filter = '(&(objectClass=ds-cfg-backend)(ds-cfg-base-dn=%s))' % (self.av_u)
-                config_scope_str = web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL
+                config_scope_str = SEARCH_SCOPE_STR_ONELEVEL
         else:
             config_filter = '(&(objectClass=olcDatabaseConfig)(olcSuffix=%s))' % (self.av_u)
-            config_scope_str = web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL
+            config_scope_str = SEARCH_SCOPE_STR_ONELEVEL
         if config_context and config_scope_str and config_filter:
             return self._app.anchor(
                 'search', 'Config',
@@ -215,21 +288,28 @@ class NamingContexts(DistinguishedName):
         monitor_filter = None
         # Check for OpenLDAP's config context attribute
         try:
-            _ = self._app.ls.rootDSE['monitorContext']
+            _ = self._app.ls.root_dse['monitorContext']
         except KeyError:
             # Check for OpenDJ's config context attribute
             try:
-                _ = self._app.ls.rootDSE['ds-private-naming-contexts']
+                _ = self._app.ls.root_dse['ds-private-naming-contexts']
             except KeyError:
                 pass
             else:
                 monitor_context = 'cn=monitor'
-                monitor_filter = '(&(objectClass=ds-backend-monitor-entry)(ds-backend-base-dn=%s))' % (self.av_u)
-                monitor_scope_str = web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL
+                monitor_filter = (
+                    '(&'
+                    '(objectClass=ds-backend-monitor-entry)'
+                    '(ds-backend-base-dn=%s)'
+                    ')'
+                ) % (
+                    self.av_u
+                )
+                monitor_scope_str = SEARCH_SCOPE_STR_ONELEVEL
         else:
             monitor_context = 'cn=Databases,cn=Monitor'
             monitor_filter = '(&(objectClass=monitoredObject)(namingContexts=%s))' % (self.av_u)
-            monitor_scope_str = web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL
+            monitor_scope_str = SEARCH_SCOPE_STR_ONELEVEL
         if monitor_context and monitor_scope_str and monitor_filter:
             return self._app.anchor(
                 'search', 'Monitor',
@@ -248,7 +328,7 @@ class NamingContexts(DistinguishedName):
             'search', 'Down',
             (
                 ('dn', self.av_u),
-                ('scope', web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL),
+                ('scope', SEARCH_SCOPE_STR_ONELEVEL),
                 ('filterstr', '(objectClass=*)'),
             )
         ))
@@ -273,6 +353,10 @@ syntax_registry.reg_at(
 
 
 class AltServer(LDAPUrl):
+    """
+    Plugin class for attribute altServer optionally present in rootDSE
+    https://datatracker.ietf.org/doc/html/rfc4512#section-5.1.1
+    """
     oid: str = 'AltServer-oid'
     desc: str = 'LDAP URIs of alternative server(s)'
 
