@@ -10,14 +10,15 @@ from typing import Dict
 import ldap0
 import ldap0.filter
 
-from web2ldap.app.schema.syntaxes import \
-    DirectoryString, \
-    SelectList, \
-    SecondsSinceEpoch, \
-    IA5String, \
-    DynamicValueSelectList, \
-    syntax_registry
-from web2ldap.app.plugins.activedirectory import LogonHours
+from ..schema.syntaxes import (
+    DirectoryString,
+    SelectList,
+    SecondsSinceEpoch,
+    IA5String,
+    DynamicValueSelectList,
+    syntax_registry,
+)
+from .activedirectory import LogonHours
 
 
 syntax_registry.reg_at(
@@ -49,7 +50,7 @@ class SambaAcctFlags(IA5String):
     oid: str = 'SambaAcctFlags-oid'
     desc: str = 'Samba 3 account flags'
     input_pattern: str = r'^\[[NDHTUMWSLXI ]{0,16}\]$'
-    reObj = re.compile(input_pattern)
+    pattern = re.compile(input_pattern)
     flags_dict = {
         'N': '<b>N</b>o password.',
         'D': '<b>D</b>isabled.',
@@ -64,14 +65,14 @@ class SambaAcctFlags(IA5String):
         'I': '<b>I</b>nterdomain trust account.',
     }
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         flags = self.av_u[1:-1] # trim brackets
         table_rows = [
             '<tr><td>%s</td><td>%s</td></tr>\n' % ({True:'*', False:''}[f in flags], d)
             for f, d in self.flags_dict.items()
         ]
         return '<pre>%s</pre><table>\n%s\n</table>\n' % (
-            self._app.form.utf2display(self.av_u),
+            self._app.form.s2d(self.av_u),
             ''.join(table_rows)
         )
 
@@ -87,7 +88,7 @@ class SambaSID(IA5String):
     oid: str = 'SambaSID-oid'
     desc: str = 'Samba SID (SDDL syntax)'
     input_pattern: str = r'^S(-[0-9]+)+$'
-    reObj = re.compile(input_pattern)
+    pattern = re.compile(input_pattern)
 
     def _search_domain_entry(self, domain_name):
         if domain_name:
@@ -129,9 +130,9 @@ class SambaSID(IA5String):
             domain_sid = primary_group_sid.rsplit('-', 1)[0]
         return domain_sid
 
-    def formValue(self) -> str:
+    def form_value(self) -> str:
         ocs = self._entry.object_class_oid_set()
-        result = IA5String.formValue(self)
+        result = IA5String.form_value(self)
         if result:
             return result
         domain_sid = self._get_domain_sid()
