@@ -4,18 +4,19 @@ web2ldap plugin classes for sudo-ldap
 (see http://www.sudo.ws/sudoers.ldap.man.html)
 """
 
-from web2ldap.app.schema.syntaxes import \
-    DynamicValueSelectList, \
-    NotBefore, \
-    NotAfter, \
-    syntax_registry
+from ..schema.syntaxes import (
+    DynamicValueSelectList,
+    NotBefore,
+    NotAfter,
+    syntax_registry,
+)
 
 
 class SudoUserGroup(DynamicValueSelectList):
     oid: str = 'SudoUserGroup-oid'
     desc: str = 'sudo-ldap: sudoUser (group)'
     ldap_url = 'ldap:///_?cn,cn?sub?(objectClass=posixGroup)'
-    valuePrefix = '%'
+    value_prefix = '%'
 
 
 syntax_registry.reg_at(
