@@ -16,7 +16,12 @@ import asn1crypto.pem
 import asn1crypto.x509
 import asn1crypto.crl
 
-from web2ldap.app.schema.syntaxes import ASN1Object, Binary, GSER, syntax_registry
+from ..schema.syntaxes import (
+    ASN1Object,
+    Binary,
+    GSER,
+    syntax_registry,
+)
 
 
 def x509name2ldapdn(x509name, subschema=None):
@@ -51,15 +56,15 @@ def x509name2ldapdn(x509name, subschema=None):
 class AttributeCertificate(Binary):
     oid: str = '1.3.6.1.4.1.4203.666.11.10.2.1'
     desc: str = 'X.509 Attribute Certificate'
-    mimeType = 'application/pkix-attr-cert'
-    fileExt = 'cer'
+    mime_type = 'application/pkix-attr-cert'
+    file_ext = 'cer'
 
 
 class Certificate(Binary):
     oid: str = '1.3.6.1.4.1.1466.115.121.1.8'
     desc: str = 'X.509 Certificate'
-    mimeType = 'application/pkix-cert'
-    fileExt = 'cer'
+    mime_type = 'application/pkix-cert'
+    file_ext = 'cer'
     cert_display_template = """
     <dl>
       <dt>Issuer:</dt>
@@ -77,13 +82,13 @@ class Certificate(Binary):
     <dd>{extn_value}</dd>
     """
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        if asn1crypto.pem.detect(attrValue):
+    def sanitize(self, attr_value: bytes) -> bytes:
+        if asn1crypto.pem.detect(attr_value):
             try:
-                _, _, attrValue = asn1crypto.pem.unarmor(attrValue, multiple=False)
+                _, _, attr_value = asn1crypto.pem.unarmor(attr_value, multiple=False)
             except ValueError:
                 pass
-        return attrValue
+        return attr_value
 
     def _display_extensions(self, x509):
         html = ['<p>Extensions</p>']
@@ -92,16 +97,16 @@ class Certificate(Binary):
             ext_oid = str(ext['extn_id'])
             html.append(
                 self.cert_extn_display_template.format(
-                    ext_id=self._app.form.utf2display(ext_oid),
+                    ext_id=self._app.form.s2d(ext_oid),
                     ext_name=asn1crypto.x509.ExtensionId._map.get(ext_oid, ext_oid),
                     ext_crit={False:'', True:'critical: '}[ext['critical'].native],
-                    extn_value=self._app.form.utf2display(str(ext['extn_value'].parsed)),
+                    extn_value=self._app.form.s2d(str(ext['extn_value'].parsed)),
                 )
             )
         html.append('</dl>')
         return html
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         html = ['%d bytes' % (len(self._av),)]
         try:
             x509 = asn1crypto.x509.Certificate.load(self._av)
@@ -109,8 +114,12 @@ class Certificate(Binary):
             return ''.join(html)
         html.append(
             self.cert_display_template.format(
-                cert_issuer_dn=self._app.form.utf2display(x509name2ldapdn(x509.issuer, self._schema)),
-                cert_subject_dn=self._app.form.utf2display(x509name2ldapdn(x509.subject, self._schema)),
+                cert_issuer_dn=self._app.form.s2d(
+                    x509name2ldapdn(x509.issuer, self._schema)
+                ),
+                cert_subject_dn=self._app.form.s2d(
+                    x509name2ldapdn(x509.subject, self._schema)
+                ),
                 cert_serial_number_dec=str(x509.serial_number),
                 cert_serial_number_hex=hex(x509.serial_number),
                 cert_not_before=x509['tbs_certificate']['validity']['not_before'].native,
@@ -129,14 +138,14 @@ class Certificate(Binary):
 class CACertificate(Certificate):
     oid: str = 'CACertificate-oid'
     desc: str = 'X.509 CA Certificate'
-    mimeType = 'application/x-x509-ca-cert'
+    mime_type = 'application/x-x509-ca-cert'
 
 
 class CertificateList(Binary):
     oid: str = '1.3.6.1.4.1.1466.115.121.1.9'
     desc: str = 'Certificate Revocation List'
-    mimeType = 'application/pkix-crl'
-    fileExt = 'crl'
+    mime_type = 'application/pkix-crl'
+    file_ext = 'crl'
     crl_display_template = """
       <dl>
         <dt>Issuer:</dt>
@@ -148,22 +157,24 @@ class CertificateList(Binary):
       </dl>
       """
 
-    def sanitize(self, attrValue: bytes) -> bytes:
-        if asn1crypto.pem.detect(attrValue):
+    def sanitize(self, attr_value: bytes) -> bytes:
+        if asn1crypto.pem.detect(attr_value):
             try:
-                _, _, attrValue = asn1crypto.pem.unarmor(attrValue, multiple=False)
+                _, _, attr_value = asn1crypto.pem.unarmor(attr_value, multiple=False)
             except ValueError:
                 pass
-        return attrValue
+        return attr_value
 
-    def display(self, valueindex=0, commandbutton=False) -> str:
+    def display(self, vidx, links) -> str:
         try:
             x509 = asn1crypto.crl.CertificateList.load(self._av)
         except ValueError:
             crl_html = ''
         else:
             crl_html = self.crl_display_template.format(
-                crl_issuer_dn=self._app.form.utf2display(x509name2ldapdn(x509.issuer, self._schema)),
+                crl_issuer_dn=self._app.form.s2d(
+                    x509name2ldapdn(x509.issuer, self._schema)
+                ),
                 crl_this_update=x509['tbs_cert_list']['this_update'].native,
                 crl_next_update=x509['tbs_cert_list']['next_update'].native,
             )
@@ -173,8 +184,8 @@ class CertificateList(Binary):
 class CertificatePair(ASN1Object):
     oid: str = '1.3.6.1.4.1.1466.115.121.1.10'
     desc: str = 'X.509 Certificate Pair'
-    mimeType = 'application/pkix-cert'
-    fileExt = 'cer'
+    mime_type = 'application/pkix-cert'
+    file_ext = 'cer'
 
 
 class SupportedAlgorithm(ASN1Object):
