@@ -14,22 +14,24 @@ https://www.apache.org/licenses/LICENSE-2.0
 
 from collections import UserDict
 
-import ldap0.schema
+import ldap0.dn
 from ldap0.cidict import CIDict
 from ldap0.schema.models import SchemaElementOIDSet, AttributeType
-from ldap0.schema.subentry import SubSchema
-from ldap0.base import encode_entry_dict
-from ldap0.dn import DNObj
 
-import web2ldap.web.forms
-import web2ldap.app.core
-import web2ldap.app.cnf
-import web2ldap.app.gui
-import web2ldap.app.schema
-from web2ldap.log import logger
-from web2ldap.app.schema.syntaxes import syntax_registry
-from web2ldap.msbase import GrabKeys
-from web2ldap.app.schema.viewer import schema_anchor
+from .schema import no_humanreadable_attr, no_userapp_attr
+from .schema.syntaxes import syntax_registry
+from .schema.viewer import schema_anchor
+from . import ErrorExit
+from .tmpl import get_variant_filename
+from .gui import (
+    context_menu_single_entry,
+    footer,
+    header,
+    main_menu,
+    top_section,
+)
+from .form import ExportFormatSelect, InclOpAttrsCheckbox
+from .entry import DisplayEntry
 
 
 class VCardEntry(UserDict):
@@ -43,7 +45,7 @@ class VCardEntry(UserDict):
         return self._entry.__contains__(nameoroid)
 
     def __getitem__(self, nameoroid):
-        if web2ldap.app.schema.no_humanreadable_attr(self._app.schema, nameoroid):
+        if no_humanreadable_attr(self._app.schema, nameoroid):
             raise KeyError('Not human-readable attribute %r not usable in vCard' % (nameoroid,))
         value = self._entry.__getitem__(nameoroid)[0]
         return value.decode(self._app.ls.charset)
@@ -55,7 +57,7 @@ def get_vcard_template(app, object_classes):
     template_oc = list(current_oc_set.intersection(template_dict.data.keys()))
     if not template_oc:
         return None
-    return web2ldap.app.gui.get_variant_filename(template_dict[template_oc[0]], app.form.accept_language)
+    return get_variant_filename(template_dict[template_oc[0]], app.form.accept_language)
 
 
 def generate_vcard(template_str, vcard_entry):
@@ -70,172 +72,6 @@ def generate_vcard(template_str, vcard_entry):
     return '\r\n'.join(res)
 
 
-class DisplayEntry(UserDict):
-
-    def __init__(self, app, dn, schema, entry, sep_attr, commandbutton):
-        assert isinstance(dn, str), TypeError("Argument 'dn' must be str, was %r" % (dn))
-        assert isinstance(schema, SubSchema), \
-            TypeError('Expected schema to be instance of SubSchema, was %r' % (schema))
-        self._app = app
-        self.schema = schema
-        self._set_dn(dn)
-        if isinstance(entry, dict):
-            self.entry = ldap0.schema.models.Entry(schema, dn, entry)
-        elif isinstance(entry, ldap0.schema.models.Entry):
-            self.entry = entry
-        else:
-            raise TypeError(
-                'Invalid type of argument entry, was %s.%s %r' % (
-                    entry.__class__.__module__,
-                    entry.__class__.__name__,
-                    entry,
-                )
-            )
-        self.soc = self.entry.get_structural_oc()
-        self.invalid_attrs = set()
-        self.sep_attr = sep_attr
-        self.commandbutton = commandbutton
-
-    def __getitem__(self, nameoroid):
-        try:
-            values = self.entry.__getitem__(nameoroid)
-        except KeyError:
-            return ''
-        result = []
-        syntax_se = syntax_registry.get_syntax(self.entry._s, nameoroid, self.soc)
-        for i, value in enumerate(values):
-            attr_instance = syntax_se(
-                self._app,
-                self.dn,
-                self.entry._s,
-                nameoroid,
-                value,
-                self.entry,
-            )
-            try:
-                attr_value_html = attr_instance.display(
-                    valueindex=i,
-                    commandbutton=self.commandbutton,
-                )
-            except UnicodeError:
-                # Fall back to hex-dump output
-                attr_instance = web2ldap.app.schema.syntaxes.OctetString(
-                    self._app,
-                    self.dn,
-                    self.schema,
-                    nameoroid,
-                    value,
-                    self.entry,
-                )
-                attr_value_html = attr_instance.display(
-                    valueindex=i,
-                    commandbutton=True,
-                )
-            try:
-                attr_instance.validate(value)
-            except web2ldap.app.schema.syntaxes.LDAPSyntaxValueError:
-                attr_value_html = '<s>%s</s>' % (attr_value_html)
-                self.invalid_attrs.add(nameoroid)
-            result.append(attr_value_html)
-        if self.sep_attr is not None:
-            value_sep = getattr(attr_instance, self.sep_attr)
-            return value_sep.join(result)
-        return result
-
-    def _get_rdn_dict(self, dn):
-        assert isinstance(dn, str), TypeError("Argument 'dn' must be str, was %r" % (dn))
-        entry_rdn_dict = ldap0.schema.models.Entry(
-            self.schema,
-            dn,
-            encode_entry_dict(DNObj.from_str(dn).rdn_attrs()),
-        )
-        for attr_type, attr_values in list(entry_rdn_dict.items()):
-            del entry_rdn_dict[attr_type]
-            d = ldap0.cidict.CIDict()
-            for attr_value in attr_values:
-                assert isinstance(attr_value, bytes), \
-                    TypeError("Var 'attr_value' must be bytes, was %r" % (attr_value))
-                d[attr_value] = None
-            entry_rdn_dict[attr_type] = d
-        return entry_rdn_dict
-
-    def _set_dn(self, dn):
-        self.dn = dn
-        self.rdn_dict = self._get_rdn_dict(dn)
-        # end of _set_dn()
-
-    def get_html_templates(self, cnf_key):
-        read_template_dict = CIDict(self._app.cfg_param(cnf_key, {}))
-        # This gets all object classes no matter what
-        all_object_class_oid_set = self.entry.object_class_oid_set()
-        # Initialize the set with only the STRUCTURAL object class of the entry
-        object_class_oid_set = SchemaElementOIDSet(
-            self.entry._s, ldap0.schema.models.ObjectClass, []
-        )
-        structural_oc = self.entry.get_structural_oc()
-        if structural_oc:
-            object_class_oid_set.add(structural_oc)
-        # Now add the other AUXILIARY and ABSTRACT object classes
-        for oc in all_object_class_oid_set:
-            oc_obj = self.entry._s.get_obj(ldap0.schema.models.ObjectClass, oc)
-            if oc_obj is None or oc_obj.kind != 0:
-                object_class_oid_set.add(oc)
-        template_oc = object_class_oid_set.intersection(read_template_dict.data.keys())
-        return template_oc.names, read_template_dict
-        # end of get_html_templates()
-
-    def template_output(self, cnf_key, display_duplicate_attrs=True):
-        # Determine relevant HTML templates
-        template_oc, read_template_dict = self.get_html_templates(cnf_key)
-        # Sort the object classes by object class category
-        structural_oc, abstract_oc, auxiliary_oc = web2ldap.app.schema.object_class_categories(
-            self.entry._s,
-            template_oc,
-        )
-        # Templates defined => display the entry with the help of the template
-        used_templates = set()
-        displayed_attrs = set()
-        for oc_set in (structural_oc, abstract_oc, auxiliary_oc):
-            for oc in oc_set:
-                read_template_filename = read_template_dict[oc]
-                logger.debug('Template file name %r defined for %r', read_template_dict[oc], oc)
-                if not read_template_filename:
-                    logger.warning('Ignoring empty template file name for %r', oc)
-                    continue
-                read_template_filename = web2ldap.app.gui.get_variant_filename(
-                    read_template_filename,
-                    self._app.form.accept_language,
-                )
-                if read_template_filename in used_templates:
-                    # template already processed
-                    logger.debug(
-                        'Skipping already processed template file name %r for %r',
-                        read_template_dict[oc],
-                        oc,
-                    )
-                    continue
-                used_templates.add(read_template_filename)
-                try:
-                    with open(read_template_filename, 'rb') as template_file:
-                        template_str = template_file.read().decode('utf-8')
-                except IOError as err:
-                    logger.error(
-                        'Error reading template file %r for %r: %s',
-                        read_template_dict[oc],
-                        oc,
-                        err,
-                    )
-                    continue
-                template_attr_oid_set = {
-                    self.entry._s.get_oid(ldap0.schema.models.AttributeType, attr_type_name)
-                    for attr_type_name in GrabKeys(template_str)()
-                }
-                if display_duplicate_attrs or not displayed_attrs.intersection(template_attr_oid_set):
-                    self._app.outf.write(template_str % self)
-                    displayed_attrs.update(template_attr_oid_set)
-        return displayed_attrs # template_output()
-
-
 def display_attribute_table(app, entry, attrs, comment):
     """
     Send a table of attributes to outf
@@ -271,7 +107,7 @@ def display_attribute_table(app, entry, attrs, comment):
     # Set separation of attribute values inactive
     entry.sep = None
     for attr_type_name in show_attrs:
-        attr_type_anchor_id = 'readattr_%s' % app.form.utf2display(attr_type_name)
+        attr_type_anchor_id = 'readattr_%s' % app.form.s2d(attr_type_name)
         attr_type_str = schema_anchor(
             app,
             attr_type_name,
@@ -305,8 +141,8 @@ def display_attribute_table(app, entry, attrs, comment):
                 ))
             else:
                 dt_list.append('(%d values)' % (attr_value_count))
-        if web2ldap.app.schema.no_humanreadable_attr(app.schema, attr_type_name):
-            if not web2ldap.app.schema.no_userapp_attr(app.schema, attr_type_name):
+        if no_humanreadable_attr(app.schema, attr_type_name):
+            if not no_userapp_attr(app.schema, attr_type_name):
                 dt_list.append(app.anchor(
                     'delete', 'Delete',
                     [('dn', app.dn), ('delete_attr', attr_type_name)]
@@ -370,7 +206,7 @@ def w2l_read(app):
 
     # Determine how to get all attributes including the operational attributes
     if not wanted_attrs:
-        if app.ls.supportsAllOpAttr:
+        if app.ls.supports_allop_attr:
             wanted_attrs = ['*', '+']
         else:
             wanted_attrs = []
@@ -383,11 +219,15 @@ def w2l_read(app):
     )
 
     if not search_result:
-        raise web2ldap.app.core.ErrorExit(u'Empty search result.')
+        raise ErrorExit(u'Empty search result.')
 
     entry = ldap0.schema.models.Entry(app.schema, app.dn, search_result.entry_as)
 
-    requested_attrs = SchemaElementOIDSet(app.schema, AttributeType, app.cfg_param('requested_attrs', []))
+    requested_attrs = SchemaElementOIDSet(
+        app.schema,
+        AttributeType,
+        app.cfg_param('requested_attrs', []),
+    )
     if not wanted_attrs and requested_attrs:
         try:
             search_result = app.ls.l.read_s(
@@ -406,7 +246,7 @@ def w2l_read(app):
             if search_result:
                 entry.update(search_result.entry_as)
 
-    display_entry = DisplayEntry(app, app.dn, app.schema, entry, 'readSep', 1)
+    display_entry = DisplayEntry(app, app.dn, app.schema, entry, 'read_sep', 1)
 
     if (
             wanted_attrs
@@ -424,9 +264,9 @@ def w2l_read(app):
             if attr_type+';binary' in entry:
                 attr_type = attr_type+';binary'
             else:
-                raise web2ldap.app.core.ErrorExit(
+                raise ErrorExit(
                     u'Attribute <em>%s</em> not in entry.' % (
-                        app.form.utf2display(attr_type)
+                        app.form.s2d(attr_type)
                     )
                 )
 
@@ -437,17 +277,17 @@ def w2l_read(app):
         # We have to create an LDAPSyntax instance to be able to call its methods
         attr_instance = syntax_se(app, app.dn, app.schema, attr_type, None, entry)
         # Send HTTP header with appropriate MIME type
-        web2ldap.app.gui.Header(
+        header(
             app,
             app.form.getInputValue(
                 'read_attrmimetype',
-                [attr_instance.mimeType],
+                [attr_instance.mime_type],
             )[0],
             app.form.accept_charset,
             more_headers=[
                 (
                     'Content-Disposition',
-                    'inline; filename=web2ldap-export.%s' % (attr_instance.fileExt,)
+                    'inline; filename=web2ldap-export.%s' % (attr_instance.file_ext,)
                 ),
             ]
         )
@@ -459,19 +299,23 @@ def w2l_read(app):
     if read_output in {u'table', u'template'}:
 
         # Display the whole entry with all its attributes
-        web2ldap.app.gui.top_section(
+        top_section(
             app,
             '',
-            web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.context_menu_single_entry(
+            main_menu(app),
+            context_menu_list=context_menu_single_entry(
                 app,
                 vcard_link=not get_vcard_template(app, entry.get('objectClass', [])) is None,
                 dds_link=b'dynamicObject' in entry.get('objectClass', []),
-                entry_uuid=entry['entryUUID'][0].decode(app.ls.charset) if 'entryUUID' in entry else None
+                entry_uuid=(
+                    entry['entryUUID'][0].decode(app.ls.charset)
+                    if 'entryUUID' in entry
+                    else None
+                )
             )
         )
 
-        export_field = web2ldap.app.form.ExportFormatSelect()
+        export_field = ExportFormatSelect()
         export_field.charset = app.form.accept_charset
 
         # List of already displayed attributes
@@ -488,7 +332,7 @@ def w2l_read(app):
                 extrastr='\n'.join((
                     export_field.input_html(),
                     'Incl. op. attrs.:',
-                    web2ldap.app.form.InclOpAttrsCheckbox().input_html(),
+                    InclOpAttrsCheckbox().input_html(),
                 )),
                 target='web2ldapexport',
             ),
@@ -511,7 +355,7 @@ def w2l_read(app):
                 )[0].decode(app.ls.charset) or str(app.dn_obj.slice(0, 1))
             app.outf.write(
                 '<h1>{0}</h1>\n<p class="EntryDN">{1}</p>\n'.format(
-                    app.form.utf2display(h1_display_name),
+                    app.form.s2d(h1_display_name),
                     display_entry['entryDN'],
                 )
             )
@@ -550,7 +394,7 @@ def w2l_read(app):
         display_attribute_table(app, display_entry, allowed_attrs, 'Allowed Attributes')
         display_attribute_table(app, display_entry, collective_attrs, 'Collective Attributes')
         display_attribute_table(app, display_entry, nomatching_attrs, 'Various Attributes')
-        display_entry.sep_attr = 'readSep'
+        display_entry.sep_attr = 'read_sep'
 
         app.outf.write(
             """%s\n%s\n%s<p>\n%s\n
@@ -559,20 +403,20 @@ def w2l_read(app):
             </p></form>
             """ % (
                 app.begin_form('read', 'GET'),
-                app.form.hiddenFieldHTML('read_nocache', u'1', u''),
-                app.form.hiddenFieldHTML('dn', app.dn, u''),
-                app.form.hiddenFieldHTML('read_output', read_output, u''),
+                app.form.hidden_field_html('read_nocache', u'1', u''),
+                app.form.hidden_field_html('dn', app.dn, u''),
+                app.form.hidden_field_html('read_output', read_output, u''),
                 ','.join([
-                    app.form.utf2display(at, sp_entity='  ')
+                    app.form.s2d(at, sp_entity='  ')
                     for at in (
                         wanted_attrs
-                        or {False:['*'], True:['*', '+']}[app.ls.supportsAllOpAttr]
+                        or {False:['*'], True:['*', '+']}[app.ls.supports_allop_attr]
                     )
                 ])
             )
         )
 
-        web2ldap.app.gui.footer(app)
+        footer(app)
 
     elif read_output == 'vcard':
 
@@ -583,13 +427,14 @@ def w2l_read(app):
         vcard_template_filename = get_vcard_template(app, entry.get('objectClass', []))
 
         if not vcard_template_filename:
-            raise web2ldap.app.core.ErrorExit(u'No vCard template file found for object class(es) of this entry.')
+            raise ErrorExit(u'No vCard template file found for object class(es) of this entry.')
 
         # Templates defined => display the entry with the help of a template
         try:
-            template_str = open(vcard_template_filename, 'rb').read()
+            with open(vcard_template_filename, 'rb') as fileobj:
+                template_str = fileobj.read()
         except IOError:
-            raise web2ldap.app.core.ErrorExit(u'I/O error during reading vCard template file!')
+            raise ErrorExit(u'I/O error during reading vCard template file!')
 
         vcard_filename = u'web2ldap-vcard'
         for vcard_name_attr in ('displayName', 'cn', 'o'):
@@ -601,7 +446,7 @@ def w2l_read(app):
                 break
         entry['dn'] = [app.ldap_dn]
         display_entry = VCardEntry(app, entry)
-        web2ldap.app.gui.Header(
+        header(
             app,
             'text/x-vcard',
             app.form.accept_charset,
