@@ -16,9 +16,7 @@ import time
 
 from ldap0.ldapurl import LDAPUrl
 
-import web2ldap.app.core
-import web2ldap.app.gui
-import web2ldap.app.cnf
+from .gui import footer, main_menu, read_template, search_root_field, top_section
 
 ERR_MSG_DIV = """
 <h1>Error</h1>
@@ -32,12 +30,7 @@ def w2l_chasereferral(app, ref_exc):
     Present an input form to change to a server referenced by referral
     """
 
-    web2ldap.app.gui.top_section(
-        app,
-        'Referral received',
-        web2ldap.app.gui.main_menu(app),
-        context_menu_list=[]
-    )
+    top_section(app, 'Referral received', main_menu(app), context_menu_list=[])
 
     # Pull out referral LDAP URL
     try:
@@ -49,11 +42,11 @@ def w2l_chasereferral(app, ref_exc):
         app.outf.write(
             ERR_MSG_DIV % (
                 'Error extracting referral LDAP URL from %s.' % (
-                    app.form.utf2display(str(repr(ref_exc), 'ascii'))
+                    app.form.s2d(str(repr(ref_exc), 'ascii'))
                 )
             )
         )
-        web2ldap.app.gui.footer(app)
+        footer(app)
         return
 
     try:
@@ -62,11 +55,11 @@ def w2l_chasereferral(app, ref_exc):
         app.outf.write(
             ERR_MSG_DIV % (
                 'Error extracting referral LDAP URL from %s.' % (
-                    app.form.utf2display(repr(ldap_url_info).decode('ascii'))
+                    app.form.s2d(repr(ldap_url_info).decode('ascii'))
                 )
             )
         )
-        web2ldap.app.gui.footer(app)
+        footer(app)
         return
 
     # Parse the referral LDAP URL
@@ -76,26 +69,26 @@ def w2l_chasereferral(app, ref_exc):
         app.outf.write(
             ERR_MSG_DIV % (
                 'Error parsing referral URL %s: %s' % (
-                    app.form.utf2display(repr(ldap_url_info).decode('ascii')),
-                    app.form.utf2display(str(value_error).decode('ascii'))
+                    app.form.s2d(repr(ldap_url_info).decode('ascii')),
+                    app.form.s2d(str(value_error).decode('ascii'))
                 )
             )
         )
-        web2ldap.app.gui.footer(app)
+        footer(app)
         return
 
-    login_template_str = web2ldap.app.gui.read_template(
+    login_template_str = read_template(
         app, 'login_template', u'referral login form'
     )
 
-    login_search_root_field = web2ldap.app.gui.search_root_field(
+    login_search_root_field = search_root_field(
         app,
         name='login_search_root',
     )
     login_fields = login_template_str.format(
         field_login_mech=app.form.field['login_mech'].input_html(),
-        value_ldap_who=app.form.utf2display(app.ls.who),
-        value_ldap_mapping=app.form.utf2display(app.binddn_mapping),
+        value_ldap_who=app.form.s2d(app.ls.who),
+        value_ldap_mapping=app.form.s2d(app.binddn_mapping),
         field_login_search_root=login_search_root_field.input_html(),
         field_login_authzid_prefix=app.form.field['login_authzid_prefix'].input_html(),
         value_submit='Chase Referral',
@@ -110,10 +103,10 @@ def w2l_chasereferral(app, ref_exc):
         </p>
         %s\n%s\n%s\n%s
         """  % (
-            app.form.utf2display(ref_url.unparse()),
+            app.form.s2d(ref_url.unparse()),
             app.begin_form(app.command, 'POST'),
-            app.form.hiddenFieldHTML('host', ref_url.hostport, u''),
-            app.form.hiddenFieldHTML('dn', ref_url.dn, u''),
+            app.form.hidden_field_html('host', ref_url.hostport, u''),
+            app.form.hidden_field_html('dn', ref_url.dn, u''),
             login_fields,
         )
     )
@@ -123,4 +116,4 @@ def w2l_chasereferral(app, ref_exc):
     )
     app.outf.write('</form>\n')
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
