@@ -12,21 +12,19 @@ Apache License Version 2.0 (Apache-2.0)
 https://www.apache.org/licenses/LICENSE-2.0
 """
 
+from typing import Dict
+
 import ldap0
 import ldap0.ldapurl
 import ldap0.filter
-from typing import Dict
 
-import web2ldap.web.forms
-
-import web2ldap.ldaputil
-import web2ldap.app.core
-import web2ldap.app.cnf
-import web2ldap.app.gui
-import web2ldap.app.form
-import web2ldap.app.schema
-import web2ldap.app.schema.syntaxes
-from web2ldap.app.schema.viewer import schema_anchors
+from ..web import forms
+from .schema.viewer import schema_anchors
+from . import ErrorExit
+from .form import DistinguishedNameInput
+from .schema.syntaxes import DynamicDNSelectList
+from .gui import context_menu_single_entry, footer, main_menu, top_section
+from .gui import read_template, search_root_field
 
 
 def new_superior_field(app, sup_search_url, old_superior_dn):
@@ -34,7 +32,7 @@ def new_superior_field(app, sup_search_url, old_superior_dn):
     returns Select field for choosing a new superior entry
     """
 
-    class NewSuperiorSelectList(web2ldap.app.schema.syntaxes.DynamicDNSelectList):
+    class NewSuperiorSelectList(DynamicDNSelectList):
         """
         plugin class for choosing a new superior entry
         """
@@ -42,22 +40,20 @@ def new_superior_field(app, sup_search_url, old_superior_dn):
             '': '- Root Naming Context -',
         }
 
-        def __init__(self, app, dn, schema, attrType, attrValue, ldap_url):
+        def __init__(self, app, dn, schema, attr_type, attr_value, ldap_url):
             self.ldap_url = ldap_url
-            web2ldap.app.schema.syntaxes.DynamicDNSelectList.__init__(
-                self, app, dn, schema, attrType, attrValue, entry=None,
-            )
+            DynamicDNSelectList.__init__(self, app, dn, schema, attr_type, attr_value, entry=None)
 
     if not sup_search_url is None:
         attr_inst = NewSuperiorSelectList(
             app, app.dn,
             app.schema, 'rdn', old_superior_dn.encode(app.ls.charset), str(sup_search_url),
         )
-        nssf = attr_inst.formField()
+        nssf = attr_inst.input_field()
         nssf.name = 'rename_newsuperior'
         nssf.text = 'New Superior DN'
     else:
-        nssf = web2ldap.app.form.DistinguishedNameInput('rename_newsuperior', 'New Superior DN')
+        nssf = DistinguishedNameInput('rename_newsuperior', 'New Superior DN')
     nssf.charset = app.form.accept_charset
     nssf.set_default(old_superior_dn)
     return nssf # new_superior_field()
@@ -71,7 +67,7 @@ def w2l_rename(app):
     rename_supsearchurl_cfg = app.cfg_param('rename_supsearchurl', {})
 
     if not app.dn:
-        raise web2ldap.app.core.ErrorExit(u'Rename operation not possible at - World - or RootDSE.')
+        raise ErrorExit(u'Rename operation not possible at - World - or RootDSE.')
 
     rename_newrdn = app.form.getInputValue('rename_newrdn', [None])[0]
     rename_newsuperior = app.form.getInputValue('rename_newsuperior', [None])[0]
@@ -99,8 +95,8 @@ def w2l_rename(app):
                 app.display_dn(old_dn),
                 app.display_dn(app.dn)
             ),
-            main_menu_list=web2ldap.app.gui.main_menu(app),
-            context_menu_list=web2ldap.app.gui.context_menu_single_entry(
+            main_menu_list=main_menu(app),
+            context_menu_list=context_menu_single_entry(
                 app, entry_uuid=entry_uuid
             ),
         )
@@ -114,7 +110,7 @@ def w2l_rename(app):
 
     app.form.field['rename_newrdn'].set_default(old_rdn)
 
-    rename_template_str = web2ldap.app.gui.read_template(app, 'rename_template', u'rename form')
+    rename_template_str = read_template(app, 'rename_template', u'rename form')
 
     rename_supsearchurl = app.form.getInputValue('rename_supsearchurl', [None])[0]
     try:
@@ -149,7 +145,7 @@ def w2l_rename(app):
         rename_newsupfilter_default = app.form.field['rename_newsupfilter'].default
         scope_default = str(ldap0.SCOPE_SUBTREE)
 
-    rename_search_root_field = web2ldap.app.gui.search_root_field(app, name='rename_searchroot')
+    rename_search_root_field = search_root_field(app, name='rename_searchroot')
     rename_new_superior_field = new_superior_field(app, sup_search_url, old_superior)
 
     name_forms_text = ''
@@ -162,7 +158,7 @@ def w2l_rename(app):
             attrlist=['objectClass', 'structuralObjectClass', 'governingStructureRule'],
         )
         if not search_result:
-            raise web2ldap.app.core.ErrorExit(
+            raise ErrorExit(
                 u'Empty search result when reading entry to be renamed.'
             )
 
@@ -201,31 +197,31 @@ def w2l_rename(app):
                 )
 
     if rename_supsearchurl_cfg:
-        rename_supsearchurl_field = web2ldap.web.forms.Select(
+        rename_supsearchurl_field = forms.Select(
             'rename_supsearchurl',
             u'LDAP URL for searching new superior entry',
             1,
             options=[],
         )
-        rename_supsearchurl_field.setOptions(rename_supsearchurl_cfg.keys())
+        rename_supsearchurl_field.set_options(rename_supsearchurl_cfg.keys())
 
     # Output empty input form for new RDN
-    web2ldap.app.gui.top_section(
+    top_section(
         app,
         'Rename Entry',
-        web2ldap.app.gui.main_menu(app),
+        main_menu(app),
         context_menu_list=[],
     )
 
     app.outf.write(
         rename_template_str.format(
             form_begin=app.begin_form('rename', 'POST'),
-            field_hidden_dn=app.form.hiddenFieldHTML('dn', app.dn, u''),
+            field_hidden_dn=app.form.hidden_field_html('dn', app.dn, u''),
             field_rename_newrdn=app.form.field['rename_newrdn'].input_html(),
             field_rename_new_superior=rename_new_superior_field.input_html(),
             text_name_forms=name_forms_text,
             field_rename_supsearchurl=rename_supsearchurl_field.input_html(),
-            value_rename_newsupfilter=app.form.utf2display(rename_newsupfilter_default),
+            value_rename_newsupfilter=app.form.s2d(rename_newsupfilter_default),
             field_rename_search_root=rename_search_root_field.input_html(
                 default=rename_searchroot_default,
             ),
@@ -234,4 +230,4 @@ def w2l_rename(app):
         )
     )
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
