@@ -27,26 +27,33 @@ from ldap0.controls.openldap import SearchNoOpControl
 from ldap0.schema.models import AttributeType
 from ldap0.base import decode_list
 from ldap0.res import SearchReference, SearchResultEntry
+from ldap0.openldap import ldapsearch_cmd
 
-import web2ldap.web.forms
-from web2ldap.web import escape_html
-import web2ldap.ldaputil.asynch
-import web2ldap.msbase
-import web2ldap.ldaputil
-import web2ldap.app.core
-import web2ldap.app.cnf
-import web2ldap.app.gui
-import web2ldap.app.read
-import web2ldap.app.searchform
-from web2ldap.ldaputil.extldapurl import ExtendedLDAPUrl
-from web2ldap.msbase import GrabKeys
-from web2ldap.app.schema.syntaxes import syntax_registry
-from web2ldap.app.searchform import SEARCH_OPT_ATTR_EXISTS, SEARCH_OPT_ATTR_NOT_EXISTS
-from web2ldap.ldapsession import LDAPLimitErrors
-from web2ldap.msbase import CaseinsensitiveStringKeyDict
-from web2ldap.wsgi import WSGIBytesWrapper
+from ..__about__ import __version__
+from ..web import escape_html
+from ..ldaputil import asynch
+from ..ldaputil import has_subordinates
+from ..ldaputil.extldapurl import ExtendedLDAPUrl
+from ..ldapsession import LDAPLimitErrors
+from ..msbase import GrabKeys, CaseinsensitiveStringKeyDict
+from ..web.wsgi import WSGIBytesWrapper
+from . import ErrorExit
 
-import web2ldap.__about__
+from .form import ExportFormatSelect, InclOpAttrsCheckbox
+from .entry import DisplayEntry
+from .schema.syntaxes import syntax_registry
+from .searchform import (
+    w2l_searchform,
+    SEARCH_OPT_ATTR_EXISTS,
+    SEARCH_OPT_ATTR_NOT_EXISTS,
+    SEARCH_SCOPE_STR_ONELEVEL,
+)
+from .gui import (
+    footer,
+    gen_headers,
+    main_menu,
+    top_section,
+)
 
 SEARCH_NOOP_TIMEOUT = 5.0
 
@@ -103,21 +110,21 @@ is_search_reference = {
 }
 
 
-class excel_semicolon(csv.excel):
+class ExcelSemicolon(csv.excel):
     """Describe the usual properties of Excel-generated TAB-delimited files."""
     delimiter = ';'
 
-csv.register_dialect('excel-semicolon', excel_semicolon)
+csv.register_dialect('excel-semicolon', ExcelSemicolon)
 
 
-class LDIFWriter(web2ldap.ldaputil.asynch.LDIFWriter):
+class LDIFWriter(asynch.LDIFWriter):
 
     def pre_processing(self):
         return
 
     def after_first(self):
         self._ldif_writer._output_file.set_headers(
-            web2ldap.app.gui.gen_headers(
+            gen_headers(
                 content_type='text/plain',
                 charset='utf-8',
                 more_headers=[
@@ -125,47 +132,47 @@ class LDIFWriter(web2ldap.ldaputil.asynch.LDIFWriter):
                 ]
             )
         )
-        web2ldap.ldaputil.asynch.LDIFWriter.pre_processing(self)
+        asynch.LDIFWriter.pre_processing(self)
 
 
-class PrintableHTMLWriter(web2ldap.ldaputil.asynch.List):
+class PrintableHTMLWriter(asynch.List):
     """
     Class for writing a stream LDAP search results to a printable file
     """
     _entryResultTypes = is_search_result
 
     def __init__(self, app, dn, sub_schema, print_template_str_dict):
-        web2ldap.ldaputil.asynch.List.__init__(self, app.ls.l)
+        asynch.List.__init__(self, app.ls.l)
         self._app = app
         self._dn = dn
         self._s = sub_schema
         self._p = print_template_str_dict
 
     def process_results(self, ignoreResultsNumber=0, processResultsCount=0):
-        web2ldap.ldaputil.asynch.List.process_results(self)
+        asynch.List.process_results(self)
         #self.allResults.sort()
         # This should speed up things
-        utf2display = self._app.form.utf2display
+        s2d = self._app.form.s2d
         print_cols = self._app.cfg_param('print_cols', '4')
         table = []
-        for r in self.allResults:
-            if not isinstance(r, SearchResultEntry):
+        for res in self.allResults:
+            if not isinstance(res, SearchResultEntry):
                 continue
-            objectclasses = r.entry_s.get('objectclass', r.entry_s.get('objectClass', []))
+            objectclasses = res.entry_s.get('objectclass', res.entry_s.get('objectClass', []))
             template_oc = list(
-                {o.lower() for o in objectclasses} & {s.lower() for s in self._p.keys()}
+                {ocl.lower() for ocl in objectclasses} & {s.lower() for s in self._p.keys()}
             )
             if template_oc:
                 tableentry = CaseinsensitiveStringKeyDict(default='')
-                attr_list = r.entry_s.keys()
+                attr_list = res.entry_s.keys()
                 for attr in attr_list:
                     tableentry[attr] = ', '.join([
-                        utf2display(attr_value)
-                        for attr_value in r.entry_s[attr]
+                        s2d(attr_value)
+                        for attr_value in res.entry_s[attr]
                     ])
                 table.append(self._p[template_oc[0]] % (tableentry))
         # Output search results as pretty-printable table without buttons
-        web2ldap.app.gui.top_section(self._app, 'Printable Search Results', [])
+        top_section(self._app, 'Printable Search Results', [])
         self._app.outf.write(
             """
             <table
@@ -182,11 +189,11 @@ class PrintableHTMLWriter(web2ldap.ldaputil.asynch.List):
             ]
             self._app.outf.write('<tr>\n%s</tr>\n' % ('\n'.join(td_list)))
         self._app.outf.write('</table>\n')
-        web2ldap.app.gui.footer(self._app)
+        footer(self._app)
         # end of process_results()
 
 
-class CSVWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
+class CSVWriter(asynch.AsyncSearchHandler):
     """
     Class for writing a stream LDAP search results to a CSV file
     """
@@ -194,7 +201,7 @@ class CSVWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
     _formular_prefixes = frozenset('@+-=|%')
 
     def __init__(self, l, f, sub_schema, attr_types, ldap_charset='utf-8'):
-        web2ldap.ldaputil.asynch.AsyncSearchHandler.__init__(self, l)
+        asynch.AsyncSearchHandler.__init__(self, l)
         self._output_file = f
         self._csv_writer = csv.writer(f, dialect='excel-semicolon')
         self._s = sub_schema
@@ -203,7 +210,7 @@ class CSVWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
 
     def after_first(self):
         self._output_file.set_headers(
-            web2ldap.app.gui.gen_headers(
+            gen_headers(
                 content_type='text/csv',
                 charset='utf-8',
                 more_headers=[
@@ -233,14 +240,14 @@ class CSVWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
         self._csv_writer.writerow(csv_row_list)
 
 
-class ExcelWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
+class ExcelWriter(asynch.AsyncSearchHandler):
     """
     Class for writing a stream LDAP search results to a Excel file
     """
     _entryResultTypes = is_search_result
 
     def __init__(self, l, f, sub_schema, attr_types, ldap_charset='utf-8'):
-        web2ldap.ldaputil.asynch.AsyncSearchHandler.__init__(self, l)
+        asynch.AsyncSearchHandler.__init__(self, l)
         self._f = f
         self._s = sub_schema
         self._attr_types = attr_types
@@ -251,7 +258,7 @@ class ExcelWriter(web2ldap.ldaputil.asynch.AsyncSearchHandler):
 
     def after_first(self):
         self._f.set_headers(
-            web2ldap.app.gui.gen_headers(
+            gen_headers(
                 content_type='application/vnd.ms-excel',
                 charset='utf-8',
                 more_headers=[
@@ -332,16 +339,16 @@ def w2l_search(app):
     searchform_mode = app.form.getInputValue('searchform_mode', [u'exp'])[0]
 
     if search_submit != u'Search' and searchform_mode == 'adv':
-        web2ldap.app.searchform.w2l_searchform(
+        w2l_searchform(
             app,
-            Msg='',
+            msg='',
             filterstr=u'',
             scope=scope
         )
         return
 
     # This should speed up things
-    utf2display = app.form.utf2display
+    s2d = app.form.s2d
 
     search_output = app.form.getInputValue('search_output', ['table'])[0]
     search_opattrs = app.form.getInputValue('search_opattrs', ['no'])[0] == 'yes'
@@ -359,7 +366,7 @@ def w2l_search(app):
     search_string = app.form.getInputValue('search_string', [])
 
     if not len(search_option) == len(search_attr) == len(search_mr) == len(search_string):
-        raise web2ldap.app.core.ErrorExit(u'Invalid search form data.')
+        raise ErrorExit(u'Invalid search form data.')
 
     # Build LDAP search filter from input data of advanced search form
     for i in range(len(search_attr)):
@@ -388,9 +395,9 @@ def w2l_search(app):
     search_filter = list(filter(None, search_filter))
 
     if not search_filter:
-        web2ldap.app.searchform.w2l_searchform(
+        w2l_searchform(
             app,
-            Msg='Empty search values.',
+            msg='Empty search values.',
             filterstr=u'',
             scope=scope
         )
@@ -444,7 +451,7 @@ def w2l_search(app):
     search_ldap_url.scope = scope
     search_ldap_url.attrs = search_attrs
 
-    ldap_search_command = search_ldap_url.ldapsearch_cmd()
+    ldap_search_command = ldapsearch_cmd(search_ldap_url)
 
     read_attr_set = ldap0.schema.models.SchemaElementOIDSet(app.schema, AttributeType, search_attrs)
     if search_output in {'table', 'print'}:
@@ -453,16 +460,16 @@ def w2l_search(app):
     if search_output == 'print':
         print_template_filenames_dict = app.cfg_param('print_template', None)
         if print_template_filenames_dict is None:
-            raise web2ldap.app.core.ErrorExit(u'No templates for printing defined.')
+            raise ErrorExit(u'No templates for printing defined.')
         print_template_str_dict = CaseinsensitiveStringKeyDict()
-        for oc in print_template_filenames_dict.keys():
+        for ocl in print_template_filenames_dict.keys():
             try:
-                with open(print_template_filenames_dict[oc], 'r') as template_file:
-                    print_template_str_dict[oc] = template_file.read()
+                with open(print_template_filenames_dict[ocl], 'r') as template_file:
+                    print_template_str_dict[ocl] = template_file.read()
             except IOError:
                 pass
             else:
-                read_attr_set.update(GrabKeys(print_template_str_dict[oc]).keys)
+                read_attr_set.update(GrabKeys(print_template_str_dict[ocl]).keys)
         read_attrs = read_attr_set.names
         result_handler = PrintableHTMLWriter(app, search_root, app.schema, print_template_str_dict)
 
@@ -471,8 +478,8 @@ def w2l_search(app):
         search_tdtemplate = ldap0.cidict.CIDict(app.cfg_param('search_tdtemplate', {}))
         search_tdtemplate_keys = search_tdtemplate.keys()
         search_tdtemplate_attrs_lower = ldap0.cidict.CIDict()
-        for oc in search_tdtemplate_keys:
-            search_tdtemplate_attrs_lower[oc] = GrabKeys(search_tdtemplate[oc]).keys
+        for ocl in search_tdtemplate_keys:
+            search_tdtemplate_attrs_lower[ocl] = GrabKeys(search_tdtemplate[ocl]).keys
 
         # Start with operational attributes used to determine subordinate
         # entries existence/count
@@ -487,25 +494,25 @@ def w2l_search(app):
 
         # Extend with list of attributes to read for displaying results with templates
         if search_output == 'table':
-            for oc in search_tdtemplate_keys:
-                read_attr_set.update(GrabKeys(search_tdtemplate[oc]).keys)
+            for ocl in search_tdtemplate_keys:
+                read_attr_set.update(GrabKeys(search_tdtemplate[ocl]).keys)
         read_attr_set.discard('entryDN')
         read_attrs = read_attr_set.names
 
         # Create async search handler instance
-        result_handler = web2ldap.ldaputil.asynch.List(app.ls.l)
+        result_handler = asynch.List(app.ls.l)
 
     elif search_output in {'ldif', 'ldif1'}:
         # read all attributes
         read_attrs = (
             search_attrs
-            or {False:('*',), True:('*', '+')}[app.ls.supportsAllOpAttr and search_opattrs]+requested_attrs
+            or {False:('*',), True:('*', '+')}[app.ls.supports_allop_attr and search_opattrs]+requested_attrs
             or None
         )
         result_handler = LDIFWriter(app.ls.l, WSGIBytesWrapper(app.outf))
         if search_output == 'ldif1':
             result_handler.header = LDIF1_HEADER % (
-                web2ldap.__about__.__version__,
+                __version__,
                 time.strftime(
                     '%A, %Y-%m-%d %H:%M:%S GMT',
                     time.gmtime(time.time())
@@ -520,9 +527,9 @@ def w2l_search(app):
         if not read_attrs:
             if searchform_mode == u'base':
                 searchform_mode = u'adv'
-            web2ldap.app.searchform.w2l_searchform(
+            w2l_searchform(
                 app,
-                Msg='For table-structured export you have to define the attributes to be read!',
+                msg='For table-structured export you have to define the attributes to be read!',
                 filterstr=filterstr,
                 scope=scope,
                 search_root=search_root,
@@ -551,25 +558,25 @@ def w2l_search(app):
     except (
             ldap0.FILTER_ERROR,
             ldap0.INAPPROPRIATE_MATCHING,
-        ) as e:
+        ) as err:
         # Give the user a chance to edit his bad search filter
-        web2ldap.app.searchform.w2l_searchform(
+        w2l_searchform(
             app,
-            Msg=' '.join((
-                app.ldap_error_msg(e),
-                utf2display(filterstr2),
+            msg=' '.join((
+                app.ldap_error_msg(err),
+                s2d(filterstr2),
             )),
             filterstr=filterstr,
             scope=scope
         )
         return
-    except ldap0.NO_SUCH_OBJECT as e:
+    except ldap0.NO_SUCH_OBJECT as err:
         if app.dn:
-            raise e
+            raise err
 
     if search_output in {'table', 'raw'}:
 
-        SearchWarningMsg = ''
+        search_warning = ''
         max_result_msg = ''
         num_all_search_results, num_all_search_continuations = None, None
         num_result_all = None
@@ -579,9 +586,9 @@ def w2l_search(app):
             result_handler.process_results(
                 search_resminindex, search_resnumber+int(search_resnumber > 0)
             )
-        except (ldap0.SIZELIMIT_EXCEEDED, ldap0.ADMINLIMIT_EXCEEDED) as e:
+        except (ldap0.SIZELIMIT_EXCEEDED, ldap0.ADMINLIMIT_EXCEEDED) as err:
             if search_size_limit < 0 or result_handler.endResultBreak < search_size_limit:
-                SearchWarningMsg = app.ldap_error_msg(e, template=LDAPERROR_SIZELIMIT_MSG)
+                search_warning = app.ldap_error_msg(err, template=LDAPERROR_SIZELIMIT_MSG)
             partial_results = 1
             resind = result_handler.endResultBreak
             # Retrieve the overall number of search results by resending the
@@ -599,22 +606,22 @@ def w2l_search(app):
                         max_result_msg = '(of %d / %d) ' % (num_all_search_results, num_all_search_continuations)
                 except LDAPLimitErrors:
                     pass
-        except (ldap0.FILTER_ERROR, ldap0.INAPPROPRIATE_MATCHING) as e:
+        except (ldap0.FILTER_ERROR, ldap0.INAPPROPRIATE_MATCHING) as err:
             # Give the user a chance to edit his bad search filter
-            web2ldap.app.searchform.w2l_searchform(
+            w2l_searchform(
                 app,
-                Msg=app.ldap_error_msg(e),
+                msg=app.ldap_error_msg(err),
                 filterstr=filterstr,
                 scope=scope
             )
             return
-        except (ldap0.NO_SUCH_OBJECT, ldap0.UNWILLING_TO_PERFORM) as e:
+        except (ldap0.NO_SUCH_OBJECT, ldap0.UNWILLING_TO_PERFORM) as err:
             resind = result_handler.endResultBreak
             if search_root or scope != ldap0.SCOPE_ONELEVEL:
                 # Give the user a chance to edit his bad search filter
-                web2ldap.app.searchform.w2l_searchform(
+                w2l_searchform(
                     app,
-                    Msg=app.ldap_error_msg(e),
+                    msg=app.ldap_error_msg(err),
                     filterstr=filterstr,
                     scope=scope
                 )
@@ -637,7 +644,7 @@ def w2l_search(app):
 
 #        result_dnlist.sort(key=lambda x: x.dn_s)
 
-        ContextMenuList = [
+        ctx_menu_items = [
             app.anchor(
                 'searchform', 'Edit Filter',
                 [
@@ -668,7 +675,7 @@ def w2l_search(app):
         ]
 
         if searchform_mode in {'base', 'adv'}:
-            ContextMenuList.append(
+            ctx_menu_items.append(
                 app.anchor(
                     'searchform', 'Modify Search',
                     app.form.allInputFields(
@@ -699,8 +706,8 @@ def w2l_search(app):
             </table>
             """ % (
                 ldap0.ldapurl.SEARCH_SCOPE_STR[scope],
-                utf2display(search_root),
-                utf2display(filterstr2),
+                s2d(search_root),
+                s2d(filterstr2),
             )
 
         if not result_dnlist:
@@ -710,8 +717,8 @@ def w2l_search(app):
             app.simple_message(
                 'No Search Results',
                 '<p class="WarningMessage">No entries found.</p>%s' % (search_param_html),
-                main_menu_list=web2ldap.app.gui.main_menu(app),
-                context_menu_list=ContextMenuList
+                main_menu_list=main_menu(app),
+                context_menu_list=ctx_menu_items
             )
 
         else:
@@ -721,7 +728,7 @@ def w2l_search(app):
 
             page_command_list = None
 
-            ContextMenuList.extend([
+            ctx_menu_items.extend([
                 app.anchor(
                     'search',
                     {False:'Raw', True:'Table'}[search_output == 'raw'],
@@ -822,23 +829,18 @@ def w2l_search(app):
                 search_bookmark,
             )
 
-            web2ldap.app.gui.top_section(
-                app,
-                'Search Results',
-                web2ldap.app.gui.main_menu(app),
-                context_menu_list=ContextMenuList
-            )
+            top_section(app, 'Search Results', main_menu(app), context_menu_list=ctx_menu_items)
 
-            export_field = web2ldap.app.form.ExportFormatSelect()
+            export_field = ExportFormatSelect()
             export_field.charset = app.form.accept_charset
 
-            app.outf.write('\n'.join((SearchWarningMsg, result_message)))
+            app.outf.write('\n'.join((search_warning, result_message)))
 
             if search_resminindex == 0 and not partial_results:
                 mailtolist = set()
-                for r in result_dnlist:
-                    if isinstance(r, SearchResultEntry):
-                        mailtolist.update(r.entry_s.get('mail', r.entry_s.get('rfc822Mailbox', [])))
+                for res in result_dnlist:
+                    if isinstance(res, SearchResultEntry):
+                        mailtolist.update(res.entry_s.get('mail', res.entry_s.get('rfc822Mailbox', [])))
                 if mailtolist:
                     mailtolist = [urllib.parse.quote(m) for m in mailtolist]
                     app.outf.write('Mail to all <a href="mailto:%s?cc=%s">Cc:-ed</a> - <a href="mailto:?bcc=%s">Bcc:-ed</a>' % (
@@ -853,54 +855,55 @@ def w2l_search(app):
 
             app.outf.write('<table id="SrchResList">\n')
 
-            for r in result_dnlist[0:resind]:
+            for res in result_dnlist[0:resind]:
 
-                if isinstance(r, SearchReference):
+                if isinstance(res, SearchReference):
 
                     # Display a search continuation (search reference)
                     entry = ldap0.cidict.CIDict({})
                     try:
-                        refUrl = ExtendedLDAPUrl(r.ref_url_strings[0])
+                        ref_url = ExtendedLDAPUrl(res.ref_url_strings[0])
                     except ValueError:
                         command_table = []
-                        result_dd_str = 'Search reference (NON-LDAP-URI) =&gt; %s' % (utf2display(str(r[1][1][0])))
+                        result_dd_str = 'Search reference (NON-LDAP-URI) =&gt; %s' % (s2d(str(res[1][1][0])))
                     else:
-                        result_dd_str = 'Search reference =&gt; %s' % (refUrl.htmlHREF(hrefTarget=None))
+                        result_dd_str = 'Search reference =&gt; %s' % (ref_url.htmlHREF(hrefTarget=None))
                         if scope == ldap0.SCOPE_SUBTREE:
-                            refUrl.scope = refUrl.scope or scope
-                            refUrl.filterstr = ((refUrl.filterstr or '') or filterstr)
+                            ref_url.scope = ref_url.scope or scope
+                            ref_url.filterstr = ((ref_url.filterstr or '') or filterstr)
                             command_table = [
                                 app.anchor(
                                     'search', 'Continue search',
-                                    [('ldapurl', refUrl.unparse())],
+                                    [('ldapurl', ref_url.unparse())],
                                     title=u'Follow this search continuation',
                                 )
                             ]
                         else:
                             command_table = []
-                            refUrl.filterstr = filterstr
-                            refUrl.scope = ldap0.SCOPE_BASE
+                            ref_url.filterstr = filterstr
+                            ref_url.scope = ldap0.SCOPE_BASE
                             command_table.append(app.anchor(
                                 'read', 'Read',
-                                [('ldapurl', refUrl.unparse())],
+                                [('ldapurl', ref_url.unparse())],
                                 title=u'Display single entry following search continuation',
                             ))
-                            refUrl.scope = ldap0.SCOPE_ONELEVEL
+                            ref_url.scope = ldap0.SCOPE_ONELEVEL
                             command_table.append(app.anchor(
                                 'search', 'Down',
-                                [('ldapurl', refUrl.unparse())],
+                                [('ldapurl', ref_url.unparse())],
                                 title=u'Descend into tree following search continuation',
                             ))
 
-                elif isinstance(r, SearchResultEntry):
+                elif isinstance(res, SearchResultEntry):
 
                     # Display a search result with entry's data
-                    entry = ldap0.schema.models.Entry(app.schema, r.dn_s, r.entry_as)
+                    res_dn_s = res.dn_s
+                    entry = ldap0.schema.models.Entry(app.schema, res_dn_s, res.entry_as)
 
                     if search_output == 'raw':
 
                         # Output DN
-                        result_dd_str = utf2display(r.dn_s)
+                        result_dd_str = s2d(res_dn_s)
 
                     else:
 
@@ -918,26 +921,26 @@ def w2l_search(app):
                                 AttributeType,
                                 [],
                             )
-                            for oc in tdtemplate_oc:
-                                template_attrs.update(search_tdtemplate_attrs_lower[oc])
+                            for ocl in tdtemplate_oc:
+                                template_attrs.update(search_tdtemplate_attrs_lower[ocl])
                             tableentry_attrs = template_attrs.intersection(entry.keys())
 
                         if tableentry_attrs:
                             # Output entry with the help of pre-defined templates
-                            tableentry = web2ldap.app.read.DisplayEntry(
-                                app, r.dn_s, app.schema, entry, 'searchSep', False
+                            tableentry = DisplayEntry(
+                                app, res_dn_s, app.schema, entry, 'search_sep', False
                             )
                             tdlist = []
-                            for oc in tdtemplate_oc:
-                                tdlist.append(search_tdtemplate[oc] % tableentry)
+                            for ocl in tdtemplate_oc:
+                                tdlist.append(search_tdtemplate[ocl] % tableentry)
                             result_dd_str = '<br>\n'.join(tdlist)
 
                         elif 'displayName' in entry:
-                            result_dd_str = utf2display(app.ls.uc_decode(entry['displayName'][0])[0])
+                            result_dd_str = s2d(app.ls.uc_decode(entry['displayName'][0])[0])
 
                         else:
                             # Output DN
-                            result_dd_str = utf2display(r.dn_s)
+                            result_dd_str = s2d(res_dn_s)
 
                     # Build the list for link table
                     command_table = []
@@ -946,65 +949,58 @@ def w2l_search(app):
                     command_table.append(
                         app.anchor(
                             'read', 'Read',
-                            [('dn', r.dn_s)],
+                            [('dn', res_dn_s)],
                         )
                     )
 
-                    # Try to determine from entry's attributes if there are subordinates
-                    hasSubordinates = entry.get('hasSubordinates', [b'TRUE'])[0].upper() == b'TRUE'
-                    try:
-                        subordinateCountFlag = int(
-                            entry.get(
-                                'subordinateCount',
-                                entry.get(
-                                    'numAllSubordinates',
-                                    entry.get('msDS-Approx-Immed-Subordinates', [b'1'])))[0]
-                        )
-                    except ValueError:
-                        subordinateCountFlag = 1
-
                     # If subordinates or unsure a [Down] link is added
-                    if hasSubordinates and subordinateCountFlag > 0:
+                    if has_subordinates(entry, default=True):
 
-                        down_title_list = [u'List direct subordinates of %s' % (r.dn_s)]
+                        down_title_list = [u'List direct subordinates of %s' % (res_dn_s)]
 
                         # Determine number of direct subordinates
-                        numSubOrdinates = entry.get(
-                            'numSubOrdinates',
-                            entry.get(
-                                'subordinateCount',
+                        try:
+                            num_subordinates = int(
                                 entry.get(
-                                    'countImmSubordinates',
+                                    'numSubOrdinates',
                                     entry.get(
-                                        'msDS-Approx-Immed-Subordinates',
-                                        [None]))))[0]
-                        if numSubOrdinates is not None:
-                            numSubOrdinates = int(numSubOrdinates)
-                            down_title_list.append('direct: %d' % (numSubOrdinates))
+                                        'subordinateCount',
+                                        entry.get(
+                                            'countImmSubordinates',
+                                            entry['msDS-Approx-Immed-Subordinates'])))[0]
+                            )
+                        except (KeyError, ValueError):
+                            pass
+                        else:
+                            down_title_list.append('direct: %d' % (num_subordinates))
                         # Determine total number of subordinates
-                        numAllSubOrdinates = entry.get(
-                            'numAllSubOrdinates',
-                            entry.get('countTotSubordinates', [None])
-                        )[0]
-                        if numAllSubOrdinates is not None:
-                            numAllSubOrdinates = int(numAllSubOrdinates)
-                            down_title_list.append(u'total: %d' % (numAllSubOrdinates))
+                        try:
+                            num_all_subordinates = int(
+                                entry.get(
+                                    'numAllSubOrdinates',
+                                    entry['countTotSubordinates']
+                                )[0]
+                            )
+                        except (KeyError, ValueError):
+                            pass
+                        else:
+                            down_title_list.append(u'total: %d' % (num_all_subordinates))
 
                         command_table.append(app.anchor(
                             'search', 'Down',
                             (
-                                ('dn', r.dn_s),
-                                ('scope', web2ldap.app.searchform.SEARCH_SCOPE_STR_ONELEVEL),
+                                ('dn', res_dn_s),
+                                ('scope', SEARCH_SCOPE_STR_ONELEVEL),
                                 ('searchform_mode', u'adv'),
                                 ('search_attr', u'objectClass'),
-                                ('search_option', web2ldap.app.searchform.SEARCH_OPT_ATTR_EXISTS),
+                                ('search_option', SEARCH_OPT_ATTR_EXISTS),
                                 ('search_string', ''),
                             ),
                             title=u'\r\n'.join(down_title_list),
                         ))
 
                 else:
-                    raise ValueError('LDAP result of invalid type: %r' % (r,))
+                    raise ValueError('LDAP result of invalid type: %r' % (res,))
 
                 # write the search result table row
                 app.outf.write(
@@ -1026,16 +1022,16 @@ def w2l_search(app):
                 """ % (
                     '\n'.join((
                         app.begin_form('search', 'GET', target='web2ldapexport'),
-                        app.form.hiddenFieldHTML('dn', app.dn, u''),
-                        app.form.hiddenFieldHTML('search_root', search_root, u''),
-                        app.form.hiddenFieldHTML('scope', str(scope), u''),
-                        app.form.hiddenFieldHTML('filterstr', filterstr, u''),
-                        app.form.hiddenFieldHTML('search_lastmod', str(search_lastmod), u''),
-                        app.form.hiddenFieldHTML('search_resnumber', u'0', u''),
-                        app.form.hiddenFieldHTML('search_attrs', u','.join(search_attrs), u''),
+                        app.form.hidden_field_html('dn', app.dn, u''),
+                        app.form.hidden_field_html('search_root', search_root, u''),
+                        app.form.hidden_field_html('scope', str(scope), u''),
+                        app.form.hidden_field_html('filterstr', filterstr, u''),
+                        app.form.hidden_field_html('search_lastmod', str(search_lastmod), u''),
+                        app.form.hidden_field_html('search_resnumber', u'0', u''),
+                        app.form.hidden_field_html('search_attrs', u','.join(search_attrs), u''),
                     )),
                     export_field.input_html(),
-                    web2ldap.app.form.InclOpAttrsCheckbox().input_html(),
+                    InclOpAttrsCheckbox().input_html(),
                 )
             )
 
@@ -1049,11 +1045,11 @@ def w2l_search(app):
                 </p>
                 """ % (
                     search_param_html,
-                    utf2display(ldap_search_command),
+                    s2d(ldap_search_command),
                 )
             )
 
-            web2ldap.app.gui.footer(app)
+            footer(app)
 
 
     else:
