@@ -16,12 +16,15 @@ import ldap0
 
 import web2ldapcnf
 
-import web2ldap.web.forms
-import web2ldap.app.core
-import web2ldap.app.gui
-import web2ldap.app.cnf
+from ..web.forms import Select as SelectField
 from ..log import logger
 
+from . import ErrorExit
+from .gui import attrtype_select_field, search_root_field
+from .gui import footer, main_menu, top_section
+from .tmpl import get_variant_filename
+
+
 SEARCHFORM_MODE_TEXT = {
     'adv': 'Advanced',
     'base': 'Basic',
@@ -44,7 +47,19 @@ SEARCH_OPT_DN_SUBORDINATE = u'({at}:dnSubordinateMatch:={av})'
 SEARCH_OPT_DN_SUBTREE = u'({at}:dnSubtreeMatch:={av})'
 SEARCH_OPT_DN_ONE_LEVEL = u'({at}:dnOneLevelMatch:={av})'
 
-search_options = (
+SEARCH_SCOPE_STR_BASE = u'0'
+SEARCH_SCOPE_STR_ONELEVEL = u'1'
+SEARCH_SCOPE_STR_SUBTREE = u'2'
+SEARCH_SCOPE_STR_SUBORDINATES = u'3'
+
+SEARCH_SCOPE_OPTIONS = [
+    (str(ldap0.SCOPE_BASE), 'Base'),
+    (str(ldap0.SCOPE_ONELEVEL), 'One level'),
+    (str(ldap0.SCOPE_SUBTREE), 'Sub tree'),
+    (str(ldap0.SCOPE_SUBORDINATE), 'Subordinate'),
+]
+
+SEARCH_OPTIONS = (
     (SEARCH_OPT_IS_EQUAL, u'attribute value is'),
     (SEARCH_OPT_CONTAINS, u'attribute value contains'),
     (SEARCH_OPT_DOESNT_CONTAIN, u'attribute value does not contain'),
@@ -62,18 +77,6 @@ search_options = (
     (SEARCH_OPT_DN_ONE_LEVEL, u'DN is direct child of'),
 )
 
-SEARCH_SCOPE_STR_BASE = u'0'
-SEARCH_SCOPE_STR_ONELEVEL = u'1'
-SEARCH_SCOPE_STR_SUBTREE = u'2'
-SEARCH_SCOPE_STR_SUBORDINATES = u'3'
-
-SEARCH_SCOPE_OPTIONS = [
-    (SEARCH_SCOPE_STR_BASE, u'Base'),
-    (SEARCH_SCOPE_STR_ONELEVEL, u'One level'),
-    (SEARCH_SCOPE_STR_SUBTREE, u'Sub tree'),
-    (SEARCH_SCOPE_STR_SUBORDINATES, u'Subordinate'),
-]
-
 FILTERSTR_FIELDSET_TMPL = """
 <fieldset>
   <legend>LDAP filter string</legend>
@@ -82,7 +85,7 @@ FILTERSTR_FIELDSET_TMPL = """
 """
 
 
-def SearchForm_exp(app, filterstr=''):
+def search_form_exp(app, filterstr=''):
     """
     Output expert search form
     """
@@ -90,25 +93,28 @@ def SearchForm_exp(app, filterstr=''):
     result = FILTERSTR_FIELDSET_TMPL % (
         app.form.field['filterstr'].maxLen,
         app.form.field['filterstr'].size,
-        app.form.utf2display(filterstr),
+        app.form.s2d(filterstr),
     )
-    return result # SearchForm_exp()
+    return result
 
 
-def SearchForm_base(app, searchform_template_name):
+def search_form_base(app, searchform_template_name):
     """
     Output basic search form based on a HTML template configured
     with host-specific configuration parameter searchform_template
     """
     searchform_template_cfg = app.cfg_param('searchform_template', '')
     searchform_template = searchform_template_cfg.get(searchform_template_name, None)
-    searchform_template_filename = web2ldap.app.gui.get_variant_filename(searchform_template, app.form.accept_language)
+    searchform_template_filename = get_variant_filename(
+        searchform_template,
+        app.form.accept_language,
+    )
     with open(searchform_template_filename, 'rb') as fileobj:
         template_str = fileobj.read().decode('utf-8')
-    return template_str # SearchForm_base()
+    return template_str
 
 
-def SearchForm_adv(app):
+def search_form_adv(app):
     """advanced search form with select lists"""
 
     search_submit = app.form.getInputValue('search_submit', [u''])[0]
@@ -135,11 +141,11 @@ def SearchForm_adv(app):
             search_string_list.insert(insert_row_num+1, u'')
 
     if not len(search_option_list) == len(search_attr_list) == len(search_string_list):
-        raise web2ldap.app.core.ErrorExit(u'Invalid search form data.')
+        raise ErrorExit(u'Invalid search form data.')
 
     search_mode = app.form.getInputValue('search_mode', [u'(&%s)'])[0]
 
-    search_mode_select = web2ldap.web.forms.Select(
+    search_mode_select = SelectField(
         'search_mode', u'Search mode', 1,
         options=[
             (u'(&%s)', u'all'),
@@ -149,7 +155,7 @@ def SearchForm_adv(app):
     )
     search_mode_select.charset = app.form.accept_charset
 
-    search_attr_select = web2ldap.app.gui.attrtype_select_field(
+    search_attr_select = attrtype_select_field(
         app,
         'search_attr',
         u'Search attribute type',
@@ -159,7 +165,7 @@ def SearchForm_adv(app):
 
     mr_list = [''] + sorted(app.schema.name2oid[ldap0.schema.models.MatchingRule].keys())
     # Create a select field instance for matching rule name
-    search_mr_select = web2ldap.web.forms.Select(
+    search_mr_select = SelectField(
         'search_mr', u'Matching rule used',
         web2ldapcnf.max_searchparams,
         options=mr_list,
@@ -194,12 +200,12 @@ def SearchForm_adv(app):
         search_mode_select.input_html(),
         '\n'.join(search_fields_html_list),
     )
-    return result # SearchForm_adv()
+    return result
 
 
 def w2l_searchform(
         app,
-        Msg='',
+        msg='',
         filterstr='',
         scope=ldap0.SCOPE_SUBTREE,
         search_root=None,
@@ -207,8 +213,8 @@ def w2l_searchform(
     ):
     """Output a search form"""
 
-    if Msg:
-        msg_html = '<p class="ErrorMessage">%s</p>' % (Msg)
+    if msg:
+        msg_html = '<p class="ErrorMessage">%s</p>' % (msg)
     else:
         msg_html = ''
 
@@ -219,14 +225,14 @@ def w2l_searchform(
         'search_root',
         [search_root or str(app.naming_context)],
     )[0]
-    search_root_field = web2ldap.app.gui.search_root_field(
+    srf = search_root_field(
         app,
         name='search_root',
         default=search_root,
         search_root_searchurl=app.cfg_param('searchform_search_root_url', None),
     )
 
-    ContextMenuList = [
+    ctx_menu_items = [
         app.anchor(
             'searchform', SEARCHFORM_MODE_TEXT[mode],
             [
@@ -245,8 +251,8 @@ def w2l_searchform(
     if isinstance(searchform_template_cfg, dict):
         for sftn in searchform_template_cfg.keys():
             if sftn != '_':
-                ContextMenuList.append(app.anchor(
-                    'searchform', app.form.utf2display(sftn),
+                ctx_menu_items.append(app.anchor(
+                    'searchform', app.form.s2d(sftn),
                     [
                         ('dn', app.dn),
                         ('searchform_mode', 'base'),
@@ -260,34 +266,34 @@ def w2l_searchform(
     if searchform_mode == u'base':
         # base search form with fixed input fields
         try:
-            inner_searchform_html = SearchForm_base(app, searchform_template_name)
+            inner_searchform_html = search_form_base(app, searchform_template_name)
         except IOError as err:
             logger.warning('Error loading search form template: %s', err)
             msg_html = '\n'.join((
                 msg_html,
                 '<p class="ErrorMessage">I/O error while loading search form template!</p>'
             ))
-            inner_searchform_html = SearchForm_adv(app)
+            inner_searchform_html = search_form_adv(app)
             searchform_mode = u'adv'
     elif searchform_mode == u'exp':
         # expert search form with single filter input field
-        inner_searchform_html = SearchForm_exp(app, filterstr)
+        inner_searchform_html = search_form_exp(app, filterstr)
     elif searchform_mode == u'adv':
         # base search form with fixed input fields
-        inner_searchform_html = SearchForm_adv(app)
+        inner_searchform_html = search_form_adv(app)
 
-    searchoptions_template_filename = web2ldap.app.gui.get_variant_filename(
+    searchoptions_template_filename = get_variant_filename(
         app.cfg_param('searchoptions_template', None),
         app.form.accept_language
     )
     with open(searchoptions_template_filename, 'r') as template_file:
         searchoptions_template_str = template_file.read()
 
-    web2ldap.app.gui.top_section(
+    top_section(
         app,
         '%s Search Form' % SEARCHFORM_MODE_TEXT[searchform_mode],
-        web2ldap.app.gui.main_menu(app),
-        context_menu_list=ContextMenuList,
+        main_menu(app),
+        context_menu_list=ctx_menu_items,
         main_div_id='Input'
     )
 
@@ -308,14 +314,14 @@ def w2l_searchform(
         </form>
         """.format(
             form_search_html=app.begin_form('search', 'GET'),
-            searchform_mode=app.form.utf2display(searchform_mode),
-            searchform_template=app.form.utf2display(searchform_template_name),
+            searchform_mode=app.form.s2d(searchform_mode),
+            searchform_template=app.form.s2d(searchform_template_name),
             search_output=app.form.getInputValue('search_output', [u'table'])[0],
             msg_html=msg_html,
             inner_searchform_html=inner_searchform_html,
-            form_dn_html=app.form.hiddenFieldHTML('dn', app.dn, u''),
+            form_dn_html=app.form.hidden_field_html('dn', app.dn, u''),
             searchoptions_template_str=searchoptions_template_str.format(
-                field_search_root=search_root_field.input_html(),
+                field_search_root=srf.input_html(),
                 field_search_scope=app.form.field['scope'].input_html(
                     default=app.form.getInputValue('scope', [str(scope)])[0]
                 ),
@@ -328,9 +334,9 @@ def w2l_searchform(
                 field_search_lastmod=app.form.field['search_lastmod'].input_html(
                     default=app.form.getInputValue('search_lastmod', [str(-1)])[0]
                 ),
-                value_search_attrs=app.form.utf2display(app.form.getInputValue('search_attrs', [u''])[0]),
+                value_search_attrs=app.form.s2d(app.form.getInputValue('search_attrs', [u''])[0]),
             ),
         )
     )
 
-    web2ldap.app.gui.footer(app)
+    footer(app)
