@@ -12,57 +12,54 @@ Apache License Version 2.0 (Apache-2.0)
 https://www.apache.org/licenses/LICENSE-2.0
 """
 
-import time
 import collections
 import logging
 import threading
 
-import web2ldap.web.session
-from web2ldap.web.helper import get_remote_ip
-
-from web2ldap.ldapsession import LDAPSession
-from web2ldap.log import logger, LogHelper
 import web2ldapcnf
 
+from ..web import session
+from ..web.session import WebSession
+from ..web.helper import get_remote_ip
 
-class InvalidSessionInstance(web2ldap.web.session.SessionException):
+from ..ldapsession import LDAPSession
+from ..log import logger, LogHelper
+
+
+SESSION_EXPIRY_INTERVAL: int = 61
+
+
+class InvalidSessionInstance(session.SessionException):
     """
     Exception raised in case of invalid session
     """
 
 
-class WrongSessionCookie(web2ldap.web.session.SessionException):
+class WrongSessionCookie(session.SessionException):
     """
     Exception raised in case of invalid cookie
     """
 
 
-class Session(web2ldap.web.session.WebSession, LogHelper):
+class Session(WebSession, LogHelper):
     """
     session store
     """
 
     def __init__(
             self,
-            dictobj=None,
-            session_ttl=0,
-            crossCheckVars=None,
-            maxSessionCount=None,
-            max_session_count_per_ip=None,
-        ):
-        web2ldap.web.session.WebSession.__init__(
-            self,
-            dictobj,
             session_ttl,
-            crossCheckVars,
-            maxSessionCount,
-        )
+            session_check_vars,
+            max_sessions,
+            max_session_count_per_ip,
+        ):
+        WebSession.__init__(self, session_ttl, session_check_vars, max_sessions)
         self.max_concurrent_sessions = 0
         self.remote_ip_sessions = collections.defaultdict(set)
         self.session_ip_addr = {}
-        self.max_session_count_per_ip = max_session_count_per_ip or self.maxSessionCount/4
+        self.max_session_count_per_ip = max_session_count_per_ip or int(self.max_sessions/4)
         self.remote_ip_counter = collections.Counter()
-        self.expiry_thread = ExpiryThread(self, interval=5)
+        self.expiry_thread = ExpiryThread(self, interval=SESSION_EXPIRY_INTERVAL)
         self.expiry_thread.start()
         logger.debug(
             'Started clean-up thread %s[%x]',
@@ -70,7 +67,7 @@ class Session(web2ldap.web.session.WebSession, LogHelper):
             id(self.expiry_thread),
         )
 
-    def new(self, env=None):
+    def new(self, env):
         self.expire()
         self.log(logging.DEBUG, 'new(): creating a new session')
         remote_ip = get_remote_ip(env)
@@ -83,8 +80,8 @@ class Session(web2ldap.web.session.WebSession, LogHelper):
                 remote_ip,
                 self.max_session_count_per_ip,
             )
-            raise web2ldap.web.session.MaxSessionPerIPExceeded(remote_ip, self.max_session_count_per_ip)
-        session_id = web2ldap.web.session.WebSession.new(self, env)
+            raise session.MaxSessionPerIPExceeded(remote_ip, self.max_session_count_per_ip)
+        session_id = WebSession.new(self, env)
         current_concurrent_sessions = len(self.sessiondict) // 2
         if current_concurrent_sessions > self.max_concurrent_sessions:
             self.max_concurrent_sessions = current_concurrent_sessions
@@ -109,10 +106,10 @@ class Session(web2ldap.web.session.WebSession, LogHelper):
         # end of _remove_ip_assoc()
 
     def rename(self, old_sid, env):
-        session_data = self.retrieveSession(old_sid, env)
+        session_data = self.retrieve(old_sid, env)
         new_sid = self.new(env)
         self.save(new_sid, session_data)
-        web2ldap.web.session.WebSession.delete(self, old_sid)
+        WebSession.delete(self, old_sid)
         # Set new remote IP associations
         remote_ip = get_remote_ip(env)
         self.session_ip_addr[new_sid] = remote_ip
@@ -130,7 +127,7 @@ class Session(web2ldap.web.session.WebSession, LogHelper):
         else:
             if isinstance(ls_local, LDAPSession):
                 ls_local.unbind()
-        web2ldap.web.session.WebSession.delete(self, sid)
+        WebSession.delete(self, sid)
         self.log(logging.INFO, 'delete(%r): removed session', sid)
         # Remove old remote IP associations
         try:
@@ -142,42 +139,55 @@ class Session(web2ldap.web.session.WebSession, LogHelper):
         # end of delete()
 
     def expire(self):
-        expired = web2ldap.web.session.WebSession.expire(self)
+        self.log(logging.DEBUG, 'Entering .expire()')
+        expired = WebSession.expire(self)
         if expired:
             self.log(logging.INFO, 'expire() removed %d expired sessions', expired)
         return expired
         # end of expire()
 
 
-class ExpiryThread(web2ldap.web.session.ExpiryThread, LogHelper):
+class ExpiryThread(threading.Thread, LogHelper):
     """
     Thread class for clean-up thread
-
-    Mainly it overrides web2ldap.web.session.ExpiryThread.run()
-    to call ldapSession.unbind().
     """
+    __slots__ = (
+        '_interval',
+        '_removed',
+        'run_counter',
+        '_session_obj',
+        '_stop_event',
+    )
 
-
-    def __init__(self, *args, **kwargs):
-        web2ldap.web.session.ExpiryThread.__init__(self, *args, **kwargs)
+    def __init__(self, session_obj, interval=60):
+        self._session_obj = session_obj
+        self._interval = interval
+        self._stop_event = threading.Event()
+        self._removed = 0
         self.run_counter = 0
-        self.enabled = True
+        threading.Thread.__init__(self, name=self.__class__.__module__+self.__class__.__name__)
+
+    def stop(self):
+        self._stop_event.set()
+
+    def __repr__(self):
+        return '%s: %d sessions removed' % (
+            self.getName(),
+            self._removed,
+        )
 
     def run(self):
         """Thread function for cleaning up session database"""
         self.log(
             logging.DEBUG,
             'Entering .run() cleaning %s[%x]',
-            self._sessionInstance.__class__.__name__,
-            id(self._sessionInstance),
+            self._session_obj.__class__.__name__,
+            id(self._session_obj),
             )
-        while self.enabled and not self._stop_event.isSet():
+        while not self._stop_event.is_set():
             self.run_counter += 1
             try:
-                self._sessionInstance.expire()
-            except (KeyboardInterrupt, SystemExit) as exit_exc:
-                self.log(logging.DEBUG, 'Caught exit exception in run(): %s', exit_exc)
-                self.enabled = False
+                self._session_obj.expire()
             except Exception:
                 # Catch all exceptions to avoid thread being killed.
                 self.log(logging.ERROR, 'Unhandled exception in run()', exc_info=True)
@@ -202,10 +212,10 @@ def session_store():
     with _SESSION_STORE_LOCK:
         if _SESSION_STORE is None:
             _SESSION_STORE = Session(
-                session_ttl=web2ldapcnf.session_remove,
-                crossCheckVars=web2ldapcnf.session_checkvars,
-                maxSessionCount=web2ldapcnf.session_limit,
-                max_session_count_per_ip=web2ldapcnf.session_per_ip_limit,
+                web2ldapcnf.session_remove,
+                web2ldapcnf.session_checkvars,
+                web2ldapcnf.session_limit,
+                web2ldapcnf.session_per_ip_limit,
             )
             logger.debug(
                 'Initialized web2ldap session store %s[%x]',
