@@ -22,7 +22,7 @@ from pprint import pformat
 
 import ldap0
 
-from web2ldap.log import logger
+from .log import logger
 
 
 def check_inst():
@@ -79,7 +79,7 @@ def check_inst():
     # Check whether built with SSL/TLS (OpenSSL)
     logger.debug('*** Support for SSL/TLS ***')
     logger.debug('ldap0.TLS_AVAIL = %r', ldap0.TLS_AVAIL)
-    logger.debug('ldap0.OPT_X_TLS_PACKAGE = %r', ldap0.get_option(ldap0.OPT_X_TLS_PACKAGE))
+    logger.debug('ldap0.LIBLDAP_TLS_PACKAGE = %r', ldap0.LIBLDAP_TLS_PACKAGE)
     # Check whether built with SASL (Cyrus-SASL)
     logger.debug('*** SASL support ***')
     logger.debug('ldap0.SASL_AVAIL = %r', ldap0.SASL_AVAIL)
