@@ -38,8 +38,8 @@ from ldap0.controls.readentry import PreReadControl, PostReadControl
 from ldap0.controls.ppolicy import PasswordPolicyControl
 from ldap0.controls.sessiontrack import SessionTrackingControl, SESSION_TRACKING_FORMAT_OID_USERNAME
 
-from web2ldap.log import logger
-from web2ldap.ldaputil.extldapurl import ExtendedLDAPUrl
+from .log import logger
+from .ldaputil.extldapurl import ExtendedLDAPUrl
 
 START_TLS_NO = 0
 START_TLS_TRY = 1
@@ -239,7 +239,7 @@ class MyLDAPObject(ReconnectLDAPObject):
             retry_delay=LDAP0_RETRY_DELAY,
             cache_ttl=LDAP0_CACHE_TTL,
         ):
-        self._req_ctrls = {
+        self.req_ctrls = {
             # all LDAP operations
             '**all**': [],
             # all bind operations
@@ -260,7 +260,6 @@ class MyLDAPObject(ReconnectLDAPObject):
             'sasl_interactive_bind_s': [],
             'simple_bind': [],
         }
-        self.flush_cache()
         ReconnectLDAPObject.__init__(
             self,
             uri,
@@ -273,14 +272,14 @@ class MyLDAPObject(ReconnectLDAPObject):
 
     def get_ctrls(self, method):
         all_s_ctrls = {}
-        for ctrl in self._req_ctrls[method]:
+        for ctrl in self.req_ctrls[method]:
             all_s_ctrls[ctrl.controlType] = ctrl
         return all_s_ctrls
 
-    def add_server_control(self, method, lc):
+    def add_server_control(self, method, ctrl):
         _s_ctrls = self.get_ctrls(method)
-        _s_ctrls[lc.controlType] = lc
-        self._req_ctrls[method] = list(_s_ctrls.values())
+        _s_ctrls[ctrl.controlType] = ctrl
+        self.req_ctrls[method] = list(_s_ctrls.values())
 
     def del_server_control(self, method, control_type):
         _s_ctrls = self.get_ctrls(method)
@@ -288,7 +287,7 @@ class MyLDAPObject(ReconnectLDAPObject):
             del _s_ctrls[control_type]
         except KeyError:
             pass
-        self._req_ctrls[method] = list(_s_ctrls.values())
+        self.req_ctrls[method] = list(_s_ctrls.values())
 
     def abandon(self, msgid, req_ctrls=None):
         return ReconnectLDAPObject.abandon(
@@ -296,8 +295,8 @@ class MyLDAPObject(ReconnectLDAPObject):
             msgid,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['abandon']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['abandon']
             ),
         )
 
@@ -309,9 +308,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             cred,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**bind**']
-                + self._req_ctrls['simple_bind']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**bind**']
+                + self.req_ctrls['simple_bind']
             ),
         )
 
@@ -329,9 +328,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             auth,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**bind**']
-                + self._req_ctrls['sasl_interactive_bind_s']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**bind**']
+                + self.req_ctrls['sasl_interactive_bind_s']
             ),
             sasl_flags
         )
@@ -343,9 +342,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             modlist,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**write**']
-                + self._req_ctrls['add']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**write**']
+                + self.req_ctrls['add']
             ),
         )
 
@@ -357,9 +356,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             value,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**read**']
-                + self._req_ctrls['compare']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**read**']
+                + self.req_ctrls['compare']
             ),
         )
 
@@ -369,9 +368,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             dn,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**write**']
-                + self._req_ctrls['delete']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**write**']
+                + self.req_ctrls['delete']
             ),
         )
 
@@ -382,9 +381,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             modlist,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**write**']
-                + self._req_ctrls['modify']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**write**']
+                + self.req_ctrls['modify']
             ),
         )
 
@@ -396,9 +395,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             newpw,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**write**']
-                + self._req_ctrls['passwd']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**write**']
+                + self.req_ctrls['passwd']
             ),
         )
 
@@ -411,9 +410,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             delold,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**write**']
-                + self._req_ctrls['rename']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**write**']
+                + self.req_ctrls['rename']
             ),
         )
 
@@ -439,9 +438,9 @@ class MyLDAPObject(ReconnectLDAPObject):
             attrsonly,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['**read**']
-                + self._req_ctrls['search']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['**read**']
+                + self.req_ctrls['search']
             ),
             timeout,
             sizelimit,
@@ -452,8 +451,8 @@ class MyLDAPObject(ReconnectLDAPObject):
             self,
             (
                 (req_ctrls or [])
-                + self._req_ctrls['**all**']
-                + self._req_ctrls['unbind']
+                + self.req_ctrls['**all**']
+                + self.req_ctrls['unbind']
             ),
         )
 
@@ -520,36 +519,33 @@ class LDAPSession:
         '_audit_context',
         '_cache_ttl',
         'charset',
-        'connStartTime',
+        'conn_start',
         'cookie',
         'l',
-        'namingContexts',
-        'namingContexts',
-        'onBehalf',
-        'rootDSE',
+        'on_behalf',
+        'root_dse',
         'sasl_auth',
         'sasl_mech',
         '_schema_cache',
         '_schema_dn_cache',
-        'secureConn',
-        'sessionStartTime',
-        'startTLSOption',
+        'secure_conn',
+        'supports_allop_attr',
+        '_traceLevel',
+        'uc_decode',
+        'uc_encode',
+        'uri',
+        'user_entry',
+        'use_start_tls',
+        'who',
+        # instance attributes with names matching the rootDSE attributes
+        'namingContexts',
         'supportedControl',
         'supportedExtension',
         'supportedFeatures',
         'supportedLDAPVersion',
         'supportedSASLMechanisms',
-        'supportsAllOpAttr',
-        'supportsAllOpAttr',
-        'supportsAllOpAttr',
-        '_traceLevel',
-        'uc_decode',
-        'uc_encode',
-        'uri',
-        'userEntry',
         'vendorName',
         'vendorVersion',
-        'who',
     )
     subordinate_attrs = (
         'hasSubordinates',
@@ -559,7 +555,7 @@ class LDAPSession:
         'msDS-Approx-Immed-Subordinates',
     )
 
-    def __init__(self, onBehalf, traceLevel, cache_ttl):
+    def __init__(self, on_behalf, traceLevel, cache_ttl):
         """Initialize a LDAPSession object"""
         self.l = None
         # Set to not connected
@@ -573,21 +569,18 @@ class LDAPSession:
         # initialize class attributes derived from rootDSE attributes later
         self._reset_rootdse_attrs()
         # security attributes of the connection
-        self.secureConn = 0
+        self.secure_conn = 0
         self.sasl_mech = None
         self.sasl_auth = None
         self.who = None
-        self.userEntry = {}
-        self.startTLSOption = 0
+        self.user_entry = {}
+        self.use_start_tls = 0
         self._schema_dn_cache = {}
         self._schema_cache = {}
-        # Supports feature described in draft-zeilenga-ldap-opattrs
-        self.supportsAllOpAttr = 0
         # IP address, host name or other free form information
         # of proxy client
-        self.onBehalf = onBehalf
-        self.sessionStartTime = time.time()
-        self.connStartTime = None
+        self.on_behalf = on_behalf
+        self.conn_start = None
         self._cache_ttl = cache_ttl
         # end of __init__()
 
@@ -617,13 +610,13 @@ class LDAPSession:
                     raise
         # end of _set_tls_options()
 
-    def _start_tls(self, startTLSOption):
+    def _start_tls(self, use_start_tls):
         """
         StartTLS if possible and requested
         """
-        self.secureConn = 0
-        self.startTLSOption = 0
-        if not startTLSOption:
+        self.secure_conn = 0
+        self.use_start_tls = 0
+        if not use_start_tls:
             return
         try:
             self.l.start_tls_s()
@@ -634,12 +627,12 @@ class LDAPSession:
                 ldap0.INSUFFICIENT_ACCESS,
                 ldap0.SERVER_DOWN,
             ) as ldap_err:
-            if startTLSOption > 1:
+            if use_start_tls > 1:
                 self.unbind()
                 raise ldap_err
         else:
-            self.startTLSOption = 2
-            self.secureConn = 1
+            self.use_start_tls = 2
+            self.secure_conn = 1
         # end of _start_tls()
 
     def _initialize(self, uri_list, timeout, tls_options=None):
@@ -699,7 +692,7 @@ class LDAPSession:
         self._initialize(uri_list, timeout, tls_options)
         if enableSessionTracking:
             session_tracking_ctrl = SessionTrackingControl(
-                self.onBehalf,
+                self.on_behalf,
                 env.get(
                     'HTTP_HOST',
                     ':'.join((
@@ -715,8 +708,8 @@ class LDAPSession:
             # Start TLS extended operation
             self._start_tls(startTLS)
         elif self.uri.lower().startswith('ldaps:') or self.uri.lower().startswith('ldapi:'):
-            self.secureConn = 1
-        self.connStartTime = time.time()
+            self.secure_conn = 1
+        self.conn_start = time.time()
         self.init_rootdse()
         # end of open()
 
@@ -736,64 +729,19 @@ class LDAPSession:
 
     def _reset_rootdse_attrs(self):
         """Forget all old RootDSE values"""
-        self.supportsAllOpAttr = False
         self.namingContexts = set()
-        self.rootDSE = ldap0.cidict.CIDict()
+        self.root_dse = ldap0.cidict.CIDict()
         # some rootDSE attributes made available as class attributes
         self.supportedLDAPVersion = frozenset([])
         self.supportedControl = frozenset([])
         self.supportedExtension = frozenset([])
         self.supportedFeatures = frozenset([])
         self.supportedSASLMechanisms = frozenset([])
-        self.supportsAllOpAttr = False
+        self.supports_allop_attr = False
 
     @property
     def is_openldap(self):
-        return b'OpenLDAProotDSE' in self.rootDSE.get('objectClass', [])
-
-    def _update_rootdse_attrs(self):
-        """
-        Derive some class attributes from rootDSE attributes
-        """
-        self.namingContexts = set()
-        for rootdse_naming_attrtype in (
-                'namingContexts',
-                'configContext',
-                'monitorContext',
-                'ds-private-naming-contexts',
-            ):
-            self.namingContexts.update([
-                DNObj.from_str('' if val == b'\x00' else val.decode(self.charset))
-                for val in self.rootDSE.get(rootdse_naming_attrtype, [])
-            ])
-        for attr_type in (
-                'supportedLDAPVersion',
-                'supportedControl',
-                'supportedExtension',
-                'supportedFeatures',
-                'supportedSASLMechanisms',
-            ):
-            setattr(
-                self,
-                attr_type,
-                frozenset(
-                    decode_list(
-                        self.rootDSE.get(attr_type, []),
-                        encoding='ascii'
-                    )
-                )
-            )
-        for attr_type in ('vendorName', 'vendorVersion'):
-            if attr_type in self.rootDSE:
-                setattr(self, attr_type, self.rootDSE[attr_type][0].decode(self.charset))
-            else:
-                setattr(self, attr_type, None)
-        # determine whether server returns all operational attributes (RFC 3673)
-        self.supportsAllOpAttr = (
-            '1.3.6.1.4.1.4203.1.5.1' in self.supportedFeatures
-            or self.is_openldap
-        )
-        # end of _update_rootdse_attrs()
+        return b'OpenLDAProotDSE' in self.root_dse.get('objectClass', [])
 
     def init_rootdse(self):
         """Retrieve attributes from Root DSE"""
@@ -816,13 +764,51 @@ class LDAPSession:
                 ldap0.PROTOCOL_ERROR,
                 ldap0.UNAVAILABLE_CRITICAL_EXTENSION,
             ):
-            self.rootDSE = {}
+            self.root_dse = {}
         else:
             if ldap_res is None:
-                self.rootDSE = {}
+                self.root_dse = {}
             else:
-                self.rootDSE = ldap_res.entry_as
-        self._update_rootdse_attrs()
+                self.root_dse = ldap_res.entry_as
+        # Derive some class attributes from rootDSE attributes
+        self.namingContexts = set()
+        for rootdse_naming_attrtype in (
+                'namingContexts',
+                'configContext',
+                'monitorContext',
+                'ds-private-naming-contexts',
+            ):
+            self.namingContexts.update([
+                DNObj.from_str('' if val == b'\x00' else val.decode(self.charset))
+                for val in self.root_dse.get(rootdse_naming_attrtype, [])
+            ])
+        for attr_type in (
+                'supportedLDAPVersion',
+                'supportedControl',
+                'supportedExtension',
+                'supportedFeatures',
+                'supportedSASLMechanisms',
+            ):
+            setattr(
+                self,
+                attr_type,
+                frozenset(
+                    decode_list(
+                        self.root_dse.get(attr_type, []),
+                        encoding='ascii'
+                    )
+                )
+            )
+        for attr_type in ('vendorName', 'vendorVersion'):
+            if attr_type in self.root_dse:
+                setattr(self, attr_type, self.root_dse[attr_type][0].decode(self.charset))
+            else:
+                setattr(self, attr_type, None)
+        # determine whether server returns all operational attributes (RFC 3673)
+        self.supports_allop_attr = (
+            '1.3.6.1.4.1.4203.1.5.1' in self.supportedFeatures
+            or self.is_openldap
+        )
         # end of init_rootdse()
 
     def get_search_root(self, dn, naming_contexts=None):
@@ -1007,7 +993,9 @@ class LDAPSession:
             except (IndexError, ValueError):
                 pass
             else:
-                subschemasubentry.update(decode_entry_dict(supplement_schema, encoding=self.charset) or {})
+                subschemasubentry.update(
+                    decode_entry_dict(supplement_schema, encoding=self.charset) or {}
+                )
         try:
             sub_schema = ldap0.schema.subentry.SubSchema(
                 subschemasubentry,
@@ -1139,7 +1127,7 @@ class LDAPSession:
             binddn_mapping,
             search_root,
         )
-        search_root = search_root or self.rootDSE.get(
+        search_root = search_root or self.root_dse.get(
             'defaultNamingContext',
             [b''],
         )[0].decode(self.charset) or ''
@@ -1324,14 +1312,16 @@ class LDAPSession:
                     cache_ttl=-1.0,
                 )
             except (ldap0.LDAPError, IndexError):
-                self.userEntry = {}
+                self.user_entry = {}
             else:
                 if user_res is None:
-                    self.userEntry = {}
+                    self.user_entry = {}
                 else:
-                    self.userEntry = user_res.entry_as
+                    self.user_entry = user_res.entry_as
+                    # replace DN because Who Am I? ext.op. could have returned case-folded form
+                    self.who = user_res.dn_s
         else:
-            self.userEntry = {}
+            self.user_entry = {}
         # end of bind()
 
     def get_governing_structure_rule(self, dn, schema):
@@ -1385,7 +1375,10 @@ class LDAPSession:
         else:
             # More than one possible DIT structure rule found
             if parent_dn:
-                parent_governing_structure_rule = self.get_governing_structure_rule(parent_dn, schema)
+                parent_governing_structure_rule = self.get_governing_structure_rule(
+                    parent_dn,
+                    schema,
+                )
                 if not parent_governing_structure_rule is None:
                     subord_structural_rules, _ = schema.get_subord_structural_oc_names(
                         parent_governing_structure_rule
@@ -1405,11 +1398,11 @@ class LDAPSession:
             return None
         lu = ExtendedLDAPUrl(ldapUrl=self.uri)
         lu.dn = dn
-        if self.startTLSOption:
-            lu.x_startTLS = str(START_TLS_REQUIRED * (self.startTLSOption > 0))
+        if self.use_start_tls:
+            lu.start_tls = str(START_TLS_REQUIRED * (self.use_start_tls > 0))
         if add_login:
             if self.sasl_auth:
-                lu.saslMech = self.sasl_mech
+                lu.sasl_mech = self.sasl_mech
                 if self.sasl_mech.encode('ascii') in ldap0.sasl.SASL_PASSWORD_MECHS:
                     lu.who = self.sasl_auth.cb_value_dict.get(
                         ldap0.sasl.CB_AUTHNAME,
@@ -1429,7 +1422,7 @@ class LDAPSession:
             connection_str,
             ','.join([
                 '%s:%r' % (a, getattr(self, a))
-                for a in ('uri', 'who', 'dn', 'onBehalf', 'startedTLS')
+                for a in ('uri', 'who', 'dn', 'on_behalf', 'startedTLS')
                 if hasattr(self, a)
             ]),
         )
