@@ -37,29 +37,44 @@ AD_LDAP49_ERROR_CODES = {
 }
 AD_LDAP49_ERROR_PREFIX = b'AcceptSecurityContext error, data '
 
-attr_type_pattern = u'[\\w;.-]+(;[\\w_-]+)*'
-attr_value_pattern = u'(([^,]|\\\\,)+|".*?")'
-rdn_pattern = attr_type_pattern + u'[ ]*=[ ]*' + attr_value_pattern
+ATTR_TYPE_PATTERN = u'[\\w;.-]+(;[\\w_-]+)*'
+ATTR_VALUE_PATTERN = u'(([^,]|\\\\,)+|".*?")'
+RDN_PATTERN = ATTR_TYPE_PATTERN + u'[ ]*=[ ]*' + ATTR_VALUE_PATTERN
 
 
-def ietf_oid_str(oid):
+def has_subordinates(entry, default=True) -> bool:
     """
-    Returns normalized IETF string representation of oid
+    Try to determine from entry's attributes whether there are subordinates.
+
+    :default: will be returned if there is no operational attribute clearly
+    specifying whether there are no subordinate entries.
     """
-    vl = oid.split(' ')
-    res = []
-    for vs in vl:
-        if vs:
-            vs = ''.join([
-                c
-                for c in vs
-                if c >= '0' and c <= '9'
-            ])
-            if not vs:
-                # no digits in component
-                raise ValueError('oid %r cannot be normalized' % (oid))
-            res.append(vs)
-    return '.'.join(res)
+    if 'hasSubordinates' in entry:
+        hs_attr = entry['hasSubordinates'][0].upper()
+        if isinstance(hs_attr, bytes):
+            if hs_attr == b'TRUE':
+                return True
+            if hs_attr == b'FALSE':
+                return False
+        else:
+            if hs_attr == 'TRUE':
+                return True
+            if hs_attr == 'FALSE':
+                return False
+        # when reaching here attribute hasSubordinates contains garbage
+        # => LDAP server vendor sucks, proceed
+    try:
+        res = int(
+            entry.get(
+                'subordinateCount',
+                entry.get(
+                    'numAllSubordinates',
+                    entry['msDS-Approx-Immed-Subordinates']
+                ))[0]
+        ) > 0
+    except (ValueError, KeyError):
+        res = default
+    return res
 
 
 def logdb_filter(logdb_objectclass, dn, entry_uuid=None):
