@@ -18,8 +18,7 @@ import uuid
 from typing import List
 
 from . import escape_html
-from . import helper
-
+from .helper import AcceptCharsetDict, AcceptHeaderDict
 
 class Field:
     """
@@ -82,14 +81,18 @@ class Field:
         # This is set by Form.add() to something meaningful.
         self._charset = 'utf-8'
         self.set_default(default)
-        self.setRegex(pattern)
+        self.set_regex(pattern)
 
     def _accesskey_attr(self):
         if not self.accesskey:
             return ''
         return 'accesskey="%s" ' % (self.accesskey)
 
-    def id_attr(self, id_value):
+    @staticmethod
+    def id_attr(id_value):
+        """
+        return id attribute if id_value is non-empty, else returns empty string
+        """
         if id_value is None:
             return ''
         return 'id="%s" ' % (id_value)
@@ -105,7 +108,8 @@ class Field:
             self.default = [i for i in default if i is not None]
         self.default = default or ''
 
-    def _regex_with_options(self, pattern):
+    @staticmethod
+    def _regex_with_options(pattern):
         """
         The result is a tuple (pattern string, pattern options).
 
@@ -121,7 +125,7 @@ class Field:
             return pattern, 0
         raise TypeError('Expected pattern to be None, str or tuple, got %r' % (pattern,))
 
-    def setRegex(self, pattern: str):
+    def set_regex(self, pattern: str):
         """
         Set the regex pattern for validating this field.
 
@@ -164,7 +168,7 @@ class Field:
         if len(self.value) >= self.maxValues:
             raise TooManyValues(self.name, self.text, len(self.value), self.maxValues)
 
-    def _decodeValue(self, value):
+    def _decode_val(self, value):
         """
         Return str to be stored in self.value
         """
@@ -186,7 +190,7 @@ class Field:
             'Expected value to be str or bytes, was %r' % (value,)
         )
         if isinstance(value, bytes):
-            value = self._decodeValue(value)
+            value = self._decode_val(value)
         # Length valid?
         self._validate_len(value)
         # Format valid?
@@ -204,17 +208,17 @@ class Field:
         """Set the character set used for the field"""
         self._charset = charset
 
-    def _defaultValue(self, default):
+    def _default_val(self, default):
         """returns default value"""
         return default or getattr(self, 'default', '')
 
-    def titleHTML(self, title):
+    def title_attr(self, title):
         """HTML output of default."""
         return escape_html(title or self.text)
 
     def _default_html(self, default):
         """HTML output of default."""
-        return escape_html(self._defaultValue(default))
+        return escape_html(self._default_val(default))
 
 
 class Textarea(Field):
@@ -240,21 +244,21 @@ class Textarea(Field):
         self.cols = cols
         Field.__init__(self, name, text, maxLen, maxValues, None, required, default, accesskey)
 
-    def setRegex(self, pattern: str):
+    def set_regex(self, pattern: str):
         """
-        Like Field.setRegex() but pattern options re.S and re.M are
+        Like Field.set_regex() but pattern options re.S and re.M are
         automatically added.
         """
         patternstring, patternoptions = self._regex_with_options(pattern)
         # This is a Unicode input field
         patternoptions = patternoptions | re.M | re.S
-        Field.setRegex(self, (patternstring, patternoptions))
+        Field.set_regex(self, (patternstring, patternoptions))
 
     def input_html(self, default=None, id_value=None, title=None):
         """Returns string with HTML input field."""
         return '<textarea %stitle="%s" name="%s" %s rows="%d" cols="%d">%s</textarea>' % (
             self.id_attr(id_value),
-            self.titleHTML(title),
+            self.title_attr(title),
             self.name,
             self._accesskey_attr(),
             self.rows,
@@ -296,7 +300,7 @@ class Input(Field):
             pattern_attr = ''
         return '<input %stitle="%s" name="%s" %s maxlength="%d" size="%d"%s%s value="%s">' % (
             self.id_attr(id_value),
-            self.titleHTML(title),
+            self.title_attr(title),
             self.name,
             self._accesskey_attr(),
             self.maxLen,
@@ -317,7 +321,7 @@ class HiddenInput(Input):
 
 class BytesInput(Input):
 
-    def setRegex(self, pattern: str):
+    def set_regex(self, pattern: str):
         """
         Set the bytes regex pattern for validating this field.
         """
@@ -333,7 +337,7 @@ class BytesInput(Input):
                 patternoptions,
             )
 
-    def _decodeValue(self, value):
+    def _decode_val(self, value):
         return value
 
 
@@ -348,7 +352,7 @@ class File(Input):
         """Binary data is assumed to be valid all the time"""
         return
 
-    def _decodeValue(self, value):
+    def _decode_val(self, value):
         """
         Return bytes to be stored in self.value
         """
@@ -357,7 +361,7 @@ class File(Input):
     def input_html(self, default=None, id_value=None, title=None, mimeType=None):
         return '<input type="file" %stitle="%s" name="%s" %s accept="%s">' % (
             self.id_attr(id_value),
-            self.titleHTML(title),
+            self.title_attr(title),
             self.name,
             self._accesskey_attr(),
             mimeType or self.mimeType
@@ -398,7 +402,7 @@ class Radio(Field):
           [('value1','description1),('value2','description2),..]
           for options with different option value and description.
         """
-        self.setOptions(options)
+        self.set_options(options)
         self.set_default(default)
         Field.__init__(self, name, text, self.maxLen, maxValues, '', required, default, accesskey)
 
@@ -412,7 +416,7 @@ class Radio(Field):
         if value and (not value in self.optionValues):
             raise InvalidValueFormat(self.name, self.text, value)
 
-    def setOptions(self, options):
+    def set_options(self, options):
         self.optionValues = {}
         self.maxLen = 0
         if options:
@@ -427,7 +431,7 @@ class Radio(Field):
 
     def input_html(self, default=None, id_value=None, title=None):
         s = []
-        default_value = self._defaultValue(default)
+        default_value = self._default_val(default)
         for i in self.options:
             if isinstance(i, tuple):
                 optionValue, optionText = i
@@ -446,7 +450,7 @@ class Radio(Field):
                 >%s<br>
                 """ % (
                     self.id_attr(id_value),
-                    self.titleHTML(title),
+                    self.title_attr(title),
                     self.name.encode(self.charset),
                     self._accesskey_attr(),
                     optionValue.encode(self.charset),
@@ -523,7 +527,7 @@ class Select(Radio):
         self.ignoreCase = ignoreCase
         Radio.__init__(self, name, text, maxValues, required, default, accesskey, options)
 
-    def _defaultValue(self, default):
+    def _default_val(self, default):
         """returns default value"""
         if default:
             return default
@@ -534,13 +538,13 @@ class Select(Radio):
     def input_html(self, default=None, id_value=None, title=None):
         res = ['<select %stitle="%s" name="%s" %s  size="%d" %s>' % (
             self.id_attr(id_value),
-            self.titleHTML(title),
+            self.title_attr(title),
             self.name,
             self._accesskey_attr(),
             self.size,
             " multiple"*(self.multiSelect > 0)
         )]
-        default_value = self._defaultValue(default)
+        default_value = self._default_val(default)
         for i in self.options:
             if isinstance(i, tuple):
                 try:
@@ -601,7 +605,7 @@ class DataList(Input, Select):
         self.size = size or 20
         self.multiSelect = 0
         self.ignoreCase = ignoreCase
-        self.setOptions(options)
+        self.set_options(options)
         self.set_default(default)
 
     def input_html(self, default=None, id_value=None, title=None):
@@ -609,7 +613,7 @@ class DataList(Input, Select):
         s = [
             '<input %stitle="%s" name="%s" %s maxlength="%d" size="%d" value="%s" list="%s">' % (
                 self.id_attr(id_value),
-                self.titleHTML(title),
+                self.title_attr(title),
                 self.name,
                 self._accesskey_attr(),
                 self.maxLen,
@@ -658,7 +662,7 @@ class Checkbox(Field):
             checked = self.checked
         return '<input type="checkbox" %stitle="%s" name="%s" %s value="%s"%s>' % (
             self.id_attr(id_value),
-            self.titleHTML(title),
+            self.title_attr(title),
             self.name,
             self._accesskey_attr(),
             self._default_html(default),
@@ -862,10 +866,10 @@ class Form:
         self.request_method = env['REQUEST_METHOD']
         self.script_name = env['SCRIPT_NAME']
         # Initialize the AcceptHeaderDict objects
-        self.http_accept_charset = helper.AcceptCharsetDict('HTTP_ACCEPT_CHARSET', env)
-        self.http_accept_language = helper.AcceptHeaderDict('HTTP_ACCEPT_LANGUAGE', env)
+        self.http_accept_charset = AcceptCharsetDict('HTTP_ACCEPT_CHARSET', env)
+        self.http_accept_language = AcceptHeaderDict('HTTP_ACCEPT_LANGUAGE', env)
         self.accept_language = self.http_accept_language.keys()
-        self.http_accept_encoding = helper.AcceptHeaderDict('HTTP_ACCEPT_ENCODING', env)
+        self.http_accept_encoding = AcceptHeaderDict('HTTP_ACCEPT_ENCODING', env)
         # Determine query string
         self.query_string = env.get('QUERY_STRING', '')
         # initialize Unicode codecs
